=encoding utf8

=head1 NAME

Locale::CLDR::Locales::My - Package for language Burmese

=cut

package Locale::CLDR::Locales::My;
# This file auto generated from Data\common\main\my.xml
#	on Wed 15 Jan 11:22:39 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

extends('Locale::CLDR::Locales::Root');
has 'valid_algorithmic_formats' => (
    is => 'ro',
    isa => ArrayRef,
    init_arg => undef,
    default => sub {[ 'spellout-numbering-year','spellout-numbering','spellout-cardinal','spellout-ordinal' ]},
);

has 'algorithmic_number_format_data' => (
    is => 'ro',
    isa => HashRef,
    init_arg => undef,
    default => sub {
        use bigfloat;
        return {
		'spellout-cardinal' => {
			'public' => {
				'-x' => {
					divisor => q(1),
					rule => q(အနုတ်→→),
				},
				'0' => {
					base_value => q(0),
					divisor => q(1),
					rule => q(သုည),
				},
				'x.x' => {
					divisor => q(1),
					rule => q(←←ဒသမ→→),
				},
				'1' => {
					base_value => q(1),
					divisor => q(1),
					rule => q(တစ်),
				},
				'2' => {
					base_value => q(2),
					divisor => q(1),
					rule => q(နှစ်),
				},
				'3' => {
					base_value => q(3),
					divisor => q(1),
					rule => q(သုံး),
				},
				'4' => {
					base_value => q(4),
					divisor => q(1),
					rule => q(လေး),
				},
				'5' => {
					base_value => q(5),
					divisor => q(1),
					rule => q(ငါး),
				},
				'6' => {
					base_value => q(6),
					divisor => q(1),
					rule => q(ခြောက်),
				},
				'7' => {
					base_value => q(7),
					divisor => q(1),
					rule => q(ခုနှစ်),
				},
				'8' => {
					base_value => q(8),
					divisor => q(1),
					rule => q(ရှစ်),
				},
				'9' => {
					base_value => q(9),
					divisor => q(1),
					rule => q(ကိုး),
				},
				'10' => {
					base_value => q(10),
					divisor => q(10),
					rule => q(ဆယ်),
				},
				'11' => {
					base_value => q(11),
					divisor => q(10),
					rule => q(ဆယ့်[→→]),
				},
				'20' => {
					base_value => q(20),
					divisor => q(10),
					rule => q(←←ဆယ်[→→]),
				},
				'100' => {
					base_value => q(100),
					divisor => q(100),
					rule => q(←←ရာ),
				},
				'101' => {
					base_value => q(101),
					divisor => q(100),
					rule => q(←←ရာ့[→→]),
				},
				'1000' => {
					base_value => q(1000),
					divisor => q(1000),
					rule => q(←←ထောင်),
				},
				'1001' => {
					base_value => q(1001),
					divisor => q(1000),
					rule => q(←←ထောင့်[→→]),
				},
				'10000' => {
					base_value => q(10000),
					divisor => q(10000),
					rule => q(←←သောင်း[→→]),
				},
				'100000' => {
					base_value => q(100000),
					divisor => q(100000),
					rule => q(←←သိန်း[→→]),
				},
				'1000000' => {
					base_value => q(1000000),
					divisor => q(1000000),
					rule => q(←←သန်း[→→]),
				},
				'10000000' => {
					base_value => q(10000000),
					divisor => q(10000000),
					rule => q(←←ကုဋေ[→→]),
				},
				'100000000000000' => {
					base_value => q(100000000000000),
					divisor => q(100000000000000),
					rule => q(←←ကောဋိ[→→]),
				},
				'1000000000000000000' => {
					base_value => q(1000000000000000000),
					divisor => q(1000000000000000000),
					rule => q(=#,##0=),
				},
				'max' => {
					base_value => q(1000000000000000000),
					divisor => q(1000000000000000000),
					rule => q(=#,##0=),
				},
			},
		},
		'spellout-numbering' => {
			'public' => {
				'0' => {
					base_value => q(0),
					divisor => q(1),
					rule => q(=%spellout-cardinal=),
				},
				'max' => {
					base_value => q(0),
					divisor => q(1),
					rule => q(=%spellout-cardinal=),
				},
			},
		},
		'spellout-numbering-year' => {
			'public' => {
				'0' => {
					base_value => q(0),
					divisor => q(1),
					rule => q(=%spellout-cardinal=),
				},
				'x.x' => {
					divisor => q(1),
					rule => q(=0.0=),
				},
				'max' => {
					divisor => q(1),
					rule => q(=0.0=),
				},
			},
		},
		'spellout-ordinal' => {
			'public' => {
				'-x' => {
					divisor => q(1),
					rule => q(အနုတ်→→),
				},
				'0' => {
					base_value => q(0),
					divisor => q(1),
					rule => q(=%spellout-cardinal=),
				},
				'x.x' => {
					divisor => q(1),
					rule => q(=#,##0.#=),
				},
				'1' => {
					base_value => q(1),
					divisor => q(1),
					rule => q(ပထမ),
				},
				'2' => {
					base_value => q(2),
					divisor => q(1),
					rule => q(ဒုတိယ),
				},
				'3' => {
					base_value => q(3),
					divisor => q(1),
					rule => q(တတိယ),
				},
				'4' => {
					base_value => q(4),
					divisor => q(1),
					rule => q(စတုတ္ထ),
				},
				'5' => {
					base_value => q(5),
					divisor => q(1),
					rule => q(ပဉ္စမ),
				},
				'6' => {
					base_value => q(6),
					divisor => q(1),
					rule => q(ဆဋ္ဌမ),
				},
				'7' => {
					base_value => q(7),
					divisor => q(1),
					rule => q(သတ္တမ),
				},
				'8' => {
					base_value => q(8),
					divisor => q(1),
					rule => q(အဋ္ဌမ),
				},
				'9' => {
					base_value => q(9),
					divisor => q(1),
					rule => q(နဝမ),
				},
				'10' => {
					base_value => q(10),
					divisor => q(10),
					rule => q(ဒသမ),
				},
				'11' => {
					base_value => q(11),
					divisor => q(10),
					rule => q(=%spellout-cardinal=),
				},
				'max' => {
					base_value => q(11),
					divisor => q(10),
					rule => q(=%spellout-cardinal=),
				},
			},
		},
    } },
);

has 'display_name_language' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub {
		 sub {
			 my %languages = (
				'aa' => 'အာဖာ',
 				'ab' => 'အဘ်ခါဇီရာ',
 				'ace' => 'အာချေး',
 				'ada' => 'ဒန်မဲ',
 				'ady' => 'အဒိုင်ဂီ',
 				'af' => 'အာဖရိကန်',
 				'agq' => 'အာဂ်ဟိန်း',
 				'ain' => 'အိန်နု',
 				'ak' => 'အာကန်',
 				'ale' => 'အာလီယု',
 				'alt' => 'တောင် အာလ်တိုင်း',
 				'am' => 'အမ်ဟာရစ်ခ်',
 				'an' => 'အာရာဂွန်',
 				'ang' => 'အင်ဂလို ဆက္ကစွန်',
 				'ann' => 'အိုဘိုလို',
 				'anp' => 'အန်ဂီကာ',
 				'ar' => 'အာရဗီ',
 				'ar_001' => 'ခေတ်သစ် ရှေ့ဆောင် အာရဗီ',
 				'arn' => 'မာပုချီ',
 				'arp' => 'အာရာပါဟို',
 				'ars' => 'နာ့ဂျဒီ အာရဗစ်',
 				'as' => 'အာသံ',
 				'asa' => 'အာစု',
 				'ast' => 'အက်စ်တိုးရီးယား',
 				'atj' => 'အာတီကမဲကု',
 				'av' => 'အာဗာရစ်ခ်',
 				'awa' => 'အာဝါဒီ',
 				'ay' => 'အိုင်မာရ',
 				'az' => 'အဇာဘိုင်ဂျန်',
 				'az@alt=short' => 'အဇာရီ',
 				'ba' => 'ဘက်ရှ်ကာ',
 				'ban' => 'ဘာလီ',
 				'bas' => 'ဘာဆာ',
 				'be' => 'ဘီလာရုစ်',
 				'bem' => 'ဘိန်ဘာ',
 				'bez' => 'ဘီနာ',
 				'bg' => 'ဘူလ်ဂေးရီးယား',
 				'bgc' => 'ဟာယန်ဗီ',
 				'bgn' => 'အနောက် ဘဲလိုချီ',
 				'bho' => 'ဘို့ဂျ်ပူရီ',
 				'bi' => 'ဘစ်စ်လာမာ',
 				'bin' => 'ဘီနီ',
 				'bla' => 'စစ္စီကာ',
 				'blo' => 'အန်နီ',
 				'bm' => 'ဘန်ဘာရာ',
 				'bn' => 'ဘင်္ဂါလီ',
 				'bo' => 'တိဘက်',
 				'br' => 'ဘရီတွန်',
 				'brx' => 'ဗိုဒို',
 				'bs' => 'ဘော့စ်နီးယား',
 				'bug' => 'ဘူဂစ်စ်',
 				'byn' => 'ဘလင်',
 				'ca' => 'ကတ်တလန်',
 				'cay' => 'ကာယုဂါ',
 				'ccp' => 'ချတ်ခ်မာ',
 				'ce' => 'ချက်ချန်း',
 				'ceb' => 'စီဗူအာနို',
 				'cgg' => 'ချီဂါ',
 				'ch' => 'ချမိုရို',
 				'chk' => 'ချူကီးစ်',
 				'chm' => 'မာရီ',
 				'cho' => 'ချော့တို',
 				'chp' => 'ချီပွေဝိုင်ရန်',
 				'chr' => 'ချာရိုကီ',
 				'chy' => 'ချေယန်း',
 				'ckb' => 'ဗဟိုဒေသသုံး ကဒ်ဘာသာ',
 				'ckb@alt=menu' => 'ကဒ် ဗဟို',
 				'ckb@alt=variant' => 'ကဒ် ဆိုရာနီ',
 				'clc' => 'ချီကိုလ်တင်',
 				'co' => 'ခိုစီကန်',
 				'cr' => 'ခရီး',
 				'crg' => 'မစ်ချစ်ခ်',
 				'crj' => 'တောင်ပိုင်း အရှေ့ခရီ',
 				'crk' => 'ပလိန်းစ် ခရီ',
 				'crl' => 'မြောက်ပိုင်း အရှေ့ခရီ',
 				'crm' => 'မုစ်ခရီး',
 				'crr' => 'ကယ်ရိုလိုင်းနား အယ်လ်ဂွန်းကီယန်',
 				'crs' => 'ခရီအိုလီ',
 				'cs' => 'ချက်',
 				'csw' => 'ဆွမ်ပီ ခရီ',
 				'cu' => 'ချပ်ချ် စလာဗစ်',
 				'cv' => 'ချူဗက်ရှ်',
 				'cy' => 'ဝေလ',
 				'da' => 'ဒိန်းမတ်',
 				'dak' => 'ဒါကိုတာ',
 				'dar' => 'ဒါဂ်ဝါ',
 				'dav' => 'တိုင်တာ',
 				'de' => 'ဂျာမန်',
 				'de_AT' => 'ဩစတြီးယား ဂျာမန်',
 				'de_CH' => 'အလီမဲန်နစ် ဂျာမန်',
 				'del' => 'ဒယ်လာဝဲလ်',
 				'dgr' => 'ဒေါ့ဂ်ရစ်ဘ်',
 				'dje' => 'ဇာမာ',
 				'doi' => 'ဒိုဂရီ',
 				'dsb' => 'အနိမ့် ဆိုဘီယန်း',
 				'dua' => 'ဒူအလာ',
 				'dum' => 'အလယ်ပိုင်း ဒတ်ချ်',
 				'dv' => 'ဒီဗာဟီ',
 				'dyo' => 'ဂျိုလာ-ဖွန်ရီ',
 				'dz' => 'ဒဇွန်ကာ',
 				'dzg' => 'ဒဇာဂါ',
 				'ebu' => 'အမ်ဘူ',
 				'ee' => 'အီဝီ',
 				'efi' => 'အာဖိခ်',
 				'egy' => 'ရှေးဟောင်း အီဂျစ်',
 				'eka' => 'အီကာဂျုခ်',
 				'el' => 'ဂရိ',
 				'en' => 'အင်္ဂလိပ်',
 				'en_AU' => 'ဩစတြေးလျ အင်္ဂလိပ်',
 				'en_CA' => 'ကနေဒါ အင်္ဂလိပ်',
 				'en_GB' => 'ဗြိတိသျှ အင်္ဂလိပ်',
 				'en_GB@alt=short' => 'ယူကေ အင်္ဂလိပ်',
 				'en_US' => 'အမေရိကန် အင်္ဂလိပ်',
 				'en_US@alt=short' => 'ယူအက်စ် အင်္ဂလိပ်',
 				'enm' => 'အလယ်ပိုင်း အင်္ဂလိပ်',
 				'eo' => 'အက်စ်ပရန်တို',
 				'es' => 'စပိန်',
 				'es_ES' => 'စပိန် (ဥရောပ)',
 				'es_MX' => 'စပိန် (မက္ကဆီကို)',
 				'et' => 'အက်စ်တိုးနီးယား',
 				'eu' => 'ဘာစ်ခ်',
 				'ewo' => 'အီဝန်ဒို',
 				'fa' => 'ပါရှန်',
 				'fa_AF' => 'ဒါရီ',
 				'ff' => 'ဖူလာ',
 				'fi' => 'ဖင်လန်',
 				'fil' => 'ဖိလစ်ပိုင်',
 				'fj' => 'ဖီဂျီ',
 				'fo' => 'ဖာရို',
 				'fon' => 'ဖော်န်',
 				'fr' => 'ပြင်သစ်',
 				'fr_CA' => 'ကနေဒါ ပြင်သစ်',
 				'fr_CH' => 'ဆွစ် ပြင်သစ်',
 				'frc' => 'ကေဂျန် ဖရန့်စ်',
 				'frm' => 'အလယ်ပိုင်း ပြင်သစ်',
 				'fro' => 'ဖရန်စီစ်',
 				'frr' => 'မြောက် ဖရီစီရန်',
 				'frs' => 'အရှေ့ ဖရီစီရန်',
 				'fur' => 'ဖရူလီယန်း',
 				'fy' => 'အနောက် ဖရီစီရန်',
 				'ga' => 'အိုင်းရစ်ရှ်',
 				'gaa' => 'ဂါ',
 				'gag' => 'ဂါဂုဇ်',
 				'gd' => 'စကော့တစ်ရှ် ဂေးလစ်ခ်',
 				'gez' => 'ဂီးဇ်',
 				'gil' => 'ကာရီဗာတီ',
 				'gl' => 'ဂါလီစီယာ',
 				'gmh' => 'အလယ်ပိုင်း အမြင့် ဂျာမန်',
 				'gn' => 'ဂူအာရာနီ',
 				'gor' => 'ဂိုရိုတာလို',
 				'grc' => 'ရှေးဟောင်း ဂရိ',
 				'gsw' => 'ဆွစ် ဂျာမန်',
 				'gu' => 'ဂူဂျာရသီ',
 				'guz' => 'ဂူစီး',
 				'gv' => 'မန်းဇ်',
 				'gwi' => 'ဂွစ်ချင်',
 				'ha' => 'ဟာဥစာ',
 				'hai' => 'ဟေဒါ',
 				'haw' => 'ဟာဝိုင်ယီ',
 				'hax' => 'တောင် ဟိုင်ဒါ',
 				'he' => 'ဟီဘရူး',
 				'hi' => 'ဟိန္ဒီ',
 				'hi_Latn' => 'ဟိန္ဒီ (လက်တင်)',
 				'hil' => 'ဟီလီဂေနွန်',
 				'hmn' => 'မုံ',
 				'hr' => 'ခရိုအေးရှား',
 				'hsb' => 'ဆက္ကဆိုနီ',
 				'ht' => 'ဟေတီ',
 				'hu' => 'ဟန်ဂေရီ',
 				'hup' => 'ဟူပါ',
 				'hur' => 'ဟော့ကမိုလွမ်',
 				'hy' => 'အာမေးနီးယား',
 				'hz' => 'ဟီရဲရို',
 				'ia' => 'အင်တာလင်ဂွါ',
 				'iba' => 'အီဗန်',
 				'ibb' => 'အီဘီဘီယို',
 				'id' => 'အင်ဒိုနီးရှား',
 				'ie' => 'အင်တာလင်း',
 				'ig' => 'အစ္ဂဘို',
 				'ii' => 'စီချွမ် ရီ',
 				'ikt' => 'အနောက် ကနေဒီယန် အီနုတီတွတ်',
 				'ilo' => 'အီလိုကို',
 				'inh' => 'အင်ဂုရှ်',
 				'io' => 'အီဒို',
 				'is' => 'အိုက်စ်လန်',
 				'it' => 'အီတလီ',
 				'iu' => 'အီနုခ်တီတု',
 				'ja' => 'ဂျပန်',
 				'jbo' => 'လိုဂျ်ဘန်',
 				'jgo' => 'ဂွမ်ဘာ',
 				'jmc' => 'မချာမီ',
 				'jpr' => 'ဂျူဒီယို-ပါရှန်',
 				'jrb' => 'ဂျူဒီယို-အာရဗီ',
 				'jv' => 'ဂျာဗား',
 				'ka' => 'ဂျော်ဂျီယာ',
 				'kab' => 'ကဘိုင်လ်',
 				'kac' => 'ကချင်',
 				'kaj' => 'ဂျူအူ',
 				'kam' => 'ကမ်ဘာ',
 				'kbd' => 'ကဘာဒင်',
 				'kcg' => 'တိုင်အပ်',
 				'kde' => 'မာခွန်ဒီ',
 				'kea' => 'ကဘူဗာဒီအာနူ',
 				'kfo' => 'ကိုရို',
 				'kg' => 'ကွန်ဂို',
 				'kgp' => 'ကိန်းဂန်',
 				'kha' => 'ခါစီ',
 				'khq' => 'ကိုရာ ချီအီနီ',
 				'ki' => 'ကီကူယူ',
 				'kj' => 'ကွန်းယာမာ',
 				'kk' => 'ကာဇာချ',
 				'kkj' => 'ကကို',
 				'kl' => 'ကလာအ်လီဆပ်',
 				'kln' => 'ကလန်ဂျင်',
 				'km' => 'ခမာ',
 				'kmb' => 'ကင်ဘွန်ဒူ',
 				'kn' => 'ကန်နာဒါ',
 				'ko' => 'ကိုရီးယား',
 				'koi' => 'ကိုမီ-ပါမြက်',
 				'kok' => 'ကွန်ကနီ',
 				'kpe' => 'ကပ်ပဲလ်',
 				'kr' => 'ကနူရီ',
 				'krc' => 'ကရာချေး-ဘာကာ',
 				'krl' => 'ကာရီလီယန်',
 				'kru' => 'ကူရုပ်ခ်',
 				'ks' => 'ကက်ရှ်မီးယား',
 				'ksb' => 'ရှန်ဘာလာ',
 				'ksf' => 'ဘာဖီအာ',
 				'ksh' => 'ကိုလိုနီယန်း',
 				'ku' => 'ကဒ်',
 				'kum' => 'ကွမ်မိုက်',
 				'kv' => 'ကိုမီ',
 				'kw' => 'ခိုနီရှ်',
 				'kwk' => 'ကွပ်ခ်ဝါလာ',
 				'kxv' => 'ကူဗီ',
 				'ky' => 'ကာဂျစ်',
 				'la' => 'လက်တင်',
 				'lad' => 'လာဒီနို',
 				'lag' => 'လန်ဂီ',
 				'lb' => 'လူဇင်ဘတ်',
 				'lez' => 'လက်ဇ်ဂီးယား',
 				'lg' => 'ဂန်ဒါ',
 				'li' => 'လင်ဘာဂစ်ရှ်',
 				'lij' => 'လက်ဂါးရီရန်',
 				'lil' => 'လာလူးဝစ်တ်',
 				'lkt' => 'လာကိုတာ',
 				'lmo' => 'လန်းဘတ်',
 				'ln' => 'လင်ဂါလာ',
 				'lo' => 'လာအို',
 				'lou' => 'လူဝီဇီယားနား ခရီးယို',
 				'loz' => 'လိုဇီ',
 				'lrc' => 'မြောက်လူရီ',
 				'lsm' => 'ဆာမိအာ',
 				'lt' => 'လစ်သူဝေးနီးယား',
 				'lu' => 'လူဘာ-ကတန်ဂါ',
 				'lua' => 'လူဘာ-လူလူအာ',
 				'lun' => 'လွန်ဒါ',
 				'luo' => 'လူအို',
 				'lus' => 'မီဇို',
 				'luy' => 'လူရီအာ',
 				'lv' => 'လတ်ဗီးယား',
 				'mad' => 'မဒူရာ',
 				'mag' => 'မဂါဟီ',
 				'mai' => 'မိုင်သီလီ',
 				'mak' => 'မကာဆာ',
 				'mas' => 'မာဆိုင်',
 				'mdf' => 'မို့ခ်ရှာ',
 				'men' => 'မန်ဒဲ',
 				'mer' => 'မီရု',
 				'mfe' => 'မောရစ်ရှ',
 				'mg' => 'မာလဂက်စီ',
 				'mga' => 'အလယ်ပိုင်း အိုင်းရစ်ရှ်',
 				'mgh' => 'မာခူဝါ-မီအီတို',
 				'mgo' => 'မီတာ',
 				'mh' => 'မာရှယ်လိဇ်',
 				'mi' => 'မာအိုရီ',
 				'mic' => 'မစ်ခ်မက်ခ်',
 				'min' => 'စူကူမီနန်',
 				'mk' => 'မက်ဆီဒိုးနီးယား',
 				'ml' => 'မလေယာလမ်',
 				'mn' => 'မွန်ဂိုလီးယား',
 				'mnc' => 'မန်ချူး',
 				'mni' => 'မနိပူရ',
 				'moe' => 'အီနုအေမွန်',
 				'moh' => 'မိုဟော့ခ်',
 				'mos' => 'မိုစီ',
 				'mr' => 'မာရသီ',
 				'ms' => 'မလေး',
 				'mt' => 'မော်လ်တာ',
 				'mua' => 'မွန်ဒန်း',
 				'mul' => 'ဘာသာစကား အမျိုးမျိုး',
 				'mus' => 'ခရိချ',
 				'mwl' => 'မီရန်ဒီးဇ်',
 				'my' => 'မြန်မာ',
 				'myv' => 'အီဇယာ',
 				'mzn' => 'မာဇန်ဒါရန်နီ',
 				'na' => 'နော်ရူး',
 				'nap' => 'နပိုလီတန်',
 				'naq' => 'နာမာ',
 				'nb' => 'နော်ဝေ ဘွတ်ခ်မော်လ်',
 				'nd' => 'မြောက် အွန်န်ဒီဘီလီ',
 				'nds' => 'အနိမ့် ဂျာမန်',
 				'nds_NL' => 'ဂျာမန် (နယ်သာလန်)',
 				'ne' => 'နီပေါ',
 				'new' => 'နီဝါရီ',
 				'ng' => 'အွန်ဒွန်ဂါ',
 				'nia' => 'နီးရပ်စ်',
 				'niu' => 'နူအဲယန်း',
 				'nl' => 'ဒတ်ခ်ျ',
 				'nl_BE' => 'ဖလီမစ်ရှ်',
 				'nmg' => 'ကွာစီအို',
 				'nn' => 'နော်ဝေ နီးနောစ်',
 				'nnh' => 'အွန်ရဲဘွန်း',
 				'no' => 'နော်ဝေ',
 				'nog' => 'နိုဂိုင်',
 				'nqo' => 'အွန်ကို',
 				'nr' => 'တောင် အွန်န်ဘီလီ',
 				'nso' => 'မြောက် ဆိုသို',
 				'nus' => 'နူအာ',
 				'nv' => 'နာဗာဟို',
 				'ny' => 'နရန်ဂျာ',
 				'nyn' => 'နရန်ကိုလီ',
 				'oc' => 'အိုစီတန်',
 				'ojb' => 'အိုဂျစ်ဘွာ',
 				'ojc' => 'အိုဂျစ်ဘွေး',
 				'ojs' => 'အိုဂျီခရီ',
 				'ojw' => 'အနောက် အိုဂျီဘွာ',
 				'oka' => 'အိုကနဂန်',
 				'om' => 'အိုရိုမို',
 				'or' => 'အိုရီရာ',
 				'os' => 'အိုဆဲတစ်ခ်',
 				'pa' => 'ပန်ချာပီ',
 				'pag' => 'ပန်ဂါစီနန်',
 				'pam' => 'ပမ်ပန်ညာ',
 				'pap' => 'ပါပီမင်တို',
 				'pau' => 'ပလာအို',
 				'pcm' => 'နိုင်ဂျီးရီးယား ပစ်ဂျင်',
 				'peo' => 'ပါရှန် အဟောင်း',
 				'pi' => 'ပါဠိ',
 				'pis' => 'ပီဂျင်',
 				'pl' => 'ပိုလန်',
 				'pqm' => 'မလိဇိ ပါစမ်မကွာဒီ',
 				'prg' => 'ပရူရှန်',
 				'ps' => 'ပက်ရှ်တွန်း',
 				'pt' => 'ပေါ်တူဂီ',
 				'pt_BR' => 'ဘရာဇီး ပေါ်တူဂီ',
 				'pt_PT' => 'ဥရောပ ပေါ်တူဂီ',
 				'qu' => 'ခီချူဝါအိုဝါ',
 				'quc' => 'ကီခ်အီချီ',
 				'raj' => 'ရာဂျာစတာနီ',
 				'rap' => 'ရပန်နူအီ',
 				'rar' => 'ရရိုတွန်ဂန်',
 				'rhg' => 'ရိုဟင်ဂျာ',
 				'rm' => 'ရောမ',
 				'rn' => 'ရွန်ဒီ',
 				'ro' => 'ရိုမေနီယား',
 				'ro_MD' => 'မော်လဒိုဗာ',
 				'rof' => 'ရွမ်ဘို',
 				'ru' => 'ရုရှ',
 				'rup' => 'အာရိုမန်းနီးယန်း',
 				'rw' => 'ကင်ရာဝန်ဒါ',
 				'rwk' => 'ရူဝမ်',
 				'sa' => 'သင်္သကရိုက်',
 				'sad' => 'ဆန်ဒါဝီ',
 				'sah' => 'ဆခါ',
 				'saq' => 'ဆမ်ဘူရူ',
 				'sat' => 'ဆန်တာလီ',
 				'sba' => 'အွန်ဂမ်းဘေး',
 				'sbp' => 'ဆန်ဂု',
 				'sc' => 'ဆာဒီနီးယား',
 				'scn' => 'စစ္စလီ',
 				'sco' => 'စကော့တ်',
 				'sd' => 'စင်ဒီ',
 				'se' => 'မြောက် ဆာမိ',
 				'seh' => 'စီနာ',
 				'ses' => 'ကိုရာဘိုရို ဆမ်နီ',
 				'sg' => 'ဆန်ဂို',
 				'sga' => 'အိုင်းရစ် ဟောင်း',
 				'shi' => 'တာချယ်လ်ဟစ်',
 				'shn' => 'ရှမ်း',
 				'si' => 'စင်ဟာလာ',
 				'sk' => 'ဆလိုဗက်',
 				'sl' => 'ဆလိုဗေးနီးယား',
 				'slh' => 'တောင် လာ့ရှုစတိ',
 				'sm' => 'ဆမိုအာ',
 				'sma' => 'တောင် ဆာမိ',
 				'smj' => 'လူလီ ဆာမိ',
 				'smn' => 'အီနာရီ ဆာမိ',
 				'sms' => 'စခိုးလ် ဆာမိ',
 				'sn' => 'ရှိုနာ',
 				'snk' => 'ဆိုနင်ကေး',
 				'so' => 'ဆိုမာလီ',
 				'sq' => 'အယ်လ်ဘေးနီးယား',
 				'sr' => 'ဆားဘီးယား',
 				'srn' => 'ဆရာနန် တွန်ဂို',
 				'ss' => 'ဆွာဇီလန်',
 				'ssy' => 'ဆာဟို',
 				'st' => 'တောင်ပိုင်း ဆိုသို',
 				'str' => 'ဆဲလစ်ရှ် ရေလက်ကြား',
 				'su' => 'ဆူဒန်',
 				'suk' => 'ဆူကူမာ',
 				'sv' => 'ဆွီဒင်',
 				'sw' => 'ဆွာဟီလီ',
 				'sw_CD' => 'ကွန်ဂို ဆွာဟီလီ',
 				'swb' => 'ကိုမိုရီးယန်း',
 				'syr' => 'ဆီးရီးယား',
 				'szl' => 'စလီရှန်',
 				'ta' => 'တမီးလ်',
 				'tce' => 'တောင် တပ်ချွန်',
 				'te' => 'တီလီဂူ',
 				'tem' => 'တင်မ်နဲ',
 				'teo' => 'တီဆို',
 				'tet' => 'တီတွမ်',
 				'tg' => 'တာဂျစ်',
 				'tgx' => 'တာဂစ်ရှ်',
 				'th' => 'ထိုင်း',
 				'tht' => 'တဟီတန်',
 				'ti' => 'တီဂ်ရင်ယာ',
 				'tig' => 'တီဂရီ',
 				'tk' => 'တာ့ခ်မင်နစ္စတန်',
 				'tlh' => 'ကလင်ဂွန်',
 				'tli' => 'တလင်းဂစ်',
 				'tn' => 'တီဆဝါနာ',
 				'to' => 'တွန်ဂါ',
 				'tok' => 'တိုကီပိုနာ',
 				'tpi' => 'တော့ခ် ပိစင်',
 				'tr' => 'တူရကီ',
 				'trv' => 'တရိုကို',
 				'ts' => 'ဆွန်ဂါ',
 				'tt' => 'တာတာ',
 				'ttm' => 'မြောက် တပ်ချွန်',
 				'tum' => 'တမ်ဘူကာ',
 				'tvl' => 'တူဗာလူ',
 				'twq' => 'တာဆာဝါချ',
 				'ty' => 'တဟီတီ',
 				'tyv' => 'တူဗန်',
 				'tzm' => 'အလယ်အာ့တလာစ် တာမာဇိုက်',
 				'udm' => 'အူမူရတ်',
 				'ug' => 'ဝီဂါ',
 				'uk' => 'ယူကရိန်း',
 				'umb' => 'အူဘန်ဒူ',
 				'und' => 'မသိသော ဘာသာ',
 				'ur' => 'အူရ်ဒူ',
 				'uz' => 'ဥဇဘတ်',
 				'vai' => 'ဗိုင်',
 				've' => 'ဗင်န်ဒါ',
 				'vec' => 'ဗနီးရှန်',
 				'vi' => 'ဗီယက်နမ်',
 				'vmw' => 'မတ်ကူးဝါး',
 				'vo' => 'ဗိုလာပိုက်',
 				'vun' => 'ဗွန်ဂျို',
 				'wa' => 'ဝါလူးန်',
 				'wae' => 'ဝေါလ်ဆာ',
 				'wal' => 'ဝိုလက်တာ',
 				'war' => 'ဝါရေး',
 				'wbp' => 'ဝေါလ်ပီရီ',
 				'wo' => 'ဝူလိုဖ်',
 				'wuu' => 'ဝူ တရုတ်',
 				'xal' => 'ကာလ်မိုက်',
 				'xh' => 'ဇိုစာ',
 				'xnr' => 'ခန်းဂရီ',
 				'xog' => 'ဆိုဂါ',
 				'yav' => 'ရန်ဘဲန်',
 				'ybb' => 'ရမ်ဘာ',
 				'yi' => 'ရဟူဒီ',
 				'yo' => 'ယိုရူဘာ',
 				'yrl' => 'အန်ဟင်းဂတူ',
 				'yue' => 'ကွမ်းတုံ',
 				'yue@alt=menu' => 'တရုတ်/ ကွမ်းတုံ',
 				'za' => 'ဂျွမ်',
 				'zgh' => 'မိုရိုကို တမဇိုက်',
 				'zh' => 'တရုတ်',
 				'zh@alt=menu' => 'ပြည်ကြီးတရုတ်',
 				'zh_Hans@alt=long' => 'ပြည်ကြီးတရုတ် (ရိုးရှင်း)',
 				'zh_Hant@alt=long' => 'ပြည်ကြီးတရုတ် (ရိုးရာ)',
 				'zu' => 'ဇူးလူး',
 				'zun' => 'ဇူနီ',
 				'zxx' => 'ဘာသာစကားနှင့် ပတ်သက်သောအရာ မရှိပါ',
 				'zza' => 'ဇာဇာ',

			);
			if (@_) {
				return $languages{$_[0]};
			}
			return \%languages;
		}
	},
);

has 'display_name_script' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub {
		sub {
			my %scripts = (
			'Adlm' => 'အက်ဒ်လမ်',
 			'Arab' => 'အာရေဗျ',
 			'Aran' => 'နက်စ်တာလိခ်',
 			'Armn' => 'အာမေးနီးယား',
 			'Beng' => 'ဘင်္ဂါလီ',
 			'Bopo' => 'ဘိုပို',
 			'Brah' => 'ဗွဟ်မမီ',
 			'Brai' => 'ဘရေ',
 			'Cakm' => 'ချပ်ခ်မာ',
 			'Cans' => 'ကင်န်စ်',
 			'Cher' => 'ချာရိုကီး',
 			'Cyrl' => 'စစ်ရိလစ်',
 			'Deva' => 'ဒီဗနာဂရီ',
 			'Ethi' => 'အီသီယိုးပီးယား',
 			'Geor' => 'ဂျော်ဂျီယာ',
 			'Grek' => 'ဂရိ',
 			'Gujr' => 'ဂုဂျာရသီ',
 			'Guru' => 'ဂူရူ',
 			'Hanb' => 'ဟန်ဘ်',
 			'Hang' => 'ဟန်ဂူးလ်',
 			'Hani' => 'ဟန်',
 			'Hans' => 'ရိုးရှင်း',
 			'Hans@alt=stand-alone' => 'ဟန် ရိုးရှင်း',
 			'Hant' => 'ရိုးရာ',
 			'Hant@alt=stand-alone' => 'ဟန် ရိုးရာ',
 			'Hebr' => 'ဟီဗရူး',
 			'Hira' => 'ဟီရဂန',
 			'Hrkt' => 'ဂျပန် အက္ခရာ',
 			'Jamo' => 'ဂျမို',
 			'Java' => 'ဂျာဗားနီးစ်',
 			'Jpan' => 'ဂျပန်',
 			'Kali' => 'ကယားလီ',
 			'Kana' => 'ခတခန',
 			'Khmr' => 'ခမာ',
 			'Knda' => 'ခန်နာဒါ',
 			'Kore' => 'ကိုရီးယား',
 			'Laoo' => 'လာအို',
 			'Latn' => 'လက်တင်',
 			'Mlym' => 'မလေယာလမ်',
 			'Mong' => 'မွန်ဂိုလီးယား',
 			'Mtei' => 'မေတဲမာယက်',
 			'Mymr' => 'မြန်မာ',
 			'Nkoo' => 'အွန်ကို',
 			'Olck' => 'အိုလ်ချီကီ',
 			'Orya' => 'အိုရာ',
 			'Rohg' => 'ဟာနီဖီ',
 			'Sinh' => 'ဆင်ဟာလ',
 			'Sund' => 'ဆူဒန်',
 			'Syrc' => 'ဆီရီရက်ခ်',
 			'Tale' => 'တိုင်လီ',
 			'Taml' => 'တမီးလ်',
 			'Telu' => 'တီလု',
 			'Tfng' => 'တီဖီနော',
 			'Tglg' => 'တဂလော့ဂ်',
 			'Thaa' => 'သာအ်',
 			'Thai' => 'ထိုင်း',
 			'Tibt' => 'တိဘက်',
 			'Vaii' => 'ဗိုင်း',
 			'Visp' => 'မြင်နိုင်သော စကား',
 			'Xpeo' => 'ပါရှန် အဟောင်း',
 			'Yiii' => 'ရီ',
 			'Zmth' => 'ဂဏန်းသင်္ချာ',
 			'Zsye' => 'အီမိုဂျီ',
 			'Zsym' => 'သင်္ကေတ',
 			'Zxxx' => 'ထုံးတမ်းသဖွယ်လိုက်နာလျက်ရှိသော',
 			'Zyyy' => 'အများနှင့်သက်ဆိုင်သော',
 			'Zzzz' => 'မသိ သို့မဟုတ် မရှိသော စကားလုံး',

			);
			if ( @_ ) {
				return $scripts{$_[0]};
			}
			return \%scripts;
		}
	}
);

has 'display_name_region' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'001' => 'ကမ္ဘာ',
 			'002' => 'အာဖရိက',
 			'003' => 'မြောက် အမေရိကတိုက်',
 			'005' => 'တောင် အမေရိက',
 			'009' => 'သမုဒ္ဒရာဒေသ',
 			'011' => 'အနောက် အာဖရိက',
 			'013' => 'ဗဟို အမေရိက',
 			'014' => 'အရှေ့ အာဖရိက',
 			'015' => 'မြောက် အာဖရိက',
 			'017' => 'အလယ် အာဖရိက',
 			'018' => 'အာဖရိက တောင်ပိုင်း',
 			'019' => 'အမေရိကန်',
 			'021' => 'မြောက် အမေရိက',
 			'029' => 'ကာရစ်ဘီယံ',
 			'030' => 'အရှေ့အာရှ',
 			'034' => 'တောင်အာရှ',
 			'035' => 'အရှေ့တောင်အာရှ',
 			'039' => 'တောင်ဥရောပ',
 			'053' => 'ဩစတြေးလျနှင့် နယူးဇီလန်',
 			'054' => 'မီလာနီးရှား',
 			'057' => 'မိုက်ခရိုနီးရှား ဒေသ',
 			'061' => 'ပိုလီနီရှား',
 			'142' => 'အာရှ',
 			'143' => 'အလယ်အာရှ',
 			'145' => 'အနောက်အာရှ',
 			'150' => 'ဥရောပ',
 			'151' => 'အရှေ့ ဥရောပ',
 			'154' => 'မြောက် ဥရောပ',
 			'155' => 'အနောက် ဥရောပ',
 			'202' => 'ဆာဟာရ-အောက်ပိုင်း အာဖရိက',
 			'419' => 'လက်တင်အမေရိက',
 			'AC' => 'အဆန်းရှင်းကျွန်း',
 			'AD' => 'အန်ဒိုရာ',
 			'AE' => 'ယူအေအီး',
 			'AF' => 'အာဖဂန်နစ္စတန်',
 			'AG' => 'အန်တီဂွါနှင့် ဘာဘူဒါ',
 			'AI' => 'အန်ဂီလာ',
 			'AL' => 'အယ်လ်ဘေးနီးယား',
 			'AM' => 'အာမေးနီးယား',
 			'AO' => 'အန်ဂိုလာ',
 			'AQ' => 'အန်တာတိက',
 			'AR' => 'အာဂျင်တီးနား',
 			'AS' => 'အမေရိကန် ဆမိုးအား',
 			'AT' => 'ဩစတြီးယား',
 			'AU' => 'ဩစတြေးလျ',
 			'AW' => 'အာရူးဗား',
 			'AX' => 'အာလန်ကျွန်း',
 			'AZ' => 'အဇာဘိုင်ဂျန်',
 			'BA' => 'ဘော့စနီးယားနှင့် ဟာဇီဂိုဗီနား',
 			'BB' => 'ဘာဘေးဒိုးစ်',
 			'BD' => 'ဘင်္ဂလားဒေ့ရှ်',
 			'BE' => 'ဘယ်လ်ဂျီယမ်',
 			'BF' => 'ဘာကီးနား ဖားဆို',
 			'BG' => 'ဘူလ်ဂေးရီးယား',
 			'BH' => 'ဘာရိန်း',
 			'BI' => 'ဘူရွန်ဒီ',
 			'BJ' => 'ဘီနင်',
 			'BL' => 'စိန့်ဘာသယ်လ်မီ',
 			'BM' => 'ဘာမြူဒါ',
 			'BN' => 'ဘရူနိုင်း',
 			'BO' => 'ဘိုလီးဗီးယား',
 			'BQ' => 'ကာရစ်ဘီယံ နယ်သာလန်',
 			'BR' => 'ဘရာဇီး',
 			'BS' => 'ဘဟားမား',
 			'BT' => 'ဘူတန်',
 			'BV' => 'ဘူဗက်ကျွန်း',
 			'BW' => 'ဘော့ဆွာနာ',
 			'BY' => 'ဘီလာရုစ်',
 			'BZ' => 'ဘလိဇ်',
 			'CA' => 'ကနေဒါ',
 			'CC' => 'ကိုကိုးကျွန်း',
 			'CD' => 'ကွန်ဂို',
 			'CD@alt=variant' => 'ကွန်ဂို ဒီမိုကရက်တစ် သမ္မတနိုင်ငံ',
 			'CF' => 'ဗဟို အာဖရိက ပြည်ထောင်စု',
 			'CG' => 'ကွန်ဂို-ဘရာဇာဗီးလ်',
 			'CG@alt=variant' => 'ကွန်ဂို သမ္မတနိုင်ငံ',
 			'CH' => 'ဆွစ်ဇာလန်',
 			'CI' => 'ကို့တ် ဒီဗွာ',
 			'CI@alt=variant' => 'အိုင်ဗရီကို့စ်',
 			'CK' => 'ကွတ် ကျွန်းစု',
 			'CL' => 'ချီလီ',
 			'CM' => 'ကင်မရွန်း',
 			'CN' => 'တရုတ်',
 			'CO' => 'ကိုလံဘီယာ',
 			'CP' => 'ကလစ်ပါတန်ကျွန်း',
 			'CR' => 'ကို့စ်တာရီကာ',
 			'CU' => 'ကျူးဘား',
 			'CV' => 'ကိတ်ဗာဒီ',
 			'CW' => 'ကျူရေးကိုးစ်',
 			'CX' => 'ခရစ်စမတ် ကျွန်း',
 			'CY' => 'ဆိုက်ပရပ်စ်',
 			'CZ' => 'ချက်ကီယား',
 			'CZ@alt=variant' => 'ချက် ပြည်ထောင်စု',
 			'DE' => 'ဂျာမနီ',
 			'DG' => 'ဒီအဲဂိုဂါစီရာ',
 			'DJ' => 'ဂျီဘူတီ',
 			'DK' => 'ဒိန်းမတ်',
 			'DM' => 'ဒိုမီနီကာ',
 			'DO' => 'ဒိုမီနီကန်',
 			'DZ' => 'အယ်လ်ဂျီးရီးယား',
 			'EA' => 'ဆယ်ဥတာနှင့်မယ်လီလ်လာ',
 			'EC' => 'အီကွေဒေါ',
 			'EE' => 'အက်စတိုးနီးယား',
 			'EG' => 'အီဂျစ်',
 			'EH' => 'အနောက် ဆာဟာရ',
 			'ER' => 'အီရီထရီးယား',
 			'ES' => 'စပိန်',
 			'ET' => 'အီသီယိုးပီးယား',
 			'EU' => 'ဥရောပသမဂ္ဂ',
 			'EZ' => 'ဥရောပဒေသ',
 			'FI' => 'ဖင်လန်',
 			'FJ' => 'ဖီဂျီ',
 			'FK' => 'ဖော့ကလန် ကျွန်းစု',
 			'FK@alt=variant' => 'ဖော့ကလန် ကျွန်းစု (အီလားစ် မောလ်ဗီနာစ်)',
 			'FM' => 'မိုင်ခရိုနီရှား',
 			'FO' => 'ဖာရိုး ကျွန်းစုများ',
 			'FR' => 'ပြင်သစ်',
 			'GA' => 'ဂါဘွန်',
 			'GB' => 'ယူနိုက်တက်ကင်းဒမ်း',
 			'GB@alt=short' => 'ယူကေ',
 			'GD' => 'ဂရီနေဒါ',
 			'GE' => 'ဂျော်ဂျီယာ',
 			'GF' => 'ပြင်သစ် ဂီယာနာ',
 			'GG' => 'ဂွန်းဇီ',
 			'GH' => 'ဂါနာ',
 			'GI' => 'ဂျီဘရော်လ်တာ',
 			'GL' => 'ဂရင်းလန်း',
 			'GM' => 'ဂမ်ဘီရာ',
 			'GN' => 'ဂီနီ',
 			'GP' => 'ဂွါဒီလု',
 			'GQ' => 'အီကွေတာ ဂီနီ',
 			'GR' => 'ဂရိ',
 			'GS' => 'တောင် ဂျော်ဂျီယာ နှင့် တောင် ဆင်းဒဝစ်ဂျ် ကျွန်းစုများ',
 			'GT' => 'ဂွါတီမာလာ',
 			'GU' => 'ဂူအမ်',
 			'GW' => 'ဂီနီ-ဘီစော',
 			'GY' => 'ဂိုင်ယာနာ',
 			'HK' => 'ဟောင်ကောင် (တရုတ်ပြည်)',
 			'HK@alt=short' => 'ဟောင်ကောင်',
 			'HM' => 'ဟတ်ကျွန်းနှင့်မက်ဒေါနယ်ကျွန်းစု',
 			'HN' => 'ဟွန်ဒူးရပ်စ်',
 			'HR' => 'ခရိုအေးရှား',
 			'HT' => 'ဟေတီ',
 			'HU' => 'ဟန်ဂေရီ',
 			'IC' => 'ကနေရီ ကျွန်းစု',
 			'ID' => 'အင်ဒိုနီးရှား',
 			'IE' => 'အိုင်ယာလန်',
 			'IL' => 'အစ္စရေး',
 			'IM' => 'မန်ကျွန်း',
 			'IN' => 'အိန္ဒိယ',
 			'IO' => 'ဗြိတိသျှပိုင် အိန္ဒိယသမုဒ္ဒရာကျွန်းများ',
 			'IQ' => 'အီရတ်',
 			'IR' => 'အီရန်',
 			'IS' => 'အိုက်စလန်',
 			'IT' => 'အီတလီ',
 			'JE' => 'ဂျာစီ',
 			'JM' => 'ဂျမေကာ',
 			'JO' => 'ဂျော်ဒန်',
 			'JP' => 'ဂျပန်',
 			'KE' => 'ကင်ညာ',
 			'KG' => 'ကာဂျစ္စတန်',
 			'KH' => 'ကမ္ဘောဒီးယား',
 			'KI' => 'ခီရီဘာတီ',
 			'KM' => 'ကိုမိုရိုစ်',
 			'KN' => 'စိန့်ကစ်နှင့်နီဗီစ်',
 			'KP' => 'မြောက်ကိုရီးယား',
 			'KR' => 'တောင်ကိုရီးယား',
 			'KW' => 'ကူဝိတ်',
 			'KY' => 'ကေမန် ကျွန်းစု',
 			'KZ' => 'ကာဇက်စတန်',
 			'LA' => 'လာအို',
 			'LB' => 'လက်ဘနွန်',
 			'LC' => 'စိန့်လူစီယာ',
 			'LI' => 'လစ်တန်စတိန်း',
 			'LK' => 'သီရိလင်္ကာ',
 			'LR' => 'လိုက်ဘေးရီးယား',
 			'LS' => 'လီဆိုသို',
 			'LT' => 'လစ်သူဝေးနီးယား',
 			'LU' => 'လူဇင်ဘတ်',
 			'LV' => 'လတ်ဗီးယား',
 			'LY' => 'လစ်ဗျား',
 			'MA' => 'မော်ရိုကို',
 			'MC' => 'မိုနာကို',
 			'MD' => 'မောလ်ဒိုဗာ',
 			'ME' => 'မွန်တီနိဂရိုး',
 			'MF' => 'စိန့်မာတင်',
 			'MG' => 'မဒါဂတ်စကား',
 			'MH' => 'မာရှယ် ကျွန်းစု',
 			'MK' => 'မြောက် မက်ဆီဒိုးနီးယား',
 			'ML' => 'မာလီ',
 			'MM' => 'မြန်မာ',
 			'MN' => 'မွန်ဂိုးလီးယား',
 			'MO' => 'မကာအို (တရုတ်ပြည်)',
 			'MO@alt=short' => 'မကာအို',
 			'MP' => 'မြောက်ပိုင်းမာရီအာနာကျွန်းစု',
 			'MQ' => 'မာတီနိခ်',
 			'MR' => 'မော်ရီတေးနီးယား',
 			'MS' => 'မောင့်စဲရက်',
 			'MT' => 'မောလ်တာ',
 			'MU' => 'မောရစ်ရှ',
 			'MV' => 'မော်လ်ဒိုက်',
 			'MW' => 'မာလာဝီ',
 			'MX' => 'မက်ကဆီကို',
 			'MY' => 'မလေးရှား',
 			'MZ' => 'မိုဇမ်ဘစ်',
 			'NA' => 'နမီးဘီးယား',
 			'NC' => 'နယူး ကယ်လီဒိုနီးယား',
 			'NE' => 'နိုင်ဂျာ',
 			'NF' => 'နောဖုတ်ကျွန်း',
 			'NG' => 'နိုင်ဂျီးရီးယား',
 			'NI' => 'နီကာရာဂွါ',
 			'NL' => 'နယ်သာလန်',
 			'NO' => 'နော်ဝေ',
 			'NP' => 'နီပေါ',
 			'NR' => 'နော်ရူး',
 			'NU' => 'နီဥူအေ',
 			'NZ' => 'နယူးဇီလန်',
 			'NZ@alt=variant' => 'အေအိုတေးအာရိုအာ နယူးဇီလန်',
 			'OM' => 'အိုမန်',
 			'PA' => 'ပနားမား',
 			'PE' => 'ပီရူး',
 			'PF' => 'ပြင်သစ် ပေါ်လီနီးရှား',
 			'PG' => 'ပါပူအာ နယူးဂီနီ',
 			'PH' => 'ဖိလစ်ပိုင်',
 			'PK' => 'ပါကစ္စတန်',
 			'PL' => 'ပိုလန်',
 			'PM' => 'စိန့်ပီအဲရ်နှင့် မီကွီလွန်',
 			'PN' => 'ပစ်တ်ကိန်းကျွန်းစု',
 			'PR' => 'ပေါ်တိုရီကို',
 			'PS' => 'ပါလက်စတိုင်း ပိုင်နက်',
 			'PS@alt=short' => 'ပါလက်စတိုင်း',
 			'PT' => 'ပေါ်တူဂီ',
 			'PW' => 'ပလာအို',
 			'PY' => 'ပါရာဂွေး',
 			'QA' => 'ကာတာ',
 			'QO' => 'သမုဒ္ဒရာ အပြင်ဘက်ရှိ ကျွန်းနိုင်ငံများ',
 			'RE' => 'ရီယူနီယန်',
 			'RO' => 'ရိုမေးနီးယား',
 			'RS' => 'ဆားဘီးယား',
 			'RU' => 'ရုရှား',
 			'RW' => 'ရဝန်ဒါ',
 			'SA' => 'ဆော်ဒီအာရေးဘီးယား',
 			'SB' => 'ဆော်လမွန်ကျွန်းစု',
 			'SC' => 'ဆေးရှဲ',
 			'SD' => 'ဆူဒန်',
 			'SE' => 'ဆွီဒင်',
 			'SG' => 'စင်္ကာပူ',
 			'SH' => 'စိန့်ဟယ်လယ်နာ',
 			'SI' => 'ဆလိုဗေးနီးယား',
 			'SJ' => 'စဗိုလ်ဘတ်နှင့်ဂျန်မေရန်',
 			'SK' => 'ဆလိုဗက်ကီးယား',
 			'SL' => 'ဆီယာရာ လီယွန်း',
 			'SM' => 'ဆန်မာရီနို',
 			'SN' => 'ဆီနီဂေါ',
 			'SO' => 'ဆိုမာလီယာ',
 			'SR' => 'ဆူရာနမ်',
 			'SS' => 'တောင် ဆူဒန်',
 			'ST' => 'ဆောင်တူမေးနှင့် ပရင်စီပီ',
 			'SV' => 'အယ်လ်ဆာဗေးဒိုး',
 			'SX' => 'စင့်မာတင်',
 			'SY' => 'ဆီးရီးယား',
 			'SZ' => 'ဆွာဇီလန်',
 			'TA' => 'ထရစ္စတန် ဒါ ကွန်ဟာ',
 			'TC' => 'တခ်စ်နှင့်ကာအီကိုစ်ကျွန်းစု',
 			'TD' => 'ချဒ်',
 			'TF' => 'ပြင်သစ် တောင်ပိုင်း ပိုင်နက်များ',
 			'TG' => 'တိုဂို',
 			'TH' => 'ထိုင်း',
 			'TJ' => 'တာဂျီကစ္စတန်',
 			'TK' => 'တိုကလောင်',
 			'TL' => 'အရှေ့တီမော',
 			'TM' => 'တာ့ခ်မင်နစ္စတန်',
 			'TN' => 'တူနီးရှား',
 			'TO' => 'တွန်ဂါ',
 			'TR' => 'တူရကီ',
 			'TR@alt=variant' => 'တူရကီယဲ',
 			'TT' => 'ထရီနီဒတ်နှင့် တိုဘက်ဂို',
 			'TV' => 'တူဗားလူ',
 			'TW' => 'ထိုင်ဝမ်',
 			'TZ' => 'တန်ဇန်းနီးယား',
 			'UA' => 'ယူကရိန်း',
 			'UG' => 'ယူဂန်းဒါး',
 			'UM' => 'ယူနိုက်တက်စတိတ် ကျွန်းနိုင်ငံများ',
 			'UN' => 'ကုလသမဂ္ဂ',
 			'US' => 'အမေရိကန် ပြည်ထောင်စု',
 			'US@alt=short' => 'ယူအက်စ်',
 			'UY' => 'ဥရုဂွေး',
 			'UZ' => 'ဥဇဘက်ကစ္စတန်',
 			'VA' => 'ဗာတီကန်စီးတီး',
 			'VC' => 'စိန့်ဗင်းဆင့်နှင့် ဂရိနေဒိုင်',
 			'VE' => 'ဗင်နီဇွဲလား',
 			'VG' => 'ဗြိတိသျှ ဗာဂျင်း ကျွန်းစု',
 			'VI' => 'ယူအက်စ် ဗာဂျင်း ကျွန်းစု',
 			'VN' => 'ဗီယက်နမ်',
 			'VU' => 'ဗနွားတူ',
 			'WF' => 'ဝေါလစ်နှင့် ဖူကျူးနား',
 			'WS' => 'ဆမိုးအား',
 			'XA' => 'နိုင်ငံခြားသံ',
 			'XB' => 'စာပြောင်းပြန်',
 			'XK' => 'ကိုဆိုဗို',
 			'YE' => 'ယီမင်',
 			'YT' => 'မေယော့',
 			'ZA' => 'တောင်အာဖရိက',
 			'ZM' => 'ဇမ်ဘီယာ',
 			'ZW' => 'ဇင်ဘာဘွေ',
 			'ZZ' => 'မသိ (သို့) မရှိသော ဒေသ',

		}
	},
);

has 'display_name_variant' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'1901' => 'ရှေးရိုးစဉ်လာ ဂျာမန် ရေးထုံး',
 			'1996' => '၁၉၉၆ ဂျာမန် ရေးထုံး',
 			'1606NICT' => 'အလယ်ပိုင်းနောက်ကျသောပြင်သစ်မှ ၁၆၀၆',
 			'1694ACAD' => '၁၆၉၄ACAD',
 			'AREVELA' => 'အရှေ့ပိုင်းအာမေးနီးယန်း',
 			'BAKU1926' => 'ပေါင်းစပ်ထားသော တူရကီ လက်တင်စကားလုံး',
 			'FONIPA' => 'IPA အသံထွက်',
 			'FONUPA' => 'UPA အသံထွက်',
 			'POSIX' => 'ကွန်ပျူတာ',
 			'REVISED' => 'ပြန်လည်စီစစ်ထားသော ရေးထုံး',
 			'SCOTLAND' => 'စကော့ စံ အင်္ဂလိပ်',

		}
	},
);

has 'display_name_key' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'calendar' => 'ပြက္ခဒိန်',
 			'cf' => 'ငွေရေတွက်ပုံစနစ်',
 			'collation' => 'အစဉ်လိုက်စီရန်',
 			'currency' => 'ငွေကြေး',
 			'hc' => 'နာရီစက်ဝန်း (၁၂ နှင့် ၂၄)',
 			'lb' => 'စာပိုဒ်ခွဲပုံစံ',
 			'ms' => 'တိုင်းတာရေးစနစ်',
 			'numbers' => 'ကိန်းဂဏန်း',

		}
	},
);

has 'display_name_type' => (
	is			=> 'ro',
	isa			=> HashRef[HashRef[Str]],
	init_arg	=> undef,
	default		=> sub {
		{
			'calendar' => {
 				'buddhist' => q{ဗုဒ္ဓ ပြက္ခဒိန်},
 				'chinese' => q{တရုတ် ပြက္ခဒိန်},
 				'coptic' => q{ကို့ပ်တစ် ပြက္ခဒိန်},
 				'dangi' => q{ဒန်းဂိ ပြက္ခဒိန်},
 				'ethiopic' => q{အီသီယိုးပီးယား ပြက္ခဒိန်},
 				'ethiopic-amete-alem' => q{အီသီယိုပစ်ခ် အာမဲတဲ အာလင်မ် ပြက္ခဒိန်},
 				'gregorian' => q{နိုင်ငံတကာသုံး ပြက္ခဒိန်},
 				'hebrew' => q{ဟီဘရူး ပြက္ခဒိန်},
 				'indian' => q{အိန္ဒြိယ အမျိုးသား ပြက္ခဒိန်},
 				'islamic' => q{အစ္စလာမ် ပြက္ခဒိန်},
 				'islamic-civil' => q{အစ္စလာမ်မစ် ပြက္ခဒိန်},
 				'islamic-umalqura' => q{အယ်လ်ကူရာ အစ္စလာမ်မစ် ပြက္ခဒိန်},
 				'iso8601' => q{ISO-8601 ပြက္ခဒိန်},
 				'japanese' => q{ဂျပန် ပြက္ခဒိန်},
 				'persian' => q{ပါရှား ပြက္ခဒိန်},
 				'roc' => q{မင်ဂုအို ပြက္ခဒိန်},
 			},
 			'cf' => {
 				'account' => q{စာရင်းကိုင်သုံး ငွေရေတွက်ပုံစနစ်},
 				'standard' => q{ပုံမှန် ငွေရေတွက်ပုံစနစ်},
 			},
 			'collation' => {
 				'ducet' => q{အစဉ်လိုက်စီထားသော ယူနီကုတ်},
 				'phonebook' => q{ဖုန်းစာအုပ် အစီအစဉ်},
 				'search' => q{ယေဘုယျရှာခြင်း},
 				'standard' => q{ပုံမှန်စီထားသော},
 			},
 			'hc' => {
 				'h11' => q{၁၂ နာရီ စနစ် (၀–၁၁)},
 				'h12' => q{၁၂ နာရီစနစ် (၁–၁၂)},
 				'h23' => q{၂၄ နာရီ စနစ် (၀–၂၃)},
 				'h24' => q{၂၄ နာရီ စနစ်(၁–၂၄)},
 			},
 			'lb' => {
 				'loose' => q{ကန့်သတ်မထားသော စာပိုဒ်ခွဲပုံစံ},
 				'normal' => q{ပုံမှန်စာပိုဒ်ခွဲပုံစံ},
 				'strict' => q{ကန့်သတ်ထားသော စာပိုဒ်ခွဲပုံစံ},
 			},
 			'ms' => {
 				'metric' => q{မက်ထရစ်စနစ်},
 				'uksystem' => q{ဗြိတိသျှတိုင်းတာစနစ်},
 				'ussystem' => q{အမေရိကန်တိုင်းတာစနစ်},
 			},
 			'numbers' => {
 				'arab' => q{အာရပ် ဂဏန်းခြေ},
 				'arabext' => q{တိုးချဲ့အာရပ် ဂဏန်းခြေ},
 				'armn' => q{အာမေးနီးယား ဂဏန်းခြေ},
 				'armnlow' => q{အာမေးနီးယား ဂဏန်းခြေ စာလုံးသေး},
 				'beng' => q{ဘင်္ဂါလီ ဂဏန်းခြေ},
 				'cakm' => q{ချာ့ခ်မာ ဂဏန်းခြေ},
 				'deva' => q{ဒီဗာနာဂရီ ဂဏန်းခြေ},
 				'ethi' => q{အီသီယိုပီးယား ဂဏန်းခြေ},
 				'fullwide' => q{ဗြက်ပြည့် ဂဏန်းခြေ},
 				'geor' => q{နိုင်ငံတကာသုံးဂဏန်းခြေ},
 				'grek' => q{ဂရိ ဂဏန်းခြေ},
 				'greklow' => q{ဂရိ ဂဏန်းခြေ စာလုံးသေး},
 				'gujr' => q{ဂုဂျာရတီ ဂဏန်းခြေ},
 				'guru' => q{ဂူမူခီ ဂဏန်းခြေ},
 				'hanidec' => q{တရုတ် ဆယ်လီစနစ် ဂဏန်းခြေ},
 				'hans' => q{ရိုးရှင်း တရုတ် ဂဏန်းခြေ},
 				'hansfin' => q{ရိုးရှင်း တရုတ် ဘဏ္ဍာရေးသုံး ဂဏန်းခြေ},
 				'hant' => q{ရိုးရာ တရုတ် ဂဏန်းခြေ},
 				'hantfin' => q{ရိုးရာ တရုတ် ဘဏ္ဍာရေးသုံး ဂဏန်းခြေ},
 				'hebr' => q{ဟီဘရူး ဂဏန်းခြေ},
 				'java' => q{ဂျာဗား ဂဏန်းခြေ},
 				'jpan' => q{ဂျပန် ဂဏန်းခြေ},
 				'jpanfin' => q{ဂျပန် ဘဏ္ဍာရေးသုံး ဂဏန်းခြေ},
 				'khmr' => q{ခမာ ဂဏန်းခြေ},
 				'knda' => q{ခန္နဒါ ဂဏန်းခြေ},
 				'laoo' => q{လာအို ဂဏန်းခြေ},
 				'latn' => q{အနောက်တိုင်း ဂဏန်းခြေ},
 				'mlym' => q{မလေယာလမ် ဂဏန်းခြေ},
 				'mtei' => q{မီတဲမာယစ်ခ် ဂဏန်းခြေ},
 				'mymr' => q{မြန်မာ ဂဏန်းခြေ},
 				'mymrshan' => q{ရှမ်း ဂဏန်းခြေ},
 				'olck' => q{အိုလ်ချီကီ ဂဏန်းခြေ},
 				'orya' => q{ဩရီရာ ဂဏန်းခြေ},
 				'roman' => q{ရောမ ဂဏန်းခြေ},
 				'romanlow' => q{ရောမ ဂဏန်းခြေ စာလုံးသေး},
 				'taml' => q{ရိုးရာ တမီးလ် ဂဏန်းခြေ},
 				'tamldec' => q{တမီးလ် ဂဏန်းခြေ},
 				'telu' => q{တလုဂု ဂဏန်းခြေ},
 				'thai' => q{ထိုင်း ဂဏန်းခြေ},
 				'tibt' => q{တိဘက် ဂဏန်းခြေ},
 				'vaii' => q{ဗိုင်း ဂဏန်းခြေ},
 			},

		}
	},
);

has 'display_name_measurement_system' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'metric' => q{မက်ထရစ်စနစ်},
 			'UK' => q{ဗြိတိန်စနစ်},
 			'US' => q{အမေရိကန်စနစ်},

		}
	},
);

has 'display_name_code_patterns' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'language' => 'ဘာသာစကား - {0}',
 			'script' => 'စာ - {0}',
 			'region' => 'နယ်ပယ်ဒေသ - {0}',

		}
	},
);

has 'characters' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> $^V ge v5.18.0
	? eval <<'EOT'
	sub {
		no warnings 'experimental::regex_sets';
		return {
			auxiliary => qr{[၀႐ ၁႑ ၂႒ ၃႓ ၄႔ ၅႕ ၆႖ ၇႗ ၈႘ ၉႙ ၵ ၚ ၽ ၾ ၐ ၑ ၥ ဨ ဢ ၒ ၓ ၔ ၕ ဳ ၖ ၗ ၘ ၙ ႆ ဴ ၢ ၤ ႈ ႊ ႏ]},
			index => ['က', 'ခ', 'ဂ', 'ဃ', 'င', 'စ', 'ဆ', 'ဇ', 'ဈ', 'ဉ', 'ည', 'ဋ', 'ဌ', 'ဍ', 'ဎ', 'ဏ', 'တ', 'ထ', 'ဒ', 'ဓ', 'န', 'ပ', 'ဖ', 'ဗ', 'ဘ', 'မ', 'ယ', 'ရ', 'လ', 'ဝ', 'သ', 'ဟ', 'ဠ', 'အ'],
			main => qr{[က ခ ဂ ဃ င စ ဆ ဇ ဈ ဉ ည ဋ ဌ ဍ ဎ ဏ တ ထ ဒ ဓ န ပ ဖ ဗ ဘ မ ယ ရ လ ဝ သ ဟ ဠ အ ဣ၏ ဤ ဥ ဦ ဧ ဩ ဪ ာါ ိ ီ ု ူ ေ ဲ ံ ဿ ျ ြ ွ ှ ္ ် ့ း]},
			numbers => qr{[\- ‑ , . % ‰ + 0၀ 1၁ 2၂ 3၃ 4၄ 5၅ 6၆ 7၇ 8၈ 9၉]},
			punctuation => qr{[\- ‐‑ – — … ၊ ။ ‘’ “” ( ) \[ \] \{ \} @ * / #]},
		};
	},
EOT
: sub {
		return { index => ['က', 'ခ', 'ဂ', 'ဃ', 'င', 'စ', 'ဆ', 'ဇ', 'ဈ', 'ဉ', 'ည', 'ဋ', 'ဌ', 'ဍ', 'ဎ', 'ဏ', 'တ', 'ထ', 'ဒ', 'ဓ', 'န', 'ပ', 'ဖ', 'ဗ', 'ဘ', 'မ', 'ယ', 'ရ', 'လ', 'ဝ', 'သ', 'ဟ', 'ဠ', 'အ'], };
},
);


has 'units' => (
	is			=> 'ro',
	isa			=> HashRef[HashRef[HashRef[Str]]],
	init_arg	=> undef,
	default		=> sub { {
				'long' => {
					# Long Unit Identifier
					'' => {
						'name' => q(အရပ် လေးမျက်နှာ),
					},
					# Core Unit Identifier
					'' => {
						'name' => q(အရပ် လေးမျက်နှာ),
					},
					# Long Unit Identifier
					'1024p1' => {
						'1' => q(ကီဘီ{0}),
					},
					# Core Unit Identifier
					'1024p1' => {
						'1' => q(ကီဘီ{0}),
					},
					# Long Unit Identifier
					'1024p2' => {
						'1' => q(မက်ဘီ{0}),
					},
					# Core Unit Identifier
					'1024p2' => {
						'1' => q(မက်ဘီ{0}),
					},
					# Long Unit Identifier
					'1024p3' => {
						'1' => q(ဂီဘီ{0}),
					},
					# Core Unit Identifier
					'1024p3' => {
						'1' => q(ဂီဘီ{0}),
					},
					# Long Unit Identifier
					'1024p4' => {
						'1' => q(တယ်ဘီ{0}),
					},
					# Core Unit Identifier
					'1024p4' => {
						'1' => q(တယ်ဘီ{0}),
					},
					# Long Unit Identifier
					'1024p5' => {
						'1' => q(ပယ်ဘီ{0}),
					},
					# Core Unit Identifier
					'1024p5' => {
						'1' => q(ပယ်ဘီ{0}),
					},
					# Long Unit Identifier
					'1024p6' => {
						'1' => q(အိတ်ဇ်ဘီ{0}),
					},
					# Core Unit Identifier
					'1024p6' => {
						'1' => q(အိတ်ဇ်ဘီ{0}),
					},
					# Long Unit Identifier
					'1024p7' => {
						'1' => q(ဇက်ဘီ{0}),
					},
					# Core Unit Identifier
					'1024p7' => {
						'1' => q(ဇက်ဘီ{0}),
					},
					# Long Unit Identifier
					'1024p8' => {
						'1' => q(ယိုဘီ{0}),
					},
					# Core Unit Identifier
					'1024p8' => {
						'1' => q(ယိုဘီ{0}),
					},
					# Long Unit Identifier
					'10p-1' => {
						'1' => q(ဒက်စီ{0}),
					},
					# Core Unit Identifier
					'1' => {
						'1' => q(ဒက်စီ{0}),
					},
					# Long Unit Identifier
					'10p-12' => {
						'1' => q(ပီကို{0}),
					},
					# Core Unit Identifier
					'12' => {
						'1' => q(ပီကို{0}),
					},
					# Long Unit Identifier
					'10p-15' => {
						'1' => q(ဖမ်တို{0}),
					},
					# Core Unit Identifier
					'15' => {
						'1' => q(ဖမ်တို{0}),
					},
					# Long Unit Identifier
					'10p-18' => {
						'1' => q(အက်တို{0}),
					},
					# Core Unit Identifier
					'18' => {
						'1' => q(အက်တို{0}),
					},
					# Long Unit Identifier
					'10p-2' => {
						'1' => q(စင်တီ{0}),
					},
					# Core Unit Identifier
					'2' => {
						'1' => q(စင်တီ{0}),
					},
					# Long Unit Identifier
					'10p-21' => {
						'1' => q(ဇက်ပ်တို{0}),
					},
					# Core Unit Identifier
					'21' => {
						'1' => q(ဇက်ပ်တို{0}),
					},
					# Long Unit Identifier
					'10p-24' => {
						'1' => q(ယောက်တို{0}),
					},
					# Core Unit Identifier
					'24' => {
						'1' => q(ယောက်တို{0}),
					},
					# Long Unit Identifier
					'10p-27' => {
						'1' => q(ရွန်တို{0}),
					},
					# Core Unit Identifier
					'27' => {
						'1' => q(ရွန်တို{0}),
					},
					# Long Unit Identifier
					'10p-3' => {
						'1' => q(မီလီ{0}),
					},
					# Core Unit Identifier
					'3' => {
						'1' => q(မီလီ{0}),
					},
					# Long Unit Identifier
					'10p-30' => {
						'1' => q(ကွီတို{0}),
					},
					# Core Unit Identifier
					'30' => {
						'1' => q(ကွီတို{0}),
					},
					# Long Unit Identifier
					'10p-6' => {
						'1' => q(မိုက်ခရို{0}),
					},
					# Core Unit Identifier
					'6' => {
						'1' => q(မိုက်ခရို{0}),
					},
					# Long Unit Identifier
					'10p-9' => {
						'1' => q(နာနို{0}),
					},
					# Core Unit Identifier
					'9' => {
						'1' => q(နာနို{0}),
					},
					# Long Unit Identifier
					'10p1' => {
						'1' => q(ဒက်ကာ{0}),
					},
					# Core Unit Identifier
					'10p1' => {
						'1' => q(ဒက်ကာ{0}),
					},
					# Long Unit Identifier
					'10p12' => {
						'1' => q(တယ်ရာ{0}),
					},
					# Core Unit Identifier
					'10p12' => {
						'1' => q(တယ်ရာ{0}),
					},
					# Long Unit Identifier
					'10p15' => {
						'1' => q(ပက်တာ{0}),
					},
					# Core Unit Identifier
					'10p15' => {
						'1' => q(ပက်တာ{0}),
					},
					# Long Unit Identifier
					'10p18' => {
						'1' => q(အိတ်စ်ဆာ{0}),
					},
					# Core Unit Identifier
					'10p18' => {
						'1' => q(အိတ်စ်ဆာ{0}),
					},
					# Long Unit Identifier
					'10p2' => {
						'1' => q(ဟက်တို{0}),
					},
					# Core Unit Identifier
					'10p2' => {
						'1' => q(ဟက်တို{0}),
					},
					# Long Unit Identifier
					'10p21' => {
						'1' => q(ဇက်တာ{0}),
					},
					# Core Unit Identifier
					'10p21' => {
						'1' => q(ဇက်တာ{0}),
					},
					# Long Unit Identifier
					'10p24' => {
						'1' => q(ယိုဒါ{0}),
					},
					# Core Unit Identifier
					'10p24' => {
						'1' => q(ယိုဒါ{0}),
					},
					# Long Unit Identifier
					'10p27' => {
						'1' => q(ရွန်နာ{0}),
					},
					# Core Unit Identifier
					'10p27' => {
						'1' => q(ရွန်နာ{0}),
					},
					# Long Unit Identifier
					'10p3' => {
						'1' => q(ကီလို{0}),
					},
					# Core Unit Identifier
					'10p3' => {
						'1' => q(ကီလို{0}),
					},
					# Long Unit Identifier
					'10p30' => {
						'1' => q(ကွက်တာ{0}),
					},
					# Core Unit Identifier
					'10p30' => {
						'1' => q(ကွက်တာ{0}),
					},
					# Long Unit Identifier
					'10p6' => {
						'1' => q(မီဂါ{0}),
					},
					# Core Unit Identifier
					'10p6' => {
						'1' => q(မီဂါ{0}),
					},
					# Long Unit Identifier
					'10p9' => {
						'1' => q(ဂီဂါ{0}),
					},
					# Core Unit Identifier
					'10p9' => {
						'1' => q(ဂီဂါ{0}),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'other' => q({0} ဆွဲငင်အား),
					},
					# Core Unit Identifier
					'g-force' => {
						'other' => q({0} ဆွဲငင်အား),
					},
					# Long Unit Identifier
					'acceleration-meter-per-square-second' => {
						'other' => q({0} မီတာ/စက္ကန့်နှစ်ထပ်ကိန်း),
					},
					# Core Unit Identifier
					'meter-per-square-second' => {
						'other' => q({0} မီတာ/စက္ကန့်နှစ်ထပ်ကိန်း),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'other' => q({0} မိနစ်),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'other' => q({0} မိနစ်),
					},
					# Long Unit Identifier
					'angle-arc-second' => {
						'other' => q({0} စက္ကန့်),
					},
					# Core Unit Identifier
					'arc-second' => {
						'other' => q({0} စက္ကန့်),
					},
					# Long Unit Identifier
					'angle-degree' => {
						'other' => q({0} ဒီဂရီ),
					},
					# Core Unit Identifier
					'degree' => {
						'other' => q({0} ဒီဂရီ),
					},
					# Long Unit Identifier
					'angle-radian' => {
						'other' => q({0} ရေဒီယဲန်း),
					},
					# Core Unit Identifier
					'radian' => {
						'other' => q({0} ရေဒီယဲန်း),
					},
					# Long Unit Identifier
					'angle-revolution' => {
						'name' => q(လည်ပတ်ခြင်း),
						'other' => q({0} လည်ပတ်ခြင်း),
					},
					# Core Unit Identifier
					'revolution' => {
						'name' => q(လည်ပတ်ခြင်း),
						'other' => q({0} လည်ပတ်ခြင်း),
					},
					# Long Unit Identifier
					'area-acre' => {
						'other' => q({0} ဧက),
					},
					# Core Unit Identifier
					'acre' => {
						'other' => q({0} ဧက),
					},
					# Long Unit Identifier
					'area-hectare' => {
						'other' => q({0} ဟက်တာ),
					},
					# Core Unit Identifier
					'hectare' => {
						'other' => q({0} ဟက်တာ),
					},
					# Long Unit Identifier
					'area-square-centimeter' => {
						'other' => q({0} စတုရန်းစင်တီမီတာ),
						'per' => q(တစ်စတုရန်းစင်တီမီတာလျှင် {0}),
					},
					# Core Unit Identifier
					'square-centimeter' => {
						'other' => q({0} စတုရန်းစင်တီမီတာ),
						'per' => q(တစ်စတုရန်းစင်တီမီတာလျှင် {0}),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'other' => q({0} စတုရန်းပေ),
					},
					# Core Unit Identifier
					'square-foot' => {
						'other' => q({0} စတုရန်းပေ),
					},
					# Long Unit Identifier
					'area-square-inch' => {
						'other' => q({0} စတုရန်းလက်မ),
						'per' => q(တစ်စတုရန်းလက်မလျှင် {0}),
					},
					# Core Unit Identifier
					'square-inch' => {
						'other' => q({0} စတုရန်းလက်မ),
						'per' => q(တစ်စတုရန်းလက်မလျှင် {0}),
					},
					# Long Unit Identifier
					'area-square-kilometer' => {
						'other' => q({0} စတုရန်းကီလိုမီတာ),
						'per' => q(တစ်စတုရန်းကီလိုမီတာလျှင် {0}),
					},
					# Core Unit Identifier
					'square-kilometer' => {
						'other' => q({0} စတုရန်းကီလိုမီတာ),
						'per' => q(တစ်စတုရန်းကီလိုမီတာလျှင် {0}),
					},
					# Long Unit Identifier
					'area-square-meter' => {
						'other' => q({0} စတုရန်းမီတာ),
						'per' => q(တစ်စတုရန်းမီတာလျှင် {0}),
					},
					# Core Unit Identifier
					'square-meter' => {
						'other' => q({0} စတုရန်းမီတာ),
						'per' => q(တစ်စတုရန်းမီတာလျှင် {0}),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'other' => q({0} စတုရန်းမိုင်),
						'per' => q(တစ်စတုရန်းမိုင်လျှင် {0}),
					},
					# Core Unit Identifier
					'square-mile' => {
						'other' => q({0} စတုရန်းမိုင်),
						'per' => q(တစ်စတုရန်းမိုင်လျှင် {0}),
					},
					# Long Unit Identifier
					'area-square-yard' => {
						'other' => q({0} စတုရန်းကိုက်),
					},
					# Core Unit Identifier
					'square-yard' => {
						'other' => q({0} စတုရန်းကိုက်),
					},
					# Long Unit Identifier
					'concentr-karat' => {
						'other' => q({0} ကာရက်),
					},
					# Core Unit Identifier
					'karat' => {
						'other' => q({0} ကာရက်),
					},
					# Long Unit Identifier
					'concentr-milligram-ofglucose-per-deciliter' => {
						'name' => q(တစ်ဒက်စီလီတာရှိ မီလီဂရမ်),
						'other' => q(တစ်ဒက်စီလီတာရှိ {0} မီလီဂရမ်),
					},
					# Core Unit Identifier
					'milligram-ofglucose-per-deciliter' => {
						'name' => q(တစ်ဒက်စီလီတာရှိ မီလီဂရမ်),
						'other' => q(တစ်ဒက်စီလီတာရှိ {0} မီလီဂရမ်),
					},
					# Long Unit Identifier
					'concentr-millimole-per-liter' => {
						'name' => q(တစ်လီတာရှိ မီလီမိုးလ်),
						'other' => q(တစ်လီတာရှိ {0} မီလီမိုးလ်),
					},
					# Core Unit Identifier
					'millimole-per-liter' => {
						'name' => q(တစ်လီတာရှိ မီလီမိုးလ်),
						'other' => q(တစ်လီတာရှိ {0} မီလီမိုးလ်),
					},
					# Long Unit Identifier
					'concentr-percent' => {
						'name' => q(ရာခိုင်နှုန်း),
						'other' => q({0} ရာခိုင်နှုန်း),
					},
					# Core Unit Identifier
					'percent' => {
						'name' => q(ရာခိုင်နှုန်း),
						'other' => q({0} ရာခိုင်နှုန်း),
					},
					# Long Unit Identifier
					'concentr-permille' => {
						'name' => q(ထောင်လီစိတ်),
						'other' => q({0} ထောင်လီစိတ်),
					},
					# Core Unit Identifier
					'permille' => {
						'name' => q(ထောင်လီစိတ်),
						'other' => q({0} ထောင်လီစိတ်),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'other' => q(တစ်သန်းပုံ {0} ပုံ),
					},
					# Core Unit Identifier
					'permillion' => {
						'other' => q(တစ်သန်းပုံ {0} ပုံ),
					},
					# Long Unit Identifier
					'concentr-permyriad' => {
						'other' => q({0} ပါမီရိတ်),
					},
					# Core Unit Identifier
					'permyriad' => {
						'other' => q({0} ပါမီရိတ်),
					},
					# Long Unit Identifier
					'concentr-portion-per-1e9' => {
						'name' => q(သန်းတစ်ထောင်ပုံ တစ်ပုံ),
						'other' => q(သန်းတစ်ထောင်ပုံ {0} ပုံ),
					},
					# Core Unit Identifier
					'portion-per-1e9' => {
						'name' => q(သန်းတစ်ထောင်ပုံ တစ်ပုံ),
						'other' => q(သန်းတစ်ထောင်ပုံ {0} ပုံ),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'other' => q(တစ်ရာကီလိုမီတာရှိ {0} လီတာ),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'other' => q(တစ်ရာကီလိုမီတာရှိ {0} လီတာ),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'name' => q(တစ်ကီလိုမီတာရှိ လီတာ),
						'other' => q(တစ်ကီလိုမီတာရှိ {0} လီတာ),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'name' => q(တစ်ကီလိုမီတာရှိ လီတာ),
						'other' => q(တစ်ကီလိုမီတာရှိ {0} လီတာ),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon' => {
						'name' => q(တစ်ဂါလံ မိုင်နှုန်း),
						'other' => q(တစ်ဂါလံလျှင် {0} မိုင်),
					},
					# Core Unit Identifier
					'mile-per-gallon' => {
						'name' => q(တစ်ဂါလံ မိုင်နှုန်း),
						'other' => q(တစ်ဂါလံလျှင် {0} မိုင်),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'name' => q(ယူကေတစ်ဂါလံ မိုင်နှုန်း),
						'other' => q(ယူကေတစ်ဂါလံလျှင် {0} မိုင်),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'name' => q(ယူကေတစ်ဂါလံ မိုင်နှုန်း),
						'other' => q(ယူကေတစ်ဂါလံလျှင် {0} မိုင်),
					},
					# Long Unit Identifier
					'coordinate' => {
						'east' => q({0} အရှေ့),
						'north' => q({0} မြောက်),
						'south' => q({0} တောင်),
						'west' => q({0} အနောက်),
					},
					# Core Unit Identifier
					'coordinate' => {
						'east' => q({0} အရှေ့),
						'north' => q({0} မြောက်),
						'south' => q({0} တောင်),
						'west' => q({0} အနောက်),
					},
					# Long Unit Identifier
					'digital-bit' => {
						'other' => q({0} ဘစ်),
					},
					# Core Unit Identifier
					'bit' => {
						'other' => q({0} ဘစ်),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'other' => q({0} ဘိုက်),
					},
					# Core Unit Identifier
					'byte' => {
						'other' => q({0} ဘိုက်),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'other' => q({0} ဂစ်ဂါဘစ်),
					},
					# Core Unit Identifier
					'gigabit' => {
						'other' => q({0} ဂစ်ဂါဘစ်),
					},
					# Long Unit Identifier
					'digital-gigabyte' => {
						'other' => q({0} ဂစ်ဂါဘိုက်),
					},
					# Core Unit Identifier
					'gigabyte' => {
						'other' => q({0} ဂစ်ဂါဘိုက်),
					},
					# Long Unit Identifier
					'digital-kilobit' => {
						'other' => q({0} ကီလိုဘစ်),
					},
					# Core Unit Identifier
					'kilobit' => {
						'other' => q({0} ကီလိုဘစ်),
					},
					# Long Unit Identifier
					'digital-kilobyte' => {
						'other' => q({0} ကီလိုဘိုက်),
					},
					# Core Unit Identifier
					'kilobyte' => {
						'other' => q({0} ကီလိုဘိုက်),
					},
					# Long Unit Identifier
					'digital-megabit' => {
						'other' => q({0} မီဂါဘစ်),
					},
					# Core Unit Identifier
					'megabit' => {
						'other' => q({0} မီဂါဘစ်),
					},
					# Long Unit Identifier
					'digital-megabyte' => {
						'other' => q({0} မီဂါဘိုက်),
					},
					# Core Unit Identifier
					'megabyte' => {
						'other' => q({0} မီဂါဘိုက်),
					},
					# Long Unit Identifier
					'digital-petabyte' => {
						'other' => q({0} ပက်တာဘိုက်),
					},
					# Core Unit Identifier
					'petabyte' => {
						'other' => q({0} ပက်တာဘိုက်),
					},
					# Long Unit Identifier
					'digital-terabit' => {
						'other' => q({0} တယ်ရာဘစ်),
					},
					# Core Unit Identifier
					'terabit' => {
						'other' => q({0} တယ်ရာဘစ်),
					},
					# Long Unit Identifier
					'digital-terabyte' => {
						'other' => q({0} တယ်ရာဘိုက်),
					},
					# Core Unit Identifier
					'terabyte' => {
						'other' => q({0} တယ်ရာဘိုက်),
					},
					# Long Unit Identifier
					'duration-century' => {
						'name' => q(ရာစုနှစ်),
						'other' => q({0} ရာစုနှစ်),
					},
					# Core Unit Identifier
					'century' => {
						'name' => q(ရာစုနှစ်),
						'other' => q({0} ရာစုနှစ်),
					},
					# Long Unit Identifier
					'duration-day' => {
						'per' => q(တစ်ရက်လျှင် {0}),
					},
					# Core Unit Identifier
					'day' => {
						'per' => q(တစ်ရက်လျှင် {0}),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'name' => q(ဆယ်စုနှစ်),
						'other' => q({0} ဆယ်စုနှစ်),
					},
					# Core Unit Identifier
					'decade' => {
						'name' => q(ဆယ်စုနှစ်),
						'other' => q({0} ဆယ်စုနှစ်),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'per' => q(တစ်နာရီလျှင် {0}),
					},
					# Core Unit Identifier
					'hour' => {
						'per' => q(တစ်နာရီလျှင် {0}),
					},
					# Long Unit Identifier
					'duration-microsecond' => {
						'other' => q({0} မိုက်ခရိုစက္ကန့်),
					},
					# Core Unit Identifier
					'microsecond' => {
						'other' => q({0} မိုက်ခရိုစက္ကန့်),
					},
					# Long Unit Identifier
					'duration-minute' => {
						'per' => q(တစ်မိနစ်လျှင် {0}),
					},
					# Core Unit Identifier
					'minute' => {
						'per' => q(တစ်မိနစ်လျှင် {0}),
					},
					# Long Unit Identifier
					'duration-month' => {
						'per' => q(တစ်လလျှင် {0}),
					},
					# Core Unit Identifier
					'month' => {
						'per' => q(တစ်လလျှင် {0}),
					},
					# Long Unit Identifier
					'duration-nanosecond' => {
						'other' => q({0} နာနိုစက္ကန့်),
					},
					# Core Unit Identifier
					'nanosecond' => {
						'other' => q({0} နာနိုစက္ကန့်),
					},
					# Long Unit Identifier
					'duration-night' => {
						'name' => q(ည),
						'other' => q({0} ည),
						'per' => q({0}/ည),
					},
					# Core Unit Identifier
					'night' => {
						'name' => q(ည),
						'other' => q({0} ည),
						'per' => q({0}/ည),
					},
					# Long Unit Identifier
					'duration-quarter' => {
						'name' => q(ကွာတား),
						'other' => q({0} ကွာတား),
						'per' => q({0}/ကွာတား),
					},
					# Core Unit Identifier
					'quarter' => {
						'name' => q(ကွာတား),
						'other' => q({0} ကွာတား),
						'per' => q({0}/ကွာတား),
					},
					# Long Unit Identifier
					'duration-second' => {
						'other' => q({0} စက္ကန့်),
						'per' => q(တစ်စက္ကန့်လျှင် {0}),
					},
					# Core Unit Identifier
					'second' => {
						'other' => q({0} စက္ကန့်),
						'per' => q(တစ်စက္ကန့်လျှင် {0}),
					},
					# Long Unit Identifier
					'duration-week' => {
						'per' => q(တစ်ပတ်လျှင် {0}),
					},
					# Core Unit Identifier
					'week' => {
						'per' => q(တစ်ပတ်လျှင် {0}),
					},
					# Long Unit Identifier
					'duration-year' => {
						'per' => q(တစ်နှစ်လျှင် {0}),
					},
					# Core Unit Identifier
					'year' => {
						'per' => q(တစ်နှစ်လျှင် {0}),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'other' => q({0} အမ်ပီယာ),
					},
					# Core Unit Identifier
					'ampere' => {
						'other' => q({0} အမ်ပီယာ),
					},
					# Long Unit Identifier
					'electric-milliampere' => {
						'name' => q(မီလီအမ်ပီယာ),
						'other' => q({0} မီလီအမ်ပီယာ),
					},
					# Core Unit Identifier
					'milliampere' => {
						'name' => q(မီလီအမ်ပီယာ),
						'other' => q({0} မီလီအမ်ပီယာ),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'other' => q({0} အုမ်း),
					},
					# Core Unit Identifier
					'ohm' => {
						'other' => q({0} အုမ်း),
					},
					# Long Unit Identifier
					'electric-volt' => {
						'other' => q({0} ဗို့),
					},
					# Core Unit Identifier
					'volt' => {
						'other' => q({0} ဗို့),
					},
					# Long Unit Identifier
					'energy-british-thermal-unit' => {
						'name' => q(ဗြိတိသျှ သာမယ်လ်ယူနစ်),
						'other' => q({0} ဗြိတိသျှ သာမယ်လ်ယူနစ်),
					},
					# Core Unit Identifier
					'british-thermal-unit' => {
						'name' => q(ဗြိတိသျှ သာမယ်လ်ယူနစ်),
						'other' => q({0} ဗြိတိသျှ သာမယ်လ်ယူနစ်),
					},
					# Long Unit Identifier
					'energy-calorie' => {
						'other' => q({0} ကယ်လိုရီ),
					},
					# Core Unit Identifier
					'calorie' => {
						'other' => q({0} ကယ်လိုရီ),
					},
					# Long Unit Identifier
					'energy-electronvolt' => {
						'other' => q({0} အီလက်ထရွန်ဗို့),
					},
					# Core Unit Identifier
					'electronvolt' => {
						'other' => q({0} အီလက်ထရွန်ဗို့),
					},
					# Long Unit Identifier
					'energy-foodcalorie' => {
						'other' => q({0} ကယ်လိုရီ),
					},
					# Core Unit Identifier
					'foodcalorie' => {
						'other' => q({0} ကယ်လိုရီ),
					},
					# Long Unit Identifier
					'energy-joule' => {
						'other' => q({0} ဂျူးလ်),
					},
					# Core Unit Identifier
					'joule' => {
						'other' => q({0} ဂျူးလ်),
					},
					# Long Unit Identifier
					'energy-kilocalorie' => {
						'other' => q({0} ကီလိုကယ်လိုရီ),
					},
					# Core Unit Identifier
					'kilocalorie' => {
						'other' => q({0} ကီလိုကယ်လိုရီ),
					},
					# Long Unit Identifier
					'energy-kilojoule' => {
						'other' => q({0} ကီလိုဂျူးလ်),
					},
					# Core Unit Identifier
					'kilojoule' => {
						'other' => q({0} ကီလိုဂျူးလ်),
					},
					# Long Unit Identifier
					'energy-kilowatt-hour' => {
						'other' => q({0} ကီလိုဝပ်-နာရီ),
					},
					# Core Unit Identifier
					'kilowatt-hour' => {
						'other' => q({0} ကီလိုဝပ်-နာရီ),
					},
					# Long Unit Identifier
					'energy-therm-us' => {
						'other' => q({0} ယူအက်စ် သာမယ်လ်),
					},
					# Core Unit Identifier
					'therm-us' => {
						'other' => q({0} ယူအက်စ် သာမယ်လ်),
					},
					# Long Unit Identifier
					'force-newton' => {
						'other' => q({0} နယူတန်),
					},
					# Core Unit Identifier
					'newton' => {
						'other' => q({0} နယူတန်),
					},
					# Long Unit Identifier
					'frequency-gigahertz' => {
						'other' => q({0} ဂီဂါဟတ်ဇ်),
					},
					# Core Unit Identifier
					'gigahertz' => {
						'other' => q({0} ဂီဂါဟတ်ဇ်),
					},
					# Long Unit Identifier
					'frequency-hertz' => {
						'name' => q(ဟတ်ဇ်),
						'other' => q({0} ဟတ်ဇ်),
					},
					# Core Unit Identifier
					'hertz' => {
						'name' => q(ဟတ်ဇ်),
						'other' => q({0} ဟတ်ဇ်),
					},
					# Long Unit Identifier
					'frequency-kilohertz' => {
						'name' => q(ကီလိုဟတ်ဇ်),
						'other' => q({0} ကီလိုဟတ်ဇ်),
					},
					# Core Unit Identifier
					'kilohertz' => {
						'name' => q(ကီလိုဟတ်ဇ်),
						'other' => q({0} ကီလိုဟတ်ဇ်),
					},
					# Long Unit Identifier
					'frequency-megahertz' => {
						'other' => q({0} မီဂါဟတ်ဇ်),
					},
					# Core Unit Identifier
					'megahertz' => {
						'other' => q({0} မီဂါဟတ်ဇ်),
					},
					# Long Unit Identifier
					'graphics-dot' => {
						'other' => q(အစက် {0} စက်),
					},
					# Core Unit Identifier
					'dot' => {
						'other' => q(အစက် {0} စက်),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'name' => q(တစ်စင်တီမီတာပါ အစက်),
						'other' => q(တစ်စင်တီမီတာလျှင် {0} စက်),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'name' => q(တစ်စင်တီမီတာပါ အစက်),
						'other' => q(တစ်စင်တီမီတာလျှင် {0} စက်),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'name' => q(တစ်လက်မပါ အစက်),
						'other' => q(တစ်လက်မလျှင် {0} စက်),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'name' => q(တစ်လက်မပါ အစက်),
						'other' => q(တစ်လက်မလျှင် {0} စက်),
					},
					# Long Unit Identifier
					'graphics-em' => {
						'name' => q(ပုံနှိပ်စာလုံး အရွယ်အစား),
						'other' => q({0} ems),
					},
					# Core Unit Identifier
					'em' => {
						'name' => q(ပုံနှိပ်စာလုံး အရွယ်အစား),
						'other' => q({0} ems),
					},
					# Long Unit Identifier
					'graphics-megapixel' => {
						'other' => q({0} မီဂါပစ်ဆယ်),
					},
					# Core Unit Identifier
					'megapixel' => {
						'other' => q({0} မီဂါပစ်ဆယ်),
					},
					# Long Unit Identifier
					'graphics-pixel' => {
						'other' => q({0} ပစ်ဆယ်),
					},
					# Core Unit Identifier
					'pixel' => {
						'other' => q({0} ပစ်ဆယ်),
					},
					# Long Unit Identifier
					'graphics-pixel-per-centimeter' => {
						'name' => q(တစ်စင်တီမီတာပါ ပစ်ဆယ်),
						'other' => q(တစ်စင်တီမီတာလျှင် {0} ပစ်ဆယ်),
					},
					# Core Unit Identifier
					'pixel-per-centimeter' => {
						'name' => q(တစ်စင်တီမီတာပါ ပစ်ဆယ်),
						'other' => q(တစ်စင်တီမီတာလျှင် {0} ပစ်ဆယ်),
					},
					# Long Unit Identifier
					'graphics-pixel-per-inch' => {
						'name' => q(တစ်လက်မပါ ပစ်ဆယ်),
						'other' => q(တစ်လက်မလျှင် {0} ပစ်ဆယ်),
					},
					# Core Unit Identifier
					'pixel-per-inch' => {
						'name' => q(တစ်လက်မပါ ပစ်ဆယ်),
						'other' => q(တစ်လက်မလျှင် {0} ပစ်ဆယ်),
					},
					# Long Unit Identifier
					'length-astronomical-unit' => {
						'name' => q(နက္ခတဗေဒ ယူနစ်),
						'other' => q({0} နက္ခတဗေဒ ယူနစ်),
					},
					# Core Unit Identifier
					'astronomical-unit' => {
						'name' => q(နက္ခတဗေဒ ယူနစ်),
						'other' => q({0} နက္ခတဗေဒ ယူနစ်),
					},
					# Long Unit Identifier
					'length-centimeter' => {
						'name' => q(စင်တီမီတာ),
						'other' => q({0} စင်တီမီတာ),
						'per' => q(တစ်စင်တီမီလာလျှင် {0}),
					},
					# Core Unit Identifier
					'centimeter' => {
						'name' => q(စင်တီမီတာ),
						'other' => q({0} စင်တီမီတာ),
						'per' => q(တစ်စင်တီမီလာလျှင် {0}),
					},
					# Long Unit Identifier
					'length-decimeter' => {
						'name' => q(ဒက်စီမီတာ),
						'other' => q({0} ဒက်စီမီတာ),
					},
					# Core Unit Identifier
					'decimeter' => {
						'name' => q(ဒက်စီမီတာ),
						'other' => q({0} ဒက်စီမီတာ),
					},
					# Long Unit Identifier
					'length-earth-radius' => {
						'name' => q(ကမ္ဘာ့ အချင်းဝက်),
					},
					# Core Unit Identifier
					'earth-radius' => {
						'name' => q(ကမ္ဘာ့ အချင်းဝက်),
					},
					# Long Unit Identifier
					'length-fathom' => {
						'other' => q({0} ဖန်တမ်),
					},
					# Core Unit Identifier
					'fathom' => {
						'other' => q({0} ဖန်တမ်),
					},
					# Long Unit Identifier
					'length-foot' => {
						'other' => q({0} ပေ),
						'per' => q(တစ်ပေလျှင် {0}),
					},
					# Core Unit Identifier
					'foot' => {
						'other' => q({0} ပေ),
						'per' => q(တစ်ပေလျှင် {0}),
					},
					# Long Unit Identifier
					'length-furlong' => {
						'other' => q({0} ဖာလုံ),
					},
					# Core Unit Identifier
					'furlong' => {
						'other' => q({0} ဖာလုံ),
					},
					# Long Unit Identifier
					'length-inch' => {
						'per' => q(တစ်လက်မလျှင် {0}),
					},
					# Core Unit Identifier
					'inch' => {
						'per' => q(တစ်လက်မလျှင် {0}),
					},
					# Long Unit Identifier
					'length-kilometer' => {
						'name' => q(ကီလိုမီတာ),
						'other' => q({0} ကီလိုမီတာ),
						'per' => q(တစ်ကီလိုမီတာလျှင် {0}),
					},
					# Core Unit Identifier
					'kilometer' => {
						'name' => q(ကီလိုမီတာ),
						'other' => q({0} ကီလိုမီတာ),
						'per' => q(တစ်ကီလိုမီတာလျှင် {0}),
					},
					# Long Unit Identifier
					'length-meter' => {
						'name' => q(မီတာ),
						'other' => q({0} မီတာ),
						'per' => q(တစ်မီတာလျှင် {0}),
					},
					# Core Unit Identifier
					'meter' => {
						'name' => q(မီတာ),
						'other' => q({0} မီတာ),
						'per' => q(တစ်မီတာလျှင် {0}),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'name' => q(မိုက်ခရိုမီတာ),
						'other' => q({0} မိုက်ခရိုမီတာ),
					},
					# Core Unit Identifier
					'micrometer' => {
						'name' => q(မိုက်ခရိုမီတာ),
						'other' => q({0} မိုက်ခရိုမီတာ),
					},
					# Long Unit Identifier
					'length-mile' => {
						'other' => q({0} မိုင်),
					},
					# Core Unit Identifier
					'mile' => {
						'other' => q({0} မိုင်),
					},
					# Long Unit Identifier
					'length-mile-scandinavian' => {
						'name' => q(စကင်ဒီနေဗီးယန်း မိုင်),
						'other' => q({0} စကင်ဒီနေဗီးယန်း မိုင်),
					},
					# Core Unit Identifier
					'mile-scandinavian' => {
						'name' => q(စကင်ဒီနေဗီးယန်း မိုင်),
						'other' => q({0} စကင်ဒီနေဗီးယန်း မိုင်),
					},
					# Long Unit Identifier
					'length-millimeter' => {
						'name' => q(မီလီမီတာ),
						'other' => q({0} မီလီမီတာ),
					},
					# Core Unit Identifier
					'millimeter' => {
						'name' => q(မီလီမီတာ),
						'other' => q({0} မီလီမီတာ),
					},
					# Long Unit Identifier
					'length-nanometer' => {
						'name' => q(နာနိုမီတာ),
						'other' => q({0} နာနိုမီတာ),
					},
					# Core Unit Identifier
					'nanometer' => {
						'name' => q(နာနိုမီတာ),
						'other' => q({0} နာနိုမီတာ),
					},
					# Long Unit Identifier
					'length-nautical-mile' => {
						'name' => q(ရေမိုင်),
						'other' => q({0} ရေမိုင်),
					},
					# Core Unit Identifier
					'nautical-mile' => {
						'name' => q(ရေမိုင်),
						'other' => q({0} ရေမိုင်),
					},
					# Long Unit Identifier
					'length-parsec' => {
						'other' => q({0} ပါစက်ခ်),
					},
					# Core Unit Identifier
					'parsec' => {
						'other' => q({0} ပါစက်ခ်),
					},
					# Long Unit Identifier
					'length-picometer' => {
						'name' => q(ပီကိုမီတာ),
						'other' => q({0} ပီကိုမီတာ),
					},
					# Core Unit Identifier
					'picometer' => {
						'name' => q(ပီကိုမီတာ),
						'other' => q({0} ပီကိုမီတာ),
					},
					# Long Unit Identifier
					'length-point' => {
						'other' => q({0} ပွိုင့်),
					},
					# Core Unit Identifier
					'point' => {
						'other' => q({0} ပွိုင့်),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'other' => q({0} ဆိုလာ ရာဒီ),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'other' => q({0} ဆိုလာ ရာဒီ),
					},
					# Long Unit Identifier
					'light-candela' => {
						'name' => q(ကန်ဒဲလာ),
						'other' => q({0} ကန်ဒဲလာ),
					},
					# Core Unit Identifier
					'candela' => {
						'name' => q(ကန်ဒဲလာ),
						'other' => q({0} ကန်ဒဲလာ),
					},
					# Long Unit Identifier
					'light-lux' => {
						'other' => q({0} လတ်ခ်),
					},
					# Core Unit Identifier
					'lux' => {
						'other' => q({0} လတ်ခ်),
					},
					# Long Unit Identifier
					'light-solar-luminosity' => {
						'name' => q(ဆိုလာ လူမီနိုစီတီးစ်),
						'other' => q({0} ဆိုလာ လူမီနိုစီးတီးစ်),
					},
					# Core Unit Identifier
					'solar-luminosity' => {
						'name' => q(ဆိုလာ လူမီနိုစီတီးစ်),
						'other' => q({0} ဆိုလာ လူမီနိုစီးတီးစ်),
					},
					# Long Unit Identifier
					'mass-carat' => {
						'other' => q({0} ကာရက်),
					},
					# Core Unit Identifier
					'carat' => {
						'other' => q({0} ကာရက်),
					},
					# Long Unit Identifier
					'mass-dalton' => {
						'other' => q({0} ဒဲလ်တန်စ်),
					},
					# Core Unit Identifier
					'dalton' => {
						'other' => q({0} ဒဲလ်တန်စ်),
					},
					# Long Unit Identifier
					'mass-earth-mass' => {
						'other' => q({0} ကမ္ဘာ့ဒြပ်ထု),
					},
					# Core Unit Identifier
					'earth-mass' => {
						'other' => q({0} ကမ္ဘာ့ဒြပ်ထု),
					},
					# Long Unit Identifier
					'mass-gram' => {
						'other' => q({0} ဂရမ်),
						'per' => q(တစ်ဂရမ်လျှင် {0}),
					},
					# Core Unit Identifier
					'gram' => {
						'other' => q({0} ဂရမ်),
						'per' => q(တစ်ဂရမ်လျှင် {0}),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'other' => q({0} ကီလိုဂရမ်),
						'per' => q(တစ်ကီလိုဂရမ်လျှင် {0}),
					},
					# Core Unit Identifier
					'kilogram' => {
						'other' => q({0} ကီလိုဂရမ်),
						'per' => q(တစ်ကီလိုဂရမ်လျှင် {0}),
					},
					# Long Unit Identifier
					'mass-microgram' => {
						'name' => q(မိုက်ခရို ဂရမ်),
						'other' => q({0} မိုက်ခရို ဂရမ်),
					},
					# Core Unit Identifier
					'microgram' => {
						'name' => q(မိုက်ခရို ဂရမ်),
						'other' => q({0} မိုက်ခရို ဂရမ်),
					},
					# Long Unit Identifier
					'mass-milligram' => {
						'other' => q({0} မီလီဂရမ်),
					},
					# Core Unit Identifier
					'milligram' => {
						'other' => q({0} မီလီဂရမ်),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'other' => q({0} အောင်စ),
						'per' => q(တစ်အောင်စလျှင် {0}),
					},
					# Core Unit Identifier
					'ounce' => {
						'other' => q({0} အောင်စ),
						'per' => q(တစ်အောင်စလျှင် {0}),
					},
					# Long Unit Identifier
					'mass-ounce-troy' => {
						'other' => q({0} ထရိုအောင်စ),
					},
					# Core Unit Identifier
					'ounce-troy' => {
						'other' => q({0} ထရိုအောင်စ),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'other' => q({0} ပေါင်),
						'per' => q(တစ်ပေါင်လျှင် {0}),
					},
					# Core Unit Identifier
					'pound' => {
						'other' => q({0} ပေါင်),
						'per' => q(တစ်ပေါင်လျှင် {0}),
					},
					# Long Unit Identifier
					'mass-solar-mass' => {
						'other' => q({0} နေရောင်ခြည် ဒြပ်ထု),
					},
					# Core Unit Identifier
					'solar-mass' => {
						'other' => q({0} နေရောင်ခြည် ဒြပ်ထု),
					},
					# Long Unit Identifier
					'mass-ton' => {
						'other' => q({0} တန်),
					},
					# Core Unit Identifier
					'ton' => {
						'other' => q({0} တန်),
					},
					# Long Unit Identifier
					'mass-tonne' => {
						'other' => q({0} မက်ထရစ်တန်),
					},
					# Core Unit Identifier
					'tonne' => {
						'other' => q({0} မက်ထရစ်တန်),
					},
					# Long Unit Identifier
					'per' => {
						'1' => q(တစ်{1} လျှင် {0}),
					},
					# Core Unit Identifier
					'per' => {
						'1' => q(တစ်{1} လျှင် {0}),
					},
					# Long Unit Identifier
					'power-gigawatt' => {
						'other' => q({0} ဂစ်ဂါဝပ်),
					},
					# Core Unit Identifier
					'gigawatt' => {
						'other' => q({0} ဂစ်ဂါဝပ်),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'name' => q(မြင်းကောင်ရေအား),
						'other' => q({0} မြင်းကောင်ရေအား),
					},
					# Core Unit Identifier
					'horsepower' => {
						'name' => q(မြင်းကောင်ရေအား),
						'other' => q({0} မြင်းကောင်ရေအား),
					},
					# Long Unit Identifier
					'power-kilowatt' => {
						'other' => q({0} ကီလိုဝပ်),
					},
					# Core Unit Identifier
					'kilowatt' => {
						'other' => q({0} ကီလိုဝပ်),
					},
					# Long Unit Identifier
					'power-megawatt' => {
						'other' => q({0} မီဂါဝပ်),
					},
					# Core Unit Identifier
					'megawatt' => {
						'other' => q({0} မီဂါဝပ်),
					},
					# Long Unit Identifier
					'power-milliwatt' => {
						'other' => q({0} မီလီဝပ်),
					},
					# Core Unit Identifier
					'milliwatt' => {
						'other' => q({0} မီလီဝပ်),
					},
					# Long Unit Identifier
					'power-watt' => {
						'other' => q({0} ဝပ်),
					},
					# Core Unit Identifier
					'watt' => {
						'other' => q({0} ဝပ်),
					},
					# Long Unit Identifier
					'power2' => {
						'1' => q(နှစ်ထပ်ကိန်း {0}),
						'other' => q(စတုရန်း{0}),
					},
					# Core Unit Identifier
					'power2' => {
						'1' => q(နှစ်ထပ်ကိန်း {0}),
						'other' => q(စတုရန်း{0}),
					},
					# Long Unit Identifier
					'power3' => {
						'1' => q(ကုဗ {0}),
						'other' => q(ကုဗ{0}),
					},
					# Core Unit Identifier
					'power3' => {
						'1' => q(ကုဗ {0}),
						'other' => q(ကုဗ{0}),
					},
					# Long Unit Identifier
					'pressure-atmosphere' => {
						'name' => q(ကမ္ဘာ့လေထု),
						'other' => q({0} ကမ္ဘာ့လေထု),
					},
					# Core Unit Identifier
					'atmosphere' => {
						'name' => q(ကမ္ဘာ့လေထု),
						'other' => q({0} ကမ္ဘာ့လေထု),
					},
					# Long Unit Identifier
					'pressure-hectopascal' => {
						'name' => q(ဟက်တိုပါစကယ်),
						'other' => q({0} ဟက်တိုပါစကယ်),
					},
					# Core Unit Identifier
					'hectopascal' => {
						'name' => q(ဟက်တိုပါစကယ်),
						'other' => q({0} ဟက်တိုပါစကယ်),
					},
					# Long Unit Identifier
					'pressure-inch-ofhg' => {
						'name' => q(ပြဒါးလက်မ),
						'other' => q({0} ပြဒါးလက်မ),
					},
					# Core Unit Identifier
					'inch-ofhg' => {
						'name' => q(ပြဒါးလက်မ),
						'other' => q({0} ပြဒါးလက်မ),
					},
					# Long Unit Identifier
					'pressure-kilopascal' => {
						'name' => q(ကီလိုပါစကယ်),
						'other' => q({0} ကီလိုပါစကယ်),
					},
					# Core Unit Identifier
					'kilopascal' => {
						'name' => q(ကီလိုပါစကယ်),
						'other' => q({0} ကီလိုပါစကယ်),
					},
					# Long Unit Identifier
					'pressure-megapascal' => {
						'name' => q(မီဂါပါစကယ်),
						'other' => q({0} မီဂါပါစကယ်),
					},
					# Core Unit Identifier
					'megapascal' => {
						'name' => q(မီဂါပါစကယ်),
						'other' => q({0} မီဂါပါစကယ်),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'other' => q({0} မီလီဘား),
					},
					# Core Unit Identifier
					'millibar' => {
						'other' => q({0} မီလီဘား),
					},
					# Long Unit Identifier
					'pressure-millimeter-ofhg' => {
						'name' => q(ပြဒါးမီလီမီတာ),
						'other' => q({0} ပြဒါးမီလီမီတာ),
					},
					# Core Unit Identifier
					'millimeter-ofhg' => {
						'name' => q(ပြဒါးမီလီမီတာ),
						'other' => q({0} ပြဒါးမီလီမီတာ),
					},
					# Long Unit Identifier
					'pressure-pound-force-per-square-inch' => {
						'other' => q(တစ်စတုရန်းလက်မလျှင် {0} ပေါင်),
					},
					# Core Unit Identifier
					'pound-force-per-square-inch' => {
						'other' => q(တစ်စတုရန်းလက်မလျှင် {0} ပေါင်),
					},
					# Long Unit Identifier
					'speed-beaufort' => {
						'name' => q(ဗျူးဖို့တ်),
						'other' => q(ဗျူးဖို့တ် {0}),
					},
					# Core Unit Identifier
					'beaufort' => {
						'name' => q(ဗျူးဖို့တ်),
						'other' => q(ဗျူးဖို့တ် {0}),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'other' => q(တစ်နာရီလျှင် {0} ကီလိုမီတာ),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'other' => q(တစ်နာရီလျှင် {0} ကီလိုမီတာ),
					},
					# Long Unit Identifier
					'speed-knot' => {
						'name' => q(နော့တီကယ်မိုင်),
						'other' => q({0} နော့တီကယ်မိုင်),
					},
					# Core Unit Identifier
					'knot' => {
						'name' => q(နော့တီကယ်မိုင်),
						'other' => q({0} နော့တီကယ်မိုင်),
					},
					# Long Unit Identifier
					'speed-light-speed' => {
						'name' => q(အလင်း),
						'other' => q({0} အလင်း),
					},
					# Core Unit Identifier
					'light-speed' => {
						'name' => q(အလင်း),
						'other' => q({0} အလင်း),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'other' => q(တစ်စက္ကန့်လျှင် {0} မီတာ),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'other' => q(တစ်စက္ကန့်လျှင် {0} မီတာ),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'other' => q(တစ်နာရီလျှင် {0} မိုင်),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'other' => q(တစ်နာရီလျှင် {0} မိုင်),
					},
					# Long Unit Identifier
					'temperature-celsius' => {
						'name' => q(ဒီဂရီ စင်တီဂရိတ်),
						'other' => q({0} ဒီဂရီ စင်တီဂရိတ်),
					},
					# Core Unit Identifier
					'celsius' => {
						'name' => q(ဒီဂရီ စင်တီဂရိတ်),
						'other' => q({0} ဒီဂရီ စင်တီဂရိတ်),
					},
					# Long Unit Identifier
					'temperature-fahrenheit' => {
						'name' => q(ဒီဂရီ ဖာရင်ဟိုက်),
						'other' => q({0} ဒီဂရီ ဖာရင်ဟိုက်),
					},
					# Core Unit Identifier
					'fahrenheit' => {
						'name' => q(ဒီဂရီ ဖာရင်ဟိုက်),
						'other' => q({0} ဒီဂရီ ဖာရင်ဟိုက်),
					},
					# Long Unit Identifier
					'temperature-kelvin' => {
						'name' => q(ကယ်လ်ဗင်),
						'other' => q({0} ကယ်လ်ဗင်),
					},
					# Core Unit Identifier
					'kelvin' => {
						'name' => q(ကယ်လ်ဗင်),
						'other' => q({0} ကယ်လ်ဗင်),
					},
					# Long Unit Identifier
					'torque-newton-meter' => {
						'name' => q(နယူတန်−မီတာ),
						'other' => q({0} နယူတန်−မီတာ),
					},
					# Core Unit Identifier
					'newton-meter' => {
						'name' => q(နယူတန်−မီတာ),
						'other' => q({0} နယူတန်−မီတာ),
					},
					# Long Unit Identifier
					'volume-acre-foot' => {
						'other' => q({0} ဧက-ပေ),
					},
					# Core Unit Identifier
					'acre-foot' => {
						'other' => q({0} ဧက-ပေ),
					},
					# Long Unit Identifier
					'volume-barrel' => {
						'name' => q(ဘယ်ရလ်စ်),
						'other' => q({0} ဘယ်ရလ်စ်),
					},
					# Core Unit Identifier
					'barrel' => {
						'name' => q(ဘယ်ရလ်စ်),
						'other' => q({0} ဘယ်ရလ်စ်),
					},
					# Long Unit Identifier
					'volume-centiliter' => {
						'other' => q({0} စင်တီလီတာ),
					},
					# Core Unit Identifier
					'centiliter' => {
						'other' => q({0} စင်တီလီတာ),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'other' => q({0} ကုဗစင်တီမီတာ),
						'per' => q(တစ်ကုဗစင်တီမီတာလျှင် {0}),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'other' => q({0} ကုဗစင်တီမီတာ),
						'per' => q(တစ်ကုဗစင်တီမီတာလျှင် {0}),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'other' => q({0} ကုဗပေ),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'other' => q({0} ကုဗပေ),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'other' => q({0} ကုဗလက်မ),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'other' => q({0} ကုဗလက်မ),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'other' => q({0} ကုဗကီလိုမီတာ),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'other' => q({0} ကုဗကီလိုမီတာ),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'other' => q({0} ကုဗမီတာ),
						'per' => q(တစ်ကုဗမီတာလျှင် {0}),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'other' => q({0} ကုဗမီတာ),
						'per' => q(တစ်ကုဗမီတာလျှင် {0}),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'name' => q(ကုဗမိုင်),
						'other' => q({0} ကုဗမိုင်),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'name' => q(ကုဗမိုင်),
						'other' => q({0} ကုဗမိုင်),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'other' => q({0} ကုဗကိုက်),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'other' => q({0} ကုဗကိုက်),
					},
					# Long Unit Identifier
					'volume-cup' => {
						'other' => q({0} ခွက်),
					},
					# Core Unit Identifier
					'cup' => {
						'other' => q({0} ခွက်),
					},
					# Long Unit Identifier
					'volume-cup-metric' => {
						'name' => q(မထ္ထရစ် ခွက်),
						'other' => q({0} မထ္ထရစ် ခွက်),
					},
					# Core Unit Identifier
					'cup-metric' => {
						'name' => q(မထ္ထရစ် ခွက်),
						'other' => q({0} မထ္ထရစ် ခွက်),
					},
					# Long Unit Identifier
					'volume-deciliter' => {
						'other' => q({0} ဒက်စီလီတာ),
					},
					# Core Unit Identifier
					'deciliter' => {
						'other' => q({0} ဒက်စီလီတာ),
					},
					# Long Unit Identifier
					'volume-dessert-spoon-imperial' => {
						'other' => q(ဗြိတိသျှသုံး အချိုပွဲဇွန်း {0} ဇွန်း),
					},
					# Core Unit Identifier
					'dessert-spoon-imperial' => {
						'other' => q(ဗြိတိသျှသုံး အချိုပွဲဇွန်း {0} ဇွန်း),
					},
					# Long Unit Identifier
					'volume-fluid-ounce' => {
						'other' => q({0} အရည်အောင်စ),
					},
					# Core Unit Identifier
					'fluid-ounce' => {
						'other' => q({0} အရည်အောင်စ),
					},
					# Long Unit Identifier
					'volume-fluid-ounce-imperial' => {
						'other' => q({0} Imp. fl oz),
					},
					# Core Unit Identifier
					'fluid-ounce-imperial' => {
						'other' => q({0} Imp. fl oz),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'per' => q(တစ်ဂါလံလျှင် {0}),
					},
					# Core Unit Identifier
					'gallon' => {
						'per' => q(တစ်ဂါလံလျှင် {0}),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'per' => q(တစ် ယူကေ ဂါလံလျှင် {0}),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'per' => q(တစ် ယူကေ ဂါလံလျှင် {0}),
					},
					# Long Unit Identifier
					'volume-hectoliter' => {
						'name' => q(ဟက်တိုလီတာ),
						'other' => q({0} ဟက်တိုမီတာ),
					},
					# Core Unit Identifier
					'hectoliter' => {
						'name' => q(ဟက်တိုလီတာ),
						'other' => q({0} ဟက်တိုမီတာ),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'per' => q(တစ်လီတာလျှင် {0}),
					},
					# Core Unit Identifier
					'liter' => {
						'per' => q(တစ်လီတာလျှင် {0}),
					},
					# Long Unit Identifier
					'volume-megaliter' => {
						'name' => q(မီဂါလီတာ),
						'other' => q({0} မီဂါလီတာ),
					},
					# Core Unit Identifier
					'megaliter' => {
						'name' => q(မီဂါလီတာ),
						'other' => q({0} မီဂါလီတာ),
					},
					# Long Unit Identifier
					'volume-milliliter' => {
						'other' => q({0} မီလီလီတာ),
					},
					# Core Unit Identifier
					'milliliter' => {
						'other' => q({0} မီလီလီတာ),
					},
					# Long Unit Identifier
					'volume-pint' => {
						'other' => q({0} ပိုင့်),
					},
					# Core Unit Identifier
					'pint' => {
						'other' => q({0} ပိုင့်),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'name' => q(မထ္ထရစ် ပိုင့်),
						'other' => q({0} မထ္ထရစ် ပိုင့်),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'name' => q(မထ္ထရစ် ပိုင့်),
						'other' => q({0} မထ္ထရစ် ပိုင့်),
					},
					# Long Unit Identifier
					'volume-quart' => {
						'other' => q({0} ကွတ်),
					},
					# Core Unit Identifier
					'quart' => {
						'other' => q({0} ကွတ်),
					},
					# Long Unit Identifier
					'volume-tablespoon' => {
						'other' => q(စားပွဲဇွန်း {0} ဇွန်း),
					},
					# Core Unit Identifier
					'tablespoon' => {
						'other' => q(စားပွဲဇွန်း {0} ဇွန်း),
					},
					# Long Unit Identifier
					'volume-teaspoon' => {
						'other' => q(လက်ဖက်ရည်ဇွန်း {0} ဇွန်း),
					},
					# Core Unit Identifier
					'teaspoon' => {
						'other' => q(လက်ဖက်ရည်ဇွန်း {0} ဇွန်း),
					},
				},
				'narrow' => {
					# Long Unit Identifier
					'angle-degree' => {
						'other' => q({0}°),
					},
					# Core Unit Identifier
					'degree' => {
						'other' => q({0}°),
					},
					# Long Unit Identifier
					'area-square-centimeter' => {
						'name' => q(cm²),
					},
					# Core Unit Identifier
					'square-centimeter' => {
						'name' => q(cm²),
					},
					# Long Unit Identifier
					'concentr-portion-per-1e9' => {
						'other' => q({0}ppb),
					},
					# Core Unit Identifier
					'portion-per-1e9' => {
						'other' => q({0}ppb),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'name' => q(L/100km),
						'other' => q({0} L/100km),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'name' => q(L/100km),
						'other' => q({0} L/100km),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'name' => q(L/km),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'name' => q(L/km),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'other' => q({0}m/gUK),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'other' => q({0}m/gUK),
					},
					# Long Unit Identifier
					'coordinate' => {
						'east' => q({0}E),
						'north' => q({0}N),
						'south' => q({0}S),
						'west' => q({0}W),
					},
					# Core Unit Identifier
					'coordinate' => {
						'east' => q({0}E),
						'north' => q({0}N),
						'south' => q({0}S),
						'west' => q({0}W),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'name' => q(B),
						'other' => q({0}B),
					},
					# Core Unit Identifier
					'byte' => {
						'name' => q(B),
						'other' => q({0}B),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'name' => q(Gb),
					},
					# Core Unit Identifier
					'gigabit' => {
						'name' => q(Gb),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'other' => q({0} ms),
					},
					# Core Unit Identifier
					'millisecond' => {
						'other' => q({0} ms),
					},
					# Long Unit Identifier
					'duration-night' => {
						'name' => q(ည),
						'other' => q({0} ည),
						'per' => q({0}/ည),
					},
					# Core Unit Identifier
					'night' => {
						'name' => q(ည),
						'other' => q({0} ည),
						'per' => q({0}/ည),
					},
					# Long Unit Identifier
					'duration-second' => {
						'other' => q({0} s),
					},
					# Core Unit Identifier
					'second' => {
						'other' => q({0} s),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'name' => q(amp),
					},
					# Core Unit Identifier
					'ampere' => {
						'name' => q(amp),
					},
					# Long Unit Identifier
					'energy-therm-us' => {
						'other' => q({0}US therms),
					},
					# Core Unit Identifier
					'therm-us' => {
						'other' => q({0}US therms),
					},
					# Long Unit Identifier
					'force-kilowatt-hour-per-100-kilometer' => {
						'other' => q({0}kWh/100km),
					},
					# Core Unit Identifier
					'kilowatt-hour-per-100-kilometer' => {
						'other' => q({0}kWh/100km),
					},
					# Long Unit Identifier
					'force-newton' => {
						'name' => q(N),
					},
					# Core Unit Identifier
					'newton' => {
						'name' => q(N),
					},
					# Long Unit Identifier
					'frequency-gigahertz' => {
						'name' => q(GHz),
					},
					# Core Unit Identifier
					'gigahertz' => {
						'name' => q(GHz),
					},
					# Long Unit Identifier
					'graphics-dot' => {
						'other' => q({0}စက်),
					},
					# Core Unit Identifier
					'dot' => {
						'other' => q({0}စက်),
					},
					# Long Unit Identifier
					'length-earth-radius' => {
						'name' => q(R⊕),
						'other' => q({0}R⊕),
					},
					# Core Unit Identifier
					'earth-radius' => {
						'name' => q(R⊕),
						'other' => q({0}R⊕),
					},
					# Long Unit Identifier
					'length-foot' => {
						'name' => q(ft),
						'other' => q({0}′),
					},
					# Core Unit Identifier
					'foot' => {
						'name' => q(ft),
						'other' => q({0}′),
					},
					# Long Unit Identifier
					'length-inch' => {
						'name' => q(in),
						'other' => q({0}″),
					},
					# Core Unit Identifier
					'inch' => {
						'name' => q(in),
						'other' => q({0}″),
					},
					# Long Unit Identifier
					'length-kilometer' => {
						'other' => q({0}km),
					},
					# Core Unit Identifier
					'kilometer' => {
						'other' => q({0}km),
					},
					# Long Unit Identifier
					'length-light-year' => {
						'name' => q(ly),
						'other' => q({0} ly),
					},
					# Core Unit Identifier
					'light-year' => {
						'name' => q(ly),
						'other' => q({0} ly),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'name' => q(μm),
					},
					# Core Unit Identifier
					'micrometer' => {
						'name' => q(μm),
					},
					# Long Unit Identifier
					'length-mile' => {
						'name' => q(mi),
					},
					# Core Unit Identifier
					'mile' => {
						'name' => q(mi),
					},
					# Long Unit Identifier
					'length-point' => {
						'name' => q(pts),
					},
					# Core Unit Identifier
					'point' => {
						'name' => q(pts),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'name' => q(R☉),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'name' => q(R☉),
					},
					# Long Unit Identifier
					'length-yard' => {
						'name' => q(yd),
						'other' => q({0} yd),
					},
					# Core Unit Identifier
					'yard' => {
						'name' => q(yd),
						'other' => q({0} yd),
					},
					# Long Unit Identifier
					'light-lumen' => {
						'name' => q(lm),
						'other' => q({0}lm),
					},
					# Core Unit Identifier
					'lumen' => {
						'name' => q(lm),
						'other' => q({0}lm),
					},
					# Long Unit Identifier
					'light-solar-luminosity' => {
						'name' => q(L☉),
					},
					# Core Unit Identifier
					'solar-luminosity' => {
						'name' => q(L☉),
					},
					# Long Unit Identifier
					'pressure-inch-ofhg' => {
						'name' => q(″ Hg),
					},
					# Core Unit Identifier
					'inch-ofhg' => {
						'name' => q(″ Hg),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'name' => q(mbar),
					},
					# Core Unit Identifier
					'millibar' => {
						'name' => q(mbar),
					},
					# Long Unit Identifier
					'pressure-pound-force-per-square-inch' => {
						'name' => q(psi),
					},
					# Core Unit Identifier
					'pound-force-per-square-inch' => {
						'name' => q(psi),
					},
					# Long Unit Identifier
					'speed-light-speed' => {
						'name' => q(အလင်း),
						'other' => q({0}အလင်း),
					},
					# Core Unit Identifier
					'light-speed' => {
						'name' => q(အလင်း),
						'other' => q({0}အလင်း),
					},
					# Long Unit Identifier
					'volume-barrel' => {
						'name' => q(စည်),
					},
					# Core Unit Identifier
					'barrel' => {
						'name' => q(စည်),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'name' => q(cm³),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'name' => q(cm³),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'name' => q(ft³),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'name' => q(ft³),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'name' => q(in³),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'name' => q(in³),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'name' => q(yd³),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'name' => q(yd³),
					},
					# Long Unit Identifier
					'volume-drop' => {
						'name' => q(စက်),
					},
					# Core Unit Identifier
					'drop' => {
						'name' => q(စက်),
					},
					# Long Unit Identifier
					'volume-fluid-ounce-imperial' => {
						'name' => q(ဗြိတိသျှသုံး အရည်အောင်စ),
						'other' => q({0}fl oz Im),
					},
					# Core Unit Identifier
					'fluid-ounce-imperial' => {
						'name' => q(ဗြိတိသျှသုံး အရည်အောင်စ),
						'other' => q({0}fl oz Im),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'other' => q(ယူကေ ဂါလံ {0} ဂါလံ),
						'per' => q({0}/ယူကေ ဂါလံ),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'other' => q(ယူကေ ဂါလံ {0} ဂါလံ),
						'per' => q({0}/ယူကေ ဂါလံ),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'other' => q({0}L),
						'per' => q({0}/လီတာ),
					},
					# Core Unit Identifier
					'liter' => {
						'other' => q({0}L),
						'per' => q({0}/လီတာ),
					},
				},
				'short' => {
					# Long Unit Identifier
					'' => {
						'name' => q(လမ်းကြောင်း),
					},
					# Core Unit Identifier
					'' => {
						'name' => q(လမ်းကြောင်း),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'name' => q(ဆွဲငင်အား),
					},
					# Core Unit Identifier
					'g-force' => {
						'name' => q(ဆွဲငင်အား),
					},
					# Long Unit Identifier
					'acceleration-meter-per-square-second' => {
						'name' => q(မီတာ/စက္ကန့်နှစ်ထပ်ကိန်း),
					},
					# Core Unit Identifier
					'meter-per-square-second' => {
						'name' => q(မီတာ/စက္ကန့်နှစ်ထပ်ကိန်း),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'name' => q(မိနစ်),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'name' => q(မိနစ်),
					},
					# Long Unit Identifier
					'angle-arc-second' => {
						'name' => q(စက္ကန့်),
					},
					# Core Unit Identifier
					'arc-second' => {
						'name' => q(စက္ကန့်),
					},
					# Long Unit Identifier
					'angle-degree' => {
						'name' => q(ဒီဂရီ),
						'other' => q({0} deg),
					},
					# Core Unit Identifier
					'degree' => {
						'name' => q(ဒီဂရီ),
						'other' => q({0} deg),
					},
					# Long Unit Identifier
					'angle-radian' => {
						'name' => q(ရေဒီယဲန်း),
					},
					# Core Unit Identifier
					'radian' => {
						'name' => q(ရေဒီယဲန်း),
					},
					# Long Unit Identifier
					'area-acre' => {
						'name' => q(ဧက),
					},
					# Core Unit Identifier
					'acre' => {
						'name' => q(ဧက),
					},
					# Long Unit Identifier
					'area-dunam' => {
						'name' => q(dunams),
					},
					# Core Unit Identifier
					'dunam' => {
						'name' => q(dunams),
					},
					# Long Unit Identifier
					'area-hectare' => {
						'name' => q(ဟက်တာ),
					},
					# Core Unit Identifier
					'hectare' => {
						'name' => q(ဟက်တာ),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'name' => q(စတုရန်းပေ),
					},
					# Core Unit Identifier
					'square-foot' => {
						'name' => q(စတုရန်းပေ),
					},
					# Long Unit Identifier
					'area-square-inch' => {
						'name' => q(စတုရန်းလက်မ),
					},
					# Core Unit Identifier
					'square-inch' => {
						'name' => q(စတုရန်းလက်မ),
					},
					# Long Unit Identifier
					'area-square-kilometer' => {
						'name' => q(စတုရန်းကီလိုမီတာ),
					},
					# Core Unit Identifier
					'square-kilometer' => {
						'name' => q(စတုရန်းကီလိုမီတာ),
					},
					# Long Unit Identifier
					'area-square-meter' => {
						'name' => q(စတုရန်းမီတာ),
					},
					# Core Unit Identifier
					'square-meter' => {
						'name' => q(စတုရန်းမီတာ),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'name' => q(စတုရန်းမိုင်),
					},
					# Core Unit Identifier
					'square-mile' => {
						'name' => q(စတုရန်းမိုင်),
					},
					# Long Unit Identifier
					'area-square-yard' => {
						'name' => q(စတုရန်းကိုက်),
					},
					# Core Unit Identifier
					'square-yard' => {
						'name' => q(စတုရန်းကိုက်),
					},
					# Long Unit Identifier
					'concentr-karat' => {
						'name' => q(ကာရက်),
					},
					# Core Unit Identifier
					'karat' => {
						'name' => q(ကာရက်),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'name' => q(တစ်သန်းပုံ တစ်ပုံ),
					},
					# Core Unit Identifier
					'permillion' => {
						'name' => q(တစ်သန်းပုံ တစ်ပုံ),
					},
					# Long Unit Identifier
					'concentr-permyriad' => {
						'name' => q(ပါမီရိတ်),
					},
					# Core Unit Identifier
					'permyriad' => {
						'name' => q(ပါမီရိတ်),
					},
					# Long Unit Identifier
					'concentr-portion-per-1e9' => {
						'name' => q(သန်းတစ်ထောင်ပုံ တစ်ပုံ),
					},
					# Core Unit Identifier
					'portion-per-1e9' => {
						'name' => q(သန်းတစ်ထောင်ပုံ တစ်ပုံ),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'name' => q(တစ်ရာကီလိုမီတာရှိ လီတာ),
						'other' => q({0} L/100 km),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'name' => q(တစ်ရာကီလိုမီတာရှိ လီတာ),
						'other' => q({0} L/100 km),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'name' => q(လီတာ/ကီလိုမီတာ),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'name' => q(လီတာ/ကီလိုမီတာ),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon' => {
						'name' => q(မိုင်/ဂါလန်),
						'other' => q({0} mpg),
					},
					# Core Unit Identifier
					'mile-per-gallon' => {
						'name' => q(မိုင်/ဂါလန်),
						'other' => q({0} mpg),
					},
					# Long Unit Identifier
					'coordinate' => {
						'east' => q({0} E),
						'north' => q({0} N),
						'south' => q({0} S),
						'west' => q({0} W),
					},
					# Core Unit Identifier
					'coordinate' => {
						'east' => q({0} E),
						'north' => q({0} N),
						'south' => q({0} S),
						'west' => q({0} W),
					},
					# Long Unit Identifier
					'digital-bit' => {
						'name' => q(ဘစ်),
					},
					# Core Unit Identifier
					'bit' => {
						'name' => q(ဘစ်),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'name' => q(ဘိုက်),
					},
					# Core Unit Identifier
					'byte' => {
						'name' => q(ဘိုက်),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'name' => q(ဂစ်ဂါဘစ်),
					},
					# Core Unit Identifier
					'gigabit' => {
						'name' => q(ဂစ်ဂါဘစ်),
					},
					# Long Unit Identifier
					'digital-gigabyte' => {
						'name' => q(ဂစ်ဂါဘိုက်),
					},
					# Core Unit Identifier
					'gigabyte' => {
						'name' => q(ဂစ်ဂါဘိုက်),
					},
					# Long Unit Identifier
					'digital-kilobit' => {
						'name' => q(ကီလိုဘစ်),
					},
					# Core Unit Identifier
					'kilobit' => {
						'name' => q(ကီလိုဘစ်),
					},
					# Long Unit Identifier
					'digital-kilobyte' => {
						'name' => q(ကီလိုဘိုက်),
					},
					# Core Unit Identifier
					'kilobyte' => {
						'name' => q(ကီလိုဘိုက်),
					},
					# Long Unit Identifier
					'digital-megabit' => {
						'name' => q(မီဂါဘစ်),
					},
					# Core Unit Identifier
					'megabit' => {
						'name' => q(မီဂါဘစ်),
					},
					# Long Unit Identifier
					'digital-megabyte' => {
						'name' => q(မီဂါဘိုက်),
					},
					# Core Unit Identifier
					'megabyte' => {
						'name' => q(မီဂါဘိုက်),
					},
					# Long Unit Identifier
					'digital-petabyte' => {
						'name' => q(ပက်တာဘိုက်),
					},
					# Core Unit Identifier
					'petabyte' => {
						'name' => q(ပက်တာဘိုက်),
					},
					# Long Unit Identifier
					'digital-terabit' => {
						'name' => q(တယ်ရာဘစ်),
					},
					# Core Unit Identifier
					'terabit' => {
						'name' => q(တယ်ရာဘစ်),
					},
					# Long Unit Identifier
					'digital-terabyte' => {
						'name' => q(တယ်ရာဘိုက်),
					},
					# Core Unit Identifier
					'terabyte' => {
						'name' => q(တယ်ရာဘိုက်),
					},
					# Long Unit Identifier
					'duration-century' => {
						'name' => q(ရာစု),
						'other' => q({0} ရာစု),
					},
					# Core Unit Identifier
					'century' => {
						'name' => q(ရာစု),
						'other' => q({0} ရာစု),
					},
					# Long Unit Identifier
					'duration-day' => {
						'name' => q(ရက်),
						'other' => q({0} ရက်),
						'per' => q({0}/ ရက်),
					},
					# Core Unit Identifier
					'day' => {
						'name' => q(ရက်),
						'other' => q({0} ရက်),
						'per' => q({0}/ ရက်),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'name' => q(ဆယ်စု),
						'other' => q({0} ဆယ်စု),
					},
					# Core Unit Identifier
					'decade' => {
						'name' => q(ဆယ်စု),
						'other' => q({0} ဆယ်စု),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'name' => q(နာရီ),
						'other' => q({0} နာရီ),
						'per' => q({0}/ နာရီ),
					},
					# Core Unit Identifier
					'hour' => {
						'name' => q(နာရီ),
						'other' => q({0} နာရီ),
						'per' => q({0}/ နာရီ),
					},
					# Long Unit Identifier
					'duration-microsecond' => {
						'name' => q(မိုက်ခရိုစက္ကန့်),
					},
					# Core Unit Identifier
					'microsecond' => {
						'name' => q(မိုက်ခရိုစက္ကန့်),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'name' => q(မီလီစက္ကန့်),
						'other' => q({0} မီလီစက္ကန့်),
					},
					# Core Unit Identifier
					'millisecond' => {
						'name' => q(မီလီစက္ကန့်),
						'other' => q({0} မီလီစက္ကန့်),
					},
					# Long Unit Identifier
					'duration-minute' => {
						'name' => q(မိနစ်),
						'other' => q({0} မိနစ်),
						'per' => q({0}/ မိနစ်),
					},
					# Core Unit Identifier
					'minute' => {
						'name' => q(မိနစ်),
						'other' => q({0} မိနစ်),
						'per' => q({0}/ မိနစ်),
					},
					# Long Unit Identifier
					'duration-month' => {
						'name' => q(လ),
						'other' => q({0} လ),
						'per' => q({0}/ လ),
					},
					# Core Unit Identifier
					'month' => {
						'name' => q(လ),
						'other' => q({0} လ),
						'per' => q({0}/ လ),
					},
					# Long Unit Identifier
					'duration-nanosecond' => {
						'name' => q(နာနိုစက္ကန့်),
					},
					# Core Unit Identifier
					'nanosecond' => {
						'name' => q(နာနိုစက္ကန့်),
					},
					# Long Unit Identifier
					'duration-night' => {
						'name' => q(ည),
						'other' => q({0} ည),
						'per' => q({0}/ည),
					},
					# Core Unit Identifier
					'night' => {
						'name' => q(ည),
						'other' => q({0} ည),
						'per' => q({0}/ည),
					},
					# Long Unit Identifier
					'duration-second' => {
						'name' => q(စက္ကန့်),
						'other' => q({0} sec),
					},
					# Core Unit Identifier
					'second' => {
						'name' => q(စက္ကန့်),
						'other' => q({0} sec),
					},
					# Long Unit Identifier
					'duration-week' => {
						'name' => q(ပတ်),
						'other' => q({0} ပတ်),
						'per' => q({0}/ ပတ်),
					},
					# Core Unit Identifier
					'week' => {
						'name' => q(ပတ်),
						'other' => q({0} ပတ်),
						'per' => q({0}/ ပတ်),
					},
					# Long Unit Identifier
					'duration-year' => {
						'name' => q(နှစ်),
						'other' => q({0} နှစ်),
						'per' => q({0}/ နှစ်),
					},
					# Core Unit Identifier
					'year' => {
						'name' => q(နှစ်),
						'other' => q({0} နှစ်),
						'per' => q({0}/ နှစ်),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'name' => q(အမ်ပီယာ),
					},
					# Core Unit Identifier
					'ampere' => {
						'name' => q(အမ်ပီယာ),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'name' => q(အုမ်း),
					},
					# Core Unit Identifier
					'ohm' => {
						'name' => q(အုမ်း),
					},
					# Long Unit Identifier
					'electric-volt' => {
						'name' => q(ဗို့),
					},
					# Core Unit Identifier
					'volt' => {
						'name' => q(ဗို့),
					},
					# Long Unit Identifier
					'energy-british-thermal-unit' => {
						'name' => q(BTU),
					},
					# Core Unit Identifier
					'british-thermal-unit' => {
						'name' => q(BTU),
					},
					# Long Unit Identifier
					'energy-calorie' => {
						'name' => q(ကယ်လိုရီ),
					},
					# Core Unit Identifier
					'calorie' => {
						'name' => q(ကယ်လိုရီ),
					},
					# Long Unit Identifier
					'energy-electronvolt' => {
						'name' => q(အီလက်ထရွန်ဗို့),
					},
					# Core Unit Identifier
					'electronvolt' => {
						'name' => q(အီလက်ထရွန်ဗို့),
					},
					# Long Unit Identifier
					'energy-foodcalorie' => {
						'name' => q(ကယ်လိုရီ),
						'other' => q({0} Cal),
					},
					# Core Unit Identifier
					'foodcalorie' => {
						'name' => q(ကယ်လိုရီ),
						'other' => q({0} Cal),
					},
					# Long Unit Identifier
					'energy-joule' => {
						'name' => q(ဂျူးလ်),
					},
					# Core Unit Identifier
					'joule' => {
						'name' => q(ဂျူးလ်),
					},
					# Long Unit Identifier
					'energy-kilocalorie' => {
						'name' => q(ကီလိုကယ်လိုရီ),
					},
					# Core Unit Identifier
					'kilocalorie' => {
						'name' => q(ကီလိုကယ်လိုရီ),
					},
					# Long Unit Identifier
					'energy-kilojoule' => {
						'name' => q(ကီလိုဂျူးလ်),
					},
					# Core Unit Identifier
					'kilojoule' => {
						'name' => q(ကီလိုဂျူးလ်),
					},
					# Long Unit Identifier
					'energy-kilowatt-hour' => {
						'name' => q(ကီလိုဝပ်-နာရီ),
					},
					# Core Unit Identifier
					'kilowatt-hour' => {
						'name' => q(ကီလိုဝပ်-နာရီ),
					},
					# Long Unit Identifier
					'energy-therm-us' => {
						'name' => q(ယူအက်စ် သာမယ်လ်),
						'other' => q({0} ယူအက်စ်သာမယ်လ်),
					},
					# Core Unit Identifier
					'therm-us' => {
						'name' => q(ယူအက်စ် သာမယ်လ်),
						'other' => q({0} ယူအက်စ်သာမယ်လ်),
					},
					# Long Unit Identifier
					'force-newton' => {
						'name' => q(နယူတန်),
					},
					# Core Unit Identifier
					'newton' => {
						'name' => q(နယူတန်),
					},
					# Long Unit Identifier
					'frequency-gigahertz' => {
						'name' => q(ဂီဂါဟတ်ဇ်),
					},
					# Core Unit Identifier
					'gigahertz' => {
						'name' => q(ဂီဂါဟတ်ဇ်),
					},
					# Long Unit Identifier
					'frequency-megahertz' => {
						'name' => q(မီဂါဟတ်ဇ်),
					},
					# Core Unit Identifier
					'megahertz' => {
						'name' => q(မီဂါဟတ်ဇ်),
					},
					# Long Unit Identifier
					'graphics-dot' => {
						'name' => q(အစက်),
					},
					# Core Unit Identifier
					'dot' => {
						'name' => q(အစက်),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'name' => q(dpcm),
						'other' => q({0} dpcm),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'name' => q(dpcm),
						'other' => q({0} dpcm),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'name' => q(dpi),
						'other' => q({0} dpi),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'name' => q(dpi),
						'other' => q({0} dpi),
					},
					# Long Unit Identifier
					'graphics-megapixel' => {
						'name' => q(မီဂါပစ်ဆယ်),
					},
					# Core Unit Identifier
					'megapixel' => {
						'name' => q(မီဂါပစ်ဆယ်),
					},
					# Long Unit Identifier
					'graphics-pixel' => {
						'name' => q(ပစ်ဆယ်),
					},
					# Core Unit Identifier
					'pixel' => {
						'name' => q(ပစ်ဆယ်),
					},
					# Long Unit Identifier
					'length-earth-radius' => {
						'name' => q(ကမ္ဘာ့အချင်းဝက်),
						'other' => q({0} ကမ္ဘာ့အချင်းဝက်),
					},
					# Core Unit Identifier
					'earth-radius' => {
						'name' => q(ကမ္ဘာ့အချင်းဝက်),
						'other' => q({0} ကမ္ဘာ့အချင်းဝက်),
					},
					# Long Unit Identifier
					'length-fathom' => {
						'name' => q(ဖန်တမ်),
					},
					# Core Unit Identifier
					'fathom' => {
						'name' => q(ဖန်တမ်),
					},
					# Long Unit Identifier
					'length-foot' => {
						'name' => q(ပေ),
					},
					# Core Unit Identifier
					'foot' => {
						'name' => q(ပေ),
					},
					# Long Unit Identifier
					'length-furlong' => {
						'name' => q(ဖာလုံ),
					},
					# Core Unit Identifier
					'furlong' => {
						'name' => q(ဖာလုံ),
					},
					# Long Unit Identifier
					'length-inch' => {
						'name' => q(လက်မ),
						'other' => q({0} လက်မ),
					},
					# Core Unit Identifier
					'inch' => {
						'name' => q(လက်မ),
						'other' => q({0} လက်မ),
					},
					# Long Unit Identifier
					'length-light-year' => {
						'name' => q(အလင်းနှစ်),
						'other' => q({0} အလင်းနှစ်),
					},
					# Core Unit Identifier
					'light-year' => {
						'name' => q(အလင်းနှစ်),
						'other' => q({0} အလင်းနှစ်),
					},
					# Long Unit Identifier
					'length-meter' => {
						'name' => q(m),
					},
					# Core Unit Identifier
					'meter' => {
						'name' => q(m),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'name' => q(μ မီတာ),
					},
					# Core Unit Identifier
					'micrometer' => {
						'name' => q(μ မီတာ),
					},
					# Long Unit Identifier
					'length-mile' => {
						'name' => q(မိုင်),
					},
					# Core Unit Identifier
					'mile' => {
						'name' => q(မိုင်),
					},
					# Long Unit Identifier
					'length-parsec' => {
						'name' => q(ပါစက်ခ်),
					},
					# Core Unit Identifier
					'parsec' => {
						'name' => q(ပါစက်ခ်),
					},
					# Long Unit Identifier
					'length-point' => {
						'name' => q(ပွိုင့်),
					},
					# Core Unit Identifier
					'point' => {
						'name' => q(ပွိုင့်),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'name' => q(ဆိုလာ ရာဒီ),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'name' => q(ဆိုလာ ရာဒီ),
					},
					# Long Unit Identifier
					'length-yard' => {
						'name' => q(ကိုက်),
						'other' => q({0} ကိုက်),
					},
					# Core Unit Identifier
					'yard' => {
						'name' => q(ကိုက်),
						'other' => q({0} ကိုက်),
					},
					# Long Unit Identifier
					'light-lumen' => {
						'name' => q(လူမန်),
						'other' => q({0} လူမန်),
					},
					# Core Unit Identifier
					'lumen' => {
						'name' => q(လူမန်),
						'other' => q({0} လူမန်),
					},
					# Long Unit Identifier
					'light-lux' => {
						'name' => q(လတ်ခ်),
					},
					# Core Unit Identifier
					'lux' => {
						'name' => q(လတ်ခ်),
					},
					# Long Unit Identifier
					'light-solar-luminosity' => {
						'name' => q(ဆိုလာ လူမီနိုစီးတီးစ်),
					},
					# Core Unit Identifier
					'solar-luminosity' => {
						'name' => q(ဆိုလာ လူမီနိုစီးတီးစ်),
					},
					# Long Unit Identifier
					'mass-carat' => {
						'name' => q(ကာရက်),
					},
					# Core Unit Identifier
					'carat' => {
						'name' => q(ကာရက်),
					},
					# Long Unit Identifier
					'mass-dalton' => {
						'name' => q(ဒဲလ်တန်စ်),
					},
					# Core Unit Identifier
					'dalton' => {
						'name' => q(ဒဲလ်တန်စ်),
					},
					# Long Unit Identifier
					'mass-earth-mass' => {
						'name' => q(ကမ္ဘာ့ဒြပ်ထု),
					},
					# Core Unit Identifier
					'earth-mass' => {
						'name' => q(ကမ္ဘာ့ဒြပ်ထု),
					},
					# Long Unit Identifier
					'mass-grain' => {
						'name' => q(ဂရိန်),
						'other' => q({0} ဂရိန်),
					},
					# Core Unit Identifier
					'grain' => {
						'name' => q(ဂရိန်),
						'other' => q({0} ဂရိန်),
					},
					# Long Unit Identifier
					'mass-gram' => {
						'name' => q(ဂရမ်),
					},
					# Core Unit Identifier
					'gram' => {
						'name' => q(ဂရမ်),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'name' => q(ကီလိုဂရမ်),
					},
					# Core Unit Identifier
					'kilogram' => {
						'name' => q(ကီလိုဂရမ်),
					},
					# Long Unit Identifier
					'mass-milligram' => {
						'name' => q(မီလီဂရမ်),
					},
					# Core Unit Identifier
					'milligram' => {
						'name' => q(မီလီဂရမ်),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'name' => q(အောင်စ),
					},
					# Core Unit Identifier
					'ounce' => {
						'name' => q(အောင်စ),
					},
					# Long Unit Identifier
					'mass-ounce-troy' => {
						'name' => q(ထရိုအောင်စ),
					},
					# Core Unit Identifier
					'ounce-troy' => {
						'name' => q(ထရိုအောင်စ),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'name' => q(ပေါင်),
					},
					# Core Unit Identifier
					'pound' => {
						'name' => q(ပေါင်),
					},
					# Long Unit Identifier
					'mass-solar-mass' => {
						'name' => q(နေရောင်ခြည် ဒြပ်ထု),
					},
					# Core Unit Identifier
					'solar-mass' => {
						'name' => q(နေရောင်ခြည် ဒြပ်ထု),
					},
					# Long Unit Identifier
					'mass-stone' => {
						'name' => q(စတုန်),
						'other' => q({0} စတုန်),
					},
					# Core Unit Identifier
					'stone' => {
						'name' => q(စတုန်),
						'other' => q({0} စတုန်),
					},
					# Long Unit Identifier
					'mass-ton' => {
						'name' => q(တန်),
					},
					# Core Unit Identifier
					'ton' => {
						'name' => q(တန်),
					},
					# Long Unit Identifier
					'mass-tonne' => {
						'name' => q(မက်ထရစ်တန်),
					},
					# Core Unit Identifier
					'tonne' => {
						'name' => q(မက်ထရစ်တန်),
					},
					# Long Unit Identifier
					'power-gigawatt' => {
						'name' => q(ဂစ်ဂါဝပ်),
					},
					# Core Unit Identifier
					'gigawatt' => {
						'name' => q(ဂစ်ဂါဝပ်),
					},
					# Long Unit Identifier
					'power-kilowatt' => {
						'name' => q(ကီလိုဝပ်),
					},
					# Core Unit Identifier
					'kilowatt' => {
						'name' => q(ကီလိုဝပ်),
					},
					# Long Unit Identifier
					'power-megawatt' => {
						'name' => q(မီဂါဝပ်),
					},
					# Core Unit Identifier
					'megawatt' => {
						'name' => q(မီဂါဝပ်),
					},
					# Long Unit Identifier
					'power-milliwatt' => {
						'name' => q(မီလီဝပ်),
					},
					# Core Unit Identifier
					'milliwatt' => {
						'name' => q(မီလီဝပ်),
					},
					# Long Unit Identifier
					'power-watt' => {
						'name' => q(ဝပ်),
					},
					# Core Unit Identifier
					'watt' => {
						'name' => q(ဝပ်),
					},
					# Long Unit Identifier
					'pressure-bar' => {
						'name' => q(ဘား),
						'other' => q({0} ဘား),
					},
					# Core Unit Identifier
					'bar' => {
						'name' => q(ဘား),
						'other' => q({0} ဘား),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'name' => q(မီလီဘား),
					},
					# Core Unit Identifier
					'millibar' => {
						'name' => q(မီလီဘား),
					},
					# Long Unit Identifier
					'pressure-pound-force-per-square-inch' => {
						'name' => q(ပေါင်/စတုရန်းလက်မ),
					},
					# Core Unit Identifier
					'pound-force-per-square-inch' => {
						'name' => q(ပေါင်/စတုရန်းလက်မ),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'name' => q(ကီလိုမီတာ/နာရီ),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'name' => q(ကီလိုမီတာ/နာရီ),
					},
					# Long Unit Identifier
					'speed-light-speed' => {
						'name' => q(အလင်း),
						'other' => q({0} အလင်း),
					},
					# Core Unit Identifier
					'light-speed' => {
						'name' => q(အလင်း),
						'other' => q({0} အလင်း),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'name' => q(မီတာ/စက္ကန့်),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'name' => q(မီတာ/စက္ကန့်),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'name' => q(မိုင်/နာရီ),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'name' => q(မိုင်/နာရီ),
					},
					# Long Unit Identifier
					'torque-newton-meter' => {
						'name' => q(N.m),
						'other' => q({0} N.m),
					},
					# Core Unit Identifier
					'newton-meter' => {
						'name' => q(N.m),
						'other' => q({0} N.m),
					},
					# Long Unit Identifier
					'torque-pound-force-foot' => {
						'name' => q(lbf.ft),
						'other' => q({0} lbf.ft),
					},
					# Core Unit Identifier
					'pound-force-foot' => {
						'name' => q(lbf.ft),
						'other' => q({0} lbf.ft),
					},
					# Long Unit Identifier
					'volume-acre-foot' => {
						'name' => q(ဧက-ပေ),
					},
					# Core Unit Identifier
					'acre-foot' => {
						'name' => q(ဧက-ပေ),
					},
					# Long Unit Identifier
					'volume-barrel' => {
						'name' => q(ဘယ်ရလ်),
					},
					# Core Unit Identifier
					'barrel' => {
						'name' => q(ဘယ်ရလ်),
					},
					# Long Unit Identifier
					'volume-bushel' => {
						'name' => q(၈ ဂါလံဝင်ပုံး),
						'other' => q(၈ ဂါလံဝင်ပုံး {0} ပုံး),
					},
					# Core Unit Identifier
					'bushel' => {
						'name' => q(၈ ဂါလံဝင်ပုံး),
						'other' => q(၈ ဂါလံဝင်ပုံး {0} ပုံး),
					},
					# Long Unit Identifier
					'volume-centiliter' => {
						'name' => q(စင်တီလီတာ),
					},
					# Core Unit Identifier
					'centiliter' => {
						'name' => q(စင်တီလီတာ),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'name' => q(ကုဗစင်တီမီတာ),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'name' => q(ကုဗစင်တီမီတာ),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'name' => q(ကုဗပေ),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'name' => q(ကုဗပေ),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'name' => q(ကုဗလက်မ),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'name' => q(ကုဗလက်မ),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'name' => q(ကုဗကီလိုမီတာ),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'name' => q(ကုဗကီလိုမီတာ),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'name' => q(ကုဗမီတာ),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'name' => q(ကုဗမီတာ),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'name' => q(ကုဗကိုက်),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'name' => q(ကုဗကိုက်),
					},
					# Long Unit Identifier
					'volume-cup' => {
						'name' => q(ခွက်),
					},
					# Core Unit Identifier
					'cup' => {
						'name' => q(ခွက်),
					},
					# Long Unit Identifier
					'volume-cup-metric' => {
						'name' => q(မထ္ထရစ်ခွက်),
					},
					# Core Unit Identifier
					'cup-metric' => {
						'name' => q(မထ္ထရစ်ခွက်),
					},
					# Long Unit Identifier
					'volume-deciliter' => {
						'name' => q(ဒက်စီလီတာ),
					},
					# Core Unit Identifier
					'deciliter' => {
						'name' => q(ဒက်စီလီတာ),
					},
					# Long Unit Identifier
					'volume-dessert-spoon' => {
						'name' => q(အချိုပွဲဇွန်း),
						'other' => q(အချိုပွဲဇွန်း {0} ဇွန်း),
					},
					# Core Unit Identifier
					'dessert-spoon' => {
						'name' => q(အချိုပွဲဇွန်း),
						'other' => q(အချိုပွဲဇွန်း {0} ဇွန်း),
					},
					# Long Unit Identifier
					'volume-dessert-spoon-imperial' => {
						'name' => q(ဗြိတိသျှသုံး အချိုပွဲဇွန်း),
						'other' => q(ဗြိတိသျှသုံးအချိုပွဲဇွန်း {0} ဇွန်း),
					},
					# Core Unit Identifier
					'dessert-spoon-imperial' => {
						'name' => q(ဗြိတိသျှသုံး အချိုပွဲဇွန်း),
						'other' => q(ဗြိတိသျှသုံးအချိုပွဲဇွန်း {0} ဇွန်း),
					},
					# Long Unit Identifier
					'volume-dram' => {
						'name' => q(ဒရမ်),
						'other' => q({0} ဒရမ်),
					},
					# Core Unit Identifier
					'dram' => {
						'name' => q(ဒရမ်),
						'other' => q({0} ဒရမ်),
					},
					# Long Unit Identifier
					'volume-drop' => {
						'name' => q(တစ်စက်),
						'other' => q({0} စက်),
					},
					# Core Unit Identifier
					'drop' => {
						'name' => q(တစ်စက်),
						'other' => q({0} စက်),
					},
					# Long Unit Identifier
					'volume-fluid-ounce' => {
						'name' => q(အရည်အောင်စ),
						'other' => q({0} fl oz),
					},
					# Core Unit Identifier
					'fluid-ounce' => {
						'name' => q(အရည်အောင်စ),
						'other' => q({0} fl oz),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'name' => q(ဂါလံ),
						'other' => q({0} ဂါလံ),
					},
					# Core Unit Identifier
					'gallon' => {
						'name' => q(ဂါလံ),
						'other' => q({0} ဂါလံ),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'name' => q(ယူကေ ဂါလံ),
						'other' => q({0} ယူကေ ဂါလံ),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'name' => q(ယူကေ ဂါလံ),
						'other' => q({0} ယူကေ ဂါလံ),
					},
					# Long Unit Identifier
					'volume-jigger' => {
						'name' => q(ပက်),
						'other' => q({0} ပက်),
					},
					# Core Unit Identifier
					'jigger' => {
						'name' => q(ပက်),
						'other' => q({0} ပက်),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'name' => q(လီတာ),
						'other' => q({0} လီတာ),
					},
					# Core Unit Identifier
					'liter' => {
						'name' => q(လီတာ),
						'other' => q({0} လီတာ),
					},
					# Long Unit Identifier
					'volume-milliliter' => {
						'name' => q(မီလီလီတာ),
					},
					# Core Unit Identifier
					'milliliter' => {
						'name' => q(မီလီလီတာ),
					},
					# Long Unit Identifier
					'volume-pinch' => {
						'name' => q(တစ်ဆိတ်),
						'other' => q({0} ဆိတ်),
					},
					# Core Unit Identifier
					'pinch' => {
						'name' => q(တစ်ဆိတ်),
						'other' => q({0} ဆိတ်),
					},
					# Long Unit Identifier
					'volume-pint' => {
						'name' => q(ပိုင့်),
					},
					# Core Unit Identifier
					'pint' => {
						'name' => q(ပိုင့်),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'name' => q(မထ္ထရစ်ပိုင့်),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'name' => q(မထ္ထရစ်ပိုင့်),
					},
					# Long Unit Identifier
					'volume-quart' => {
						'name' => q(ကွတ်),
					},
					# Core Unit Identifier
					'quart' => {
						'name' => q(ကွတ်),
					},
					# Long Unit Identifier
					'volume-quart-imperial' => {
						'name' => q(ဗြိတိသျှသုံး ကွတ်),
						'other' => q(ဗြိတိသျှသုံး {0} ကွတ်),
					},
					# Core Unit Identifier
					'quart-imperial' => {
						'name' => q(ဗြိတိသျှသုံး ကွတ်),
						'other' => q(ဗြိတိသျှသုံး {0} ကွတ်),
					},
					# Long Unit Identifier
					'volume-tablespoon' => {
						'name' => q(စားပွဲဇွန်း),
					},
					# Core Unit Identifier
					'tablespoon' => {
						'name' => q(စားပွဲဇွန်း),
					},
					# Long Unit Identifier
					'volume-teaspoon' => {
						'name' => q(လက်ဖက်ရည်ဇွန်း),
					},
					# Core Unit Identifier
					'teaspoon' => {
						'name' => q(လက်ဖက်ရည်ဇွန်း),
					},
				},
			} }
);

has 'yesstr' => (
	is			=> 'ro',
	isa			=> RegexpRef,
	init_arg	=> undef,
	default		=> sub { qr'^(?i:Yes)$' }
);

has 'nostr' => (
	is			=> 'ro',
	isa			=> RegexpRef,
	init_arg	=> undef,
	default		=> sub { qr'^(?i:No)$' }
);

has 'listPatterns' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
				start => q({0} - {1}),
				middle => q({0} - {1}),
				end => q({0}နှင့် {1}),
				2 => q({0}နှင့် {1}),
		} }
);

has 'default_numbering_system' => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> 'mymr',
);

has native_numbering_system => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> 'mymr',
);

has 'number_symbols' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'latn' => {
			'nan' => q(ဂဏန်းမဟုတ်သော),
		},
		'mymr' => {
			'list' => q(၊),
		},
	} }
);

has 'number_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		decimalFormat => {
			'long' => {
				'1000' => {
					'other' => '0 ထောင်',
				},
				'10000' => {
					'other' => '0 သောင်း',
				},
				'100000' => {
					'other' => '0 သိန်း',
				},
				'1000000' => {
					'other' => '0 သန်း',
				},
				'10000000' => {
					'other' => '0 ကုဋေ',
				},
				'100000000' => {
					'other' => '00 ကုဋေ',
				},
				'1000000000' => {
					'other' => '000 ကုဋေ',
				},
				'10000000000' => {
					'other' => '0000 ကုဋေ',
				},
				'100000000000' => {
					'other' => 'ကုဋေ 0 သောင်း',
				},
				'1000000000000' => {
					'other' => 'ကုဋေ 0 သိန်း',
				},
				'10000000000000' => {
					'other' => 'ကုဋေ 0 သန်း',
				},
				'100000000000000' => {
					'other' => '0 ကောဋိ',
				},
			},
			'short' => {
				'1000' => {
					'other' => '0 ထောင်',
				},
				'10000' => {
					'other' => '0 သောင်း',
				},
				'100000' => {
					'other' => '0 သိန်း',
				},
				'1000000' => {
					'other' => '0 သန်း',
				},
				'10000000' => {
					'other' => '0 ကုဋေ',
				},
				'100000000' => {
					'other' => '00 ကုဋေ',
				},
				'1000000000' => {
					'other' => '000 ဋေ',
				},
				'10000000000' => {
					'other' => 'ဋေ 0 ထ',
				},
				'100000000000' => {
					'other' => 'ဋေ 0 သ',
				},
				'1000000000000' => {
					'other' => 'ဋေ 0 သိန်း',
				},
				'10000000000000' => {
					'other' => 'ဋေ 0 သန်း',
				},
				'100000000000000' => {
					'other' => '0 ကောဋိ',
				},
			},
		},
} },
);

has 'number_currency_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'latn' => {
			'pattern' => {
				'default' => {
					'accounting' => {
						'positive' => '¤ #,##0.00',
					},
					'standard' => {
						'positive' => '#,##0.00 ¤',
					},
				},
			},
		},
} },
);

has 'currencies' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'AED' => {
			display_name => {
				'currency' => q(အာရပ်စော်ဘွားများ ပြည်ထောင်စု ဒါဟမ်း),
			},
		},
		'AFN' => {
			display_name => {
				'currency' => q(အာဖဂန် အာဖဂါနီ),
			},
		},
		'ALL' => {
			display_name => {
				'currency' => q(အယ်ဘေးနီးယား လီခ်),
			},
		},
		'AMD' => {
			display_name => {
				'currency' => q(အာမေးနီးယား ဒရမ်),
			},
		},
		'ANG' => {
			symbol => 'NAf',
			display_name => {
				'currency' => q(နယ်သာလန် အန်တီလန် ဂင်းဒါး),
			},
		},
		'AOA' => {
			display_name => {
				'currency' => q(အန်ဂိုလာ ကွမ်ဇာ),
			},
		},
		'ARP' => {
			display_name => {
				'currency' => q(အာဂျင်တီးနား ပီဆို \(၁၉၈၃–၁၉၈၅\)),
			},
		},
		'ARS' => {
			display_name => {
				'currency' => q(အာဂျင်တီးနား ပီဆို),
			},
		},
		'AUD' => {
			display_name => {
				'currency' => q(ဩစတြေးလျ ဒေါ်လာ),
			},
		},
		'AWG' => {
			symbol => 'Afl',
			display_name => {
				'currency' => q(အရူးဗာ ဖလိုရင်း),
			},
		},
		'AZN' => {
			display_name => {
				'currency' => q(အဇာဘိုင်ဂျန် မာနတ်),
			},
		},
		'BAM' => {
			display_name => {
				'currency' => q(ဘော့စနီးယားနှင့် ဟာဇီဂိုဘီးနား ငွေလဲနိုင်သော မတ်က်),
				'other' => q(ဘော့စနီးယားနှင့် ဟာဇီဂိုဘီးနားမတ်က်),
			},
		},
		'BBD' => {
			symbol => 'Bds$',
			display_name => {
				'currency' => q(ဘာဘေးဒိုးစ် ဒေါ်လာ),
			},
		},
		'BDT' => {
			display_name => {
				'currency' => q(ဘင်္ဂလားဒေ့ရှ် တာကာ),
			},
		},
		'BEF' => {
			display_name => {
				'currency' => q(ဘယ်လ်ဂျီယမ် ဖရန့်),
			},
		},
		'BGN' => {
			display_name => {
				'currency' => q(ဘူလ်ဂေးရီးယား လက်ဖ်),
			},
		},
		'BHD' => {
			display_name => {
				'currency' => q(ဘာရိန်း ဒီနား),
			},
		},
		'BIF' => {
			display_name => {
				'currency' => q(ဘူရွန်ဒီ ဖရန့်),
			},
		},
		'BMD' => {
			display_name => {
				'currency' => q(ဘာမြူဒါ ဒေါ်လာ),
			},
		},
		'BND' => {
			display_name => {
				'currency' => q(ဘရူနိုင်း ဒေါ်လာ),
			},
		},
		'BOB' => {
			display_name => {
				'currency' => q(ဘိုလီးဗီးယား ဘိုလီးဗီယားနို),
			},
		},
		'BOP' => {
			display_name => {
				'currency' => q(ဘိုလီးဘီးယား ပီဆို),
			},
		},
		'BRL' => {
			display_name => {
				'currency' => q(ဘရာဇီး ရီးယဲ),
			},
		},
		'BSD' => {
			symbol => 'B$',
			display_name => {
				'currency' => q(ဘဟားမား ဒေါ်လာ),
			},
		},
		'BTN' => {
			display_name => {
				'currency' => q(ဘူတန် အံဂါလ်ထရန်),
			},
		},
		'BUK' => {
			display_name => {
				'currency' => q(ဗမာ ကျပ်),
			},
		},
		'BWP' => {
			display_name => {
				'currency' => q(ဘော့ဆွာနာ ပုလ),
			},
		},
		'BYB' => {
			display_name => {
				'currency' => q(ဘီလာရုစ် ရူဘယ်အသစ် \(၁၉၉၄–၁၉၉၉\)),
			},
		},
		'BYN' => {
			symbol => 'р.',
			display_name => {
				'currency' => q(ဘီလာရုစ် ရူဘယ်),
			},
		},
		'BYR' => {
			display_name => {
				'currency' => q(ဘီလာရုဇ် ရူဘယ် \(၂၀၀၀–၂၀၁၆\)),
			},
		},
		'BZD' => {
			display_name => {
				'currency' => q(ဘလိဇ် ဒေါ်လာ),
			},
		},
		'CAD' => {
			display_name => {
				'currency' => q(ကနေဒါ ဒေါ်လာ),
			},
		},
		'CDF' => {
			display_name => {
				'currency' => q(ကွန်ဂို ဖရန့်),
			},
		},
		'CHF' => {
			display_name => {
				'currency' => q(ဆွစ် ဖရန့်),
			},
		},
		'CLP' => {
			display_name => {
				'currency' => q(ချီလီ ပီဆို),
			},
		},
		'CNH' => {
			display_name => {
				'currency' => q(တရုတ် ယွမ် \(ဟောင်ကောင်\)),
			},
		},
		'CNY' => {
			display_name => {
				'currency' => q(တရုတ် ယွမ်),
			},
		},
		'COP' => {
			display_name => {
				'currency' => q(ကိုလံဘီယာ ပီဆို),
			},
		},
		'CRC' => {
			display_name => {
				'currency' => q(ကို့စတာရီကာ ကိုလွန်),
			},
		},
		'CUC' => {
			display_name => {
				'currency' => q(နိုင်ငံခြားငွေလဲလှယ်နိုင်သော ကျူးဘားပီဆို),
			},
		},
		'CUP' => {
			display_name => {
				'currency' => q(ကျူးဘား ပီဆို),
			},
		},
		'CVE' => {
			display_name => {
				'currency' => q(ကိတ်ပ်ဗာဒီ အက်စ်ခူဒို),
			},
		},
		'CYP' => {
			display_name => {
				'currency' => q(ဆိုက်ပရက်စ် ပေါင်),
			},
		},
		'CZK' => {
			display_name => {
				'currency' => q(ချက် ခိုရိုနာ),
			},
		},
		'DEM' => {
			display_name => {
				'currency' => q(ဂျာမဏီ မတ်),
			},
		},
		'DJF' => {
			display_name => {
				'currency' => q(ဂျီဘူတီ ဖရန့်),
			},
		},
		'DKK' => {
			display_name => {
				'currency' => q(ဒိန်းမတ် ခရိုဏာ),
			},
		},
		'DOP' => {
			display_name => {
				'currency' => q(ဒိုမီနီကန် ပီဆို),
			},
		},
		'DZD' => {
			display_name => {
				'currency' => q(အယ်လ်ဂျီးရီးယား ဒီနာ),
			},
		},
		'EGP' => {
			display_name => {
				'currency' => q(အီဂျစ် ပေါင်),
			},
		},
		'ERN' => {
			display_name => {
				'currency' => q(အီရီထရီးယား နာ့ခ်ဖာ),
			},
		},
		'ESP' => {
			display_name => {
				'currency' => q(စပိန် ပယ်စေးတာ),
			},
		},
		'ETB' => {
			display_name => {
				'currency' => q(အီသီယိုးပီးယား ဘီးယာ),
			},
		},
		'EUR' => {
			display_name => {
				'currency' => q(ယူရို),
			},
		},
		'FJD' => {
			display_name => {
				'currency' => q(ဖီဂျီ ဒေါ်လာ),
			},
		},
		'FKP' => {
			display_name => {
				'currency' => q(ဖော့ကလန်ကျွန်းစု ပေါင်),
			},
		},
		'FRF' => {
			display_name => {
				'currency' => q(ပြင်သစ် ဖရန့်),
			},
		},
		'GBP' => {
			display_name => {
				'currency' => q(ဗြိတိသျှ ပေါင်),
			},
		},
		'GEL' => {
			display_name => {
				'currency' => q(ဂျော်ဂျီယာ လားရီ),
			},
		},
		'GHS' => {
			display_name => {
				'currency' => q(ဂါနာ ဆဲဒီ),
			},
		},
		'GIP' => {
			display_name => {
				'currency' => q(ဂျီဘရော်လ်တာ ပေါင်),
			},
		},
		'GMD' => {
			display_name => {
				'currency' => q(ဂမ်ဘီယာ ဒါလာစီ),
			},
		},
		'GNF' => {
			display_name => {
				'currency' => q(ဂီနီရာ ဖရန့်),
			},
		},
		'GTQ' => {
			display_name => {
				'currency' => q(ဂွါတီမာလာ ခက်ဇော်လ်),
			},
		},
		'GYD' => {
			display_name => {
				'currency' => q(ဂိုင်ယာနာ ဒေါ်လာ),
			},
		},
		'HKD' => {
			display_name => {
				'currency' => q(ဟောင်ကောင် ဒေါ်လာ),
			},
		},
		'HNL' => {
			display_name => {
				'currency' => q(ဟွန်ဒူးရပ်စ် လမ်းပီရာ),
			},
		},
		'HRK' => {
			display_name => {
				'currency' => q(ခရိုအေးရှား ခူးနာ),
			},
		},
		'HTG' => {
			symbol => 'G',
			display_name => {
				'currency' => q(ဟေတီဂူးအော်ဒ်),
			},
		},
		'HUF' => {
			display_name => {
				'currency' => q(ဟန်ဂေရီယံ ဖော်ရင့်တ်),
			},
		},
		'IDR' => {
			display_name => {
				'currency' => q(အင်ဒိုနီးရှား ရူပီးယား),
			},
		},
		'ILP' => {
			display_name => {
				'currency' => q(အစ္စရေး ပေါင်),
			},
		},
		'ILS' => {
			display_name => {
				'currency' => q(အစ္စရေး ရှဲကလ်အသစ်),
			},
		},
		'INR' => {
			display_name => {
				'currency' => q(အိန္ဒိယ ရူပီး),
			},
		},
		'IQD' => {
			display_name => {
				'currency' => q(အီရတ် ဒီနာ),
			},
		},
		'IRR' => {
			display_name => {
				'currency' => q(အီရန် ရီအော်လ်),
			},
		},
		'ISK' => {
			display_name => {
				'currency' => q(အိုက်စလန် ခရိုဏာ),
			},
		},
		'JMD' => {
			display_name => {
				'currency' => q(ဂျမေကာ ဒေါ်လာ),
			},
		},
		'JOD' => {
			display_name => {
				'currency' => q(ဂျော်ဒန် ဒီနာ),
			},
		},
		'JPY' => {
			display_name => {
				'currency' => q(ဂျပန် ယန်း),
			},
		},
		'KES' => {
			display_name => {
				'currency' => q(ကင်ညာ သျှီလင်),
			},
		},
		'KGS' => {
			display_name => {
				'currency' => q(ကာဂျစ္စတန် ဆော်မ်),
			},
		},
		'KHR' => {
			display_name => {
				'currency' => q(ကမ္ဘောဒီးယား ရီးယဲ),
			},
		},
		'KMF' => {
			display_name => {
				'currency' => q(ကိုမိုရိုစ် ဖရန့်),
			},
		},
		'KPW' => {
			display_name => {
				'currency' => q(မြောက်ကိုရီးယား ဝမ်),
			},
		},
		'KRW' => {
			display_name => {
				'currency' => q(တောင်ကိုရီးယား ဝမ်),
			},
		},
		'KWD' => {
			display_name => {
				'currency' => q(ကူဝိတ် ဒီနာ),
			},
		},
		'KYD' => {
			display_name => {
				'currency' => q(ကေမန် ကျွန်းစု ဒေါ်လာ),
			},
		},
		'KZT' => {
			display_name => {
				'currency' => q(ကာဇက်စတန် ထိန်ဂျီ),
			},
		},
		'LAK' => {
			display_name => {
				'currency' => q(လာအို ကစ်),
			},
		},
		'LBP' => {
			display_name => {
				'currency' => q(လက်ဘနွန် ပေါင်),
			},
		},
		'LKR' => {
			display_name => {
				'currency' => q(သီရိလင်္ကာ ရူပီး),
			},
		},
		'LRD' => {
			display_name => {
				'currency' => q(လိုက်ဘေးရီးယား ဒေါ်လာ),
			},
		},
		'LSL' => {
			display_name => {
				'currency' => q(လီဆိုသို လိုတီ),
				'other' => q(လီဆိုသို လိုတီစ်),
			},
		},
		'LTL' => {
			display_name => {
				'currency' => q(လစ်သူယေးနီးယားလီတားစ်),
			},
		},
		'LVL' => {
			display_name => {
				'currency' => q(လတ်ဗီးယားလတ်),
			},
		},
		'LYD' => {
			display_name => {
				'currency' => q(လစ်ဗျား ဒိုင်နာ),
			},
		},
		'MAD' => {
			display_name => {
				'currency' => q(မိုရိုကို ဒရမ်),
			},
		},
		'MDL' => {
			display_name => {
				'currency' => q(မောလ်ဒိုဗာ လယ်အို),
			},
		},
		'MGA' => {
			display_name => {
				'currency' => q(မာလာဂါစီ အရီရရီ),
			},
		},
		'MKD' => {
			display_name => {
				'currency' => q(မက်ဆီဒိုးနီးယား ဒီနာ),
			},
		},
		'MMK' => {
			symbol => 'K',
			display_name => {
				'currency' => q(မြန်မာ ကျပ်),
			},
		},
		'MNT' => {
			display_name => {
				'currency' => q(မွန်ဂိုးလီးယား ထူးဂရခ်),
			},
		},
		'MOP' => {
			display_name => {
				'currency' => q(မကာအို ပါတားကား),
			},
		},
		'MRO' => {
			display_name => {
				'currency' => q(မော်ရီတေးနီးယား အူဂီးယာ \(၁၉၇၃–၂၀၁၇\)),
			},
		},
		'MRU' => {
			display_name => {
				'currency' => q(မော်ရီတေးနီးယန်း အူဂီးယာ),
			},
		},
		'MUR' => {
			display_name => {
				'currency' => q(မောရစ်ရှ ရူပီး),
			},
		},
		'MVR' => {
			display_name => {
				'currency' => q(မော်လ်ဒိုက် ရူးဖီရာ),
			},
		},
		'MWK' => {
			display_name => {
				'currency' => q(မာလာဝီ ခွါးချာ),
			},
		},
		'MXN' => {
			display_name => {
				'currency' => q(မက်ကဆီကို ပီဆို),
			},
		},
		'MYR' => {
			display_name => {
				'currency' => q(မလေးရှား ရင်းဂစ်),
			},
		},
		'MZN' => {
			display_name => {
				'currency' => q(မိုဇမ်ဘစ် မက်တီခယ်လ်),
			},
		},
		'NAD' => {
			display_name => {
				'currency' => q(နမီးဘီးယား ဒေါ်လာ),
			},
		},
		'NGN' => {
			display_name => {
				'currency' => q(နိုင်ဂျီးရီးယား နိုင်းရာ),
			},
		},
		'NIO' => {
			display_name => {
				'currency' => q(နီကာရာဂွါ ခိုးဒိုဘာ),
			},
		},
		'NOK' => {
			display_name => {
				'currency' => q(နော်ဝေ ခရိုဏာ),
			},
		},
		'NPR' => {
			display_name => {
				'currency' => q(နီပေါ ရူပီး),
			},
		},
		'NZD' => {
			display_name => {
				'currency' => q(နယူးဇီလန် ဒေါ်လာ),
			},
		},
		'OMR' => {
			display_name => {
				'currency' => q(အိုမန်နီ ရီရယ်),
			},
		},
		'PAB' => {
			symbol => 'B/.',
			display_name => {
				'currency' => q(ပနားမား ဘလျဘိုးအာ),
			},
		},
		'PEN' => {
			display_name => {
				'currency' => q(ပီရူး ဆိုးလ်),
			},
		},
		'PGK' => {
			display_name => {
				'currency' => q(ပါပူအာ နယူးဂီနီ ခီးနာ),
			},
		},
		'PHP' => {
			display_name => {
				'currency' => q(ဖိလစ်ပိုင် ပီဆို),
			},
		},
		'PKR' => {
			display_name => {
				'currency' => q(ပါကစ္စတန် ရူပီး),
			},
		},
		'PLN' => {
			display_name => {
				'currency' => q(ပိုလန် ဇလော့တီ),
			},
		},
		'PYG' => {
			display_name => {
				'currency' => q(ပါရာဂွေး ဂွါးအ်နီး),
			},
		},
		'QAR' => {
			display_name => {
				'currency' => q(ကာတာရီ ရီရယ်),
			},
		},
		'RON' => {
			display_name => {
				'currency' => q(ရိုမေးနီးယား လယ်အို),
			},
		},
		'RSD' => {
			display_name => {
				'currency' => q(ဆားဘီးယား ဒယ်နား),
			},
		},
		'RUB' => {
			display_name => {
				'currency' => q(ရုရှ ရူဘယ်),
			},
		},
		'RUR' => {
			display_name => {
				'currency' => q(ရုရှ ရူဘယ် \(၁၉၉၁–၁၉၉၈\)),
			},
		},
		'RWF' => {
			display_name => {
				'currency' => q(ရဝန်ဒါ ဖရန့်),
			},
		},
		'SAR' => {
			display_name => {
				'currency' => q(ဆော်ဒီအာရေးဗီးယား ရီယော်လ်),
			},
		},
		'SBD' => {
			display_name => {
				'currency' => q(ဆော်လမွန်ကျွန်းစု ဒေါ်လာ),
			},
		},
		'SCR' => {
			display_name => {
				'currency' => q(ဆေးရှဲ ရူပီး),
			},
		},
		'SDG' => {
			display_name => {
				'currency' => q(ဆူဒန် ပေါင်),
			},
		},
		'SDP' => {
			display_name => {
				'currency' => q(ဆူဒန် ပေါင်အဟောင်း),
			},
		},
		'SEK' => {
			display_name => {
				'currency' => q(ဆွီဒင် ခရိုဏာ),
			},
		},
		'SGD' => {
			display_name => {
				'currency' => q(စင်္ကာပူ ဒေါ်လာ),
			},
		},
		'SHP' => {
			display_name => {
				'currency' => q(စိန့်ဟယ်လယ်နာ ပေါင်),
			},
		},
		'SLE' => {
			display_name => {
				'currency' => q(ဆီယာရာလီယွန်း လီအိုနီ),
			},
		},
		'SLL' => {
			display_name => {
				'currency' => q(ဆီယာရာလီယွန်း လီအိုနီ \(၁၉၆၄—၂၀၂၂\)),
				'other' => q(ဆီယာရာလီယွန်း လီအိုနီ \(၁၉၆၄—၂၀၂၂\)),
			},
		},
		'SOS' => {
			display_name => {
				'currency' => q(ဆိုမာလီ သျှီလင်),
			},
		},
		'SRD' => {
			display_name => {
				'currency' => q(ဆူရီနမ်း ဒေါ်လာ),
			},
		},
		'SSP' => {
			display_name => {
				'currency' => q(တောင်ဆူဒန် ပေါင်),
			},
		},
		'STD' => {
			display_name => {
				'currency' => q(ဆောင်တူမေးနှင့် ပရင်စီပီ ဒိုဘရာ),
			},
		},
		'STN' => {
			display_name => {
				'currency' => q(ဆောင်တူမေးနှင့် ပရင်စီပီ ဒိုဘရာ \(၂၀၁၈\)),
				'other' => q(ဆောင်တူမေးနှင့် ပရင်စီပီ ဒိုဘရာစ် \(၂၀၁၈\)),
			},
		},
		'SUR' => {
			display_name => {
				'currency' => q(ဆိုဗီယက် ရူဗယ်),
			},
		},
		'SYP' => {
			display_name => {
				'currency' => q(ဆီးရီးယား ပေါင်),
			},
		},
		'SZL' => {
			display_name => {
				'currency' => q(ဆွာဇီလန် လီလန်းဂီနီ),
			},
		},
		'THB' => {
			symbol => '฿',
			display_name => {
				'currency' => q(ထိုင်း ဘတ်),
			},
		},
		'TJS' => {
			display_name => {
				'currency' => q(တာဂျစ်ကစ္စတန် ဆိုမိုနီ),
			},
		},
		'TMT' => {
			display_name => {
				'currency' => q(တာ့ခ်မင်နစ္စတန် မာနတ်),
			},
		},
		'TND' => {
			display_name => {
				'currency' => q(တူနီးရှား ဒိုင်နာ),
			},
		},
		'TOP' => {
			display_name => {
				'currency' => q(တွန်ဂါ ဗန်ဂါ),
			},
		},
		'TRL' => {
			display_name => {
				'currency' => q(ရှေးဟောင်းတူရကီ လိုင်ရာ),
			},
		},
		'TRY' => {
			display_name => {
				'currency' => q(တူရကီ လိုင်ရာ),
			},
		},
		'TTD' => {
			symbol => 'TT$',
			display_name => {
				'currency' => q(ထရီနီဒတ်နှင့် တိုဘက်ဂို ဒေါ်လာ),
			},
		},
		'TWD' => {
			display_name => {
				'currency' => q(ထိုင်ဝမ် ဒေါ်လာအသစ်),
			},
		},
		'TZS' => {
			display_name => {
				'currency' => q(တန်ဇန်းနီးယား သျှီလင်),
			},
		},
		'UAH' => {
			display_name => {
				'currency' => q(ယူကရိန်း ဟီရီဗင်းညား),
			},
		},
		'UGX' => {
			display_name => {
				'currency' => q(ယူဂန္ဒာ သျှီလင်),
			},
		},
		'USD' => {
			display_name => {
				'currency' => q(အမေရိကန် ဒေါ်လာ),
			},
		},
		'USN' => {
			display_name => {
				'currency' => q(အမေရိကန် ဒေါ်လာ \(နောက်နေ့\)),
			},
		},
		'USS' => {
			display_name => {
				'currency' => q(အမေရိကန် ဒေါ်လာ \(တနေ့တည်း\)),
			},
		},
		'UYU' => {
			display_name => {
				'currency' => q(ဥရုဂွေး ပီဆို),
			},
		},
		'UZS' => {
			display_name => {
				'currency' => q(ဥဇဘက်ကစ္စတန် ဆော်မ်),
			},
		},
		'VEF' => {
			display_name => {
				'currency' => q(ဗင်နီဇွဲလား ဘိုလီဗာ \(၂၀၀၈–၂၀၁၈\)),
			},
		},
		'VES' => {
			display_name => {
				'currency' => q(ဗင်နီဇွဲလန်း ဘိုလီဗာ),
			},
		},
		'VND' => {
			display_name => {
				'currency' => q(ဗီယက်နမ် ဒေါင်),
			},
		},
		'VUV' => {
			display_name => {
				'currency' => q(ဗနွားတူ ဗားထူ),
			},
		},
		'WST' => {
			display_name => {
				'currency' => q(ဆမိုအား ထားလာ),
			},
		},
		'XAF' => {
			display_name => {
				'currency' => q(ကင်မရွန်း ဖရန့်),
			},
		},
		'XAG' => {
			display_name => {
				'currency' => q(ငွေ),
			},
		},
		'XAU' => {
			display_name => {
				'currency' => q(ရွှေ),
			},
		},
		'XBB' => {
			display_name => {
				'currency' => q(ဥရောပငွေကြေးစံနစ်),
			},
		},
		'XCD' => {
			display_name => {
				'currency' => q(အရှေ့ကာရစ်ဘီယံ ဒေါ်လာ),
			},
		},
		'XDR' => {
			display_name => {
				'currency' => q(အထူးထုတ်ယူခွင့်),
			},
		},
		'XOF' => {
			display_name => {
				'currency' => q(အနောက် အာဖရိက [CFA ]ဖရန့်),
				'other' => q(အနောက် အာဖရိက [CFA] ဖရန့်),
			},
		},
		'XPF' => {
			display_name => {
				'currency' => q([CFP] ဖရန့်),
			},
		},
		'XPT' => {
			display_name => {
				'currency' => q(ပလက်တီနမ်),
			},
		},
		'XTS' => {
			display_name => {
				'currency' => q(စမ်းသပ် ငွေကြေး ကုဒ်),
			},
		},
		'XXX' => {
			display_name => {
				'currency' => q(မသိသို့မဟုတ်မရှိသောငွေကြေး),
				'other' => q(\(မသိသို့မဟုတ်မရှိသောငွေကြေး\)),
			},
		},
		'YER' => {
			display_name => {
				'currency' => q(ယီမင်နီ ရီရယ်),
			},
		},
		'ZAR' => {
			display_name => {
				'currency' => q(တောင်အာဖရိက ရန်း),
			},
		},
		'ZMW' => {
			display_name => {
				'currency' => q(ဇင်ဘာဘွေ ခွါးချာ),
			},
		},
		'ZWD' => {
			display_name => {
				'currency' => q(ဇင်ဘာဘွေ ဒေါ်လာ),
			},
		},
	} },
);


has 'calendar_months' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {
						nonleap => [
							'ဇန်',
							'ဖေ',
							'မတ်',
							'ဧ',
							'မေ',
							'ဇွန်',
							'ဇူ',
							'ဩ',
							'စက်',
							'အောက်',
							'နို',
							'ဒီ'
						],
						leap => [
							
						],
					},
					wide => {
						nonleap => [
							'ဇန်နဝါရီ',
							'ဖေဖော်ဝါရီ',
							'မတ်',
							'ဧပြီ',
							'မေ',
							'ဇွန်',
							'ဇူလိုင်',
							'ဩဂုတ်',
							'စက်တင်ဘာ',
							'အောက်တိုဘာ',
							'နိုဝင်ဘာ',
							'ဒီဇင်ဘာ'
						],
						leap => [
							
						],
					},
				},
				'stand-alone' => {
					narrow => {
						nonleap => [
							'ဇ',
							'ဖ',
							'မ',
							'ဧ',
							'မ',
							'ဇ',
							'ဇ',
							'ဩ',
							'စ',
							'အ',
							'န',
							'ဒ'
						],
						leap => [
							
						],
					},
				},
			},
	} },
);

has 'calendar_days' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					short => {
						mon => 'လာ',
						tue => 'ဂါ',
						wed => 'ဟူး',
						thu => 'တေး',
						fri => 'ကြာ',
						sat => 'နေ',
						sun => 'နွေ'
					},
					wide => {
						mon => 'တနင်္လာ',
						tue => 'အင်္ဂါ',
						wed => 'ဗုဒ္ဓဟူး',
						thu => 'ကြာသပတေး',
						fri => 'သောကြာ',
						sat => 'စနေ',
						sun => 'တနင်္ဂနွေ'
					},
				},
				'stand-alone' => {
					narrow => {
						mon => 'တ',
						tue => 'အ',
						wed => 'ဗ',
						thu => 'က',
						fri => 'သ',
						sat => 'စ',
						sun => 'တ'
					},
					short => {
						mon => 'လာ',
						tue => 'ဂါ',
						wed => 'ဟူး',
						thu => 'တေး',
						fri => 'ကြာ',
						sat => 'နေ',
						sun => 'နွေ'
					},
				},
			},
	} },
);

has 'calendar_quarters' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {0 => 'Q1',
						1 => 'Q2',
						2 => 'Q3',
						3 => 'Q4'
					},
					wide => {0 => 'ပထမ သုံးလပတ်',
						1 => 'ဒုတိယ သုံးလပတ်',
						2 => 'တတိယ သုံးလပတ်',
						3 => 'စတုတ္ထ သုံးလပတ်'
					},
				},
				'stand-alone' => {
					abbreviated => {0 => 'Q1',
						1 => 'Q2',
						2 => 'Q3',
						3 => 'Q4'
					},
					narrow => {0 => 'ပ',
						1 => 'ဒု',
						2 => 'တ',
						3 => 'စ'
					},
				},
			},
	} },
);

has 'day_period_data' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub { sub {
		# Time in hhmm format
		my ($self, $type, $time, $day_period_type) = @_;
		$day_period_type //= 'default';
		SWITCH:
		for ($type) {
			if ($_ eq 'generic') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'noon' if $time == 1200;
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 1900;
					return 'morning1' if $time >= 0
						&& $time < 1200;
					return 'night1' if $time >= 1900
						&& $time < 2400;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 1900;
					return 'morning1' if $time >= 0
						&& $time < 1200;
					return 'night1' if $time >= 1900
						&& $time < 2400;
				}
				last SWITCH;
				}
			if ($_ eq 'gregorian') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'noon' if $time == 1200;
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 1900;
					return 'morning1' if $time >= 0
						&& $time < 1200;
					return 'night1' if $time >= 1900
						&& $time < 2400;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 1900;
					return 'morning1' if $time >= 0
						&& $time < 1200;
					return 'night1' if $time >= 1900
						&& $time < 2400;
				}
				last SWITCH;
				}
		}
	} },
);

around day_period_data => sub {
    my ($orig, $self) = @_;
    return $self->$orig;
};

has 'day_periods' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'gregorian' => {
			'format' => {
				'abbreviated' => {
					'afternoon1' => q{နေ့လယ်},
					'am' => q{နံနက်},
					'evening1' => q{ညနေ},
					'midnight' => q{သန်းခေါင်ယံ},
					'morning1' => q{နံနက်},
					'night1' => q{ည},
					'noon' => q{မွန်းတည့်},
					'pm' => q{ညနေ},
				},
			},
		},
	} },
);

has 'eras' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
		},
		'gregorian' => {
			abbreviated => {
				'0' => 'ဘီစီ',
				'1' => 'အဒေီ'
			},
			wide => {
				'0' => 'ခရစ်တော် မပေါ်မီနှစ်',
				'1' => 'ခရစ်နှစ်'
			},
		},
	} },
);

has 'date_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			'full' => q{EEEE G dd MMMM y},
			'long' => q{G dd MMMM y},
			'medium' => q{G d MMM y},
			'short' => q{GGGGG d/M/y},
		},
		'gregorian' => {
			'full' => q{y MMMM d EEEE},
			'long' => q{y MMMM d},
			'medium' => q{y MMM d},
			'short' => q{d/M/yy},
		},
	} },
);

has 'time_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
		},
		'gregorian' => {
			'full' => q{zzzz HH:mm:ss},
			'long' => q{z HH:mm:ss},
			'medium' => q{H:mm:ss},
			'short' => q{H:mm},
		},
	} },
);

has 'datetime_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			'full' => q{{1} {0}},
			'long' => q{{1} {0}},
			'medium' => q{{1} {0}},
			'short' => q{{1} {0}},
		},
		'gregorian' => {
			'full' => q{{1} {0}},
			'long' => q{{1} {0}},
			'medium' => q{{1} {0}},
			'short' => q{{1} {0}},
		},
	} },
);

has 'datetime_formats_available_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			Bh => q{B h},
			Bhm => q{B h:mm},
			Bhms => q{B h:mm:ss},
			EBhm => q{E B h:mm},
			EBhms => q{E B h:mm:ss},
			Ed => q{d E},
			Ehm => q{E a h:mm},
			Ehms => q{E a h:mm:ss},
			GyMMMd => q{G d MMM y},
			GyMd => q{GGGGG y/M/d},
			MMMEd => q{MMM d E},
			MMMMEd => q{MMMM d Eနေ့},
			Md => q{d/M},
			h => q{a h},
			hm => q{a h:mm},
			hms => q{a h:mm:ss},
			yyyyM => q{G M/y},
			yyyyMMMd => q{G d MMM y},
			yyyyMd => q{GGGGG dd/MM/Y},
		},
		'gregorian' => {
			Bh => q{B h},
			Bhm => q{B h:mm},
			Bhms => q{B h:mm:ss},
			EBhm => q{E B h:mm},
			EBhms => q{E B h:mm:ss},
			Ed => q{d ရက် E},
			Ehm => q{E a h:mm},
			Ehms => q{E a h:mm:ss},
			GyMMMEd => q{G y/ MMM d/ E},
			GyMd => q{G y/M/d},
			Hmsv => q{v HH:mm:ss},
			Hmv => q{v HH:mm},
			MEd => q{d/M E},
			MMMEd => q{MMM d E},
			MMMMEd => q{MMMM d E},
			MMMMW => q{MMMM လ W ပတ်မြောက်},
			Md => q{d/M},
			h => q{a h},
			hm => q{a h:mm},
			hms => q{a h:mm:ss},
			hmsv => q{v a h:mm:ss},
			hmv => q{v a h:mm},
			yMEd => q{d/M/y E},
			yMMMEd => q{y MMM d E},
			yMd => q{d/M/y},
			yw => q{Y ခု w ပတ်မြောက်},
		},
	} },
);

has 'datetime_formats_append_item' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'gregorian' => {
			'Timezone' => '{1} {0}',
		},
	} },
);

has 'datetime_formats_interval' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			Bh => {
				h => q{h – h B},
			},
			Bhm => {
				h => q{h:mm – h:mm B},
				m => q{h:mm – h:mm B},
			},
			Gy => {
				y => q{G y – y},
			},
			GyM => {
				G => q{GGGGG y/M – GGGGG y/M},
			},
			M => {
				M => q{M – M},
			},
			MEd => {
				M => q{d/M Eနေ့ – d/M Eနေ့},
				d => q{d/M Eနေ့ – d/M Eနေ့},
			},
			MMM => {
				M => q{MMMM – MMMM},
			},
			MMMEd => {
				M => q{d MMM Eနေ့ – d MMM Eနေ့},
				d => q{d MMM Eနေ့ – d MMM Eနေ့},
			},
			MMMd => {
				M => q{d MMM – d MMM},
				d => q{d –d MMM},
			},
			Md => {
				M => q{d/M – d/M},
				d => q{d/M – d/M},
			},
			d => {
				d => q{d – d},
			},
			fallback => '{0} – {1}',
			y => {
				y => q{G y – y},
			},
			yM => {
				M => q{GGGGG M/y – M/y},
				y => q{GGGGG M/y – M/y},
			},
			yMEd => {
				M => q{GGGGG d/M/y Eနေ့ – d/M/y Eနေ့},
				d => q{GGGGG d/M/y Eနေ့ – d/M/y Eနေ့},
				y => q{GGGGG d/M/y Eနေ့ – d/M/y Eနေ့},
			},
			yMMM => {
				M => q{G MMM y – MMM y},
				y => q{G MMM y – MMM y},
			},
			yMMMEd => {
				M => q{G y MMM d E – y MMM d E},
				d => q{G y MMM d E – y MMM d E},
				y => q{G y MMM d E – y MMM d E},
			},
			yMMMM => {
				M => q{G y MMMM – MMMM},
			},
			yMMMd => {
				d => q{G d – d MMM y},
			},
			yMd => {
				M => q{GGGGG d/M/y – d/M/y},
				d => q{GGGGG d/M/y – d/M/y},
				y => q{GGGGG d/M/y – d/M/y},
			},
		},
		'gregorian' => {
			Bh => {
				h => q{h – h B},
			},
			Bhm => {
				h => q{h:mm – h:mm B},
				m => q{h:mm – h:mm B},
			},
			Gy => {
				y => q{G y – y},
			},
			GyM => {
				G => q{G y/M – G y/M},
				M => q{G y/M – y/M},
				y => q{G y/M – y/M},
			},
			GyMEd => {
				G => q{G y/M/d E – G y/M/d E},
				M => q{G y/M/d E – y/M/d E},
				d => q{G y/M/d E – y/M/d E},
				y => q{G y/M/d E – y/M/d E},
			},
			GyMMMEd => {
				G => q{G y MMM d E – G y MMM d E},
				M => q{G y MMM d E – MMM d E},
				d => q{G y MMM d E – MMM d E},
				y => q{G y MMM d E – y MMM d E},
			},
			GyMMMd => {
				d => q{G y MMM d – d},
			},
			GyMd => {
				G => q{G y/M/d – G y/M/d},
				M => q{G y/M/d – y/M/d},
				d => q{G y/M/d – y/M/d},
				y => q{G y/M/d – y/M/d},
			},
			H => {
				H => q{HH – HH},
			},
			Hm => {
				H => q{HH:mm – HH:mm},
				m => q{HH:mm – HH:mm},
			},
			Hmv => {
				H => q{v HH:mm – HH:mm},
				m => q{v HH:mm – HH:mm},
			},
			Hv => {
				H => q{v HH – HH},
			},
			M => {
				M => q{M – M},
			},
			MEd => {
				M => q{d/M- EEEE – d/M- EEEE},
				d => q{d/M EEEE – d/M EEEE},
			},
			MMM => {
				M => q{MMM – MMM},
			},
			MMMEd => {
				M => q{MMM d E – MMM d E},
				d => q{MMM d E – MMM d E},
			},
			MMMd => {
				d => q{MMM d – d},
			},
			Md => {
				M => q{d/M – d/M},
				d => q{d/M – d/M},
			},
			d => {
				d => q{d – d},
			},
			fallback => '{0} – {1}',
			h => {
				a => q{a h – a h},
				h => q{a h – h},
			},
			hm => {
				a => q{a h:mm – a h:mm},
				h => q{a h:mm – h:mm},
				m => q{a h:mm – h:mm},
			},
			hmv => {
				a => q{v a h:mm – a h:mm},
				h => q{v a h:mm – h:mm},
				m => q{v a h:mm – h:mm},
			},
			hv => {
				a => q{v a h – a h},
				h => q{v a h – h},
			},
			y => {
				y => q{y – y},
			},
			yM => {
				M => q{M/y – M/y},
				y => q{M/y – M/y},
			},
			yMEd => {
				M => q{d/M/y EEEE – d/M/y EEEE},
				d => q{d/M/y EEE – d/M/y EEEE},
				y => q{d/M/y EEEE – d/M/y EEEE},
			},
			yMMM => {
				M => q{y MMM – MMM},
			},
			yMMMEd => {
				M => q{y MMM d EEEE – MMM d EEEE},
				d => q{y MMM d EEEE – MMM d EEEE},
				y => q{y MMM d EEEE – y MMM d EEEE},
			},
			yMMMM => {
				M => q{y MMMM – MMMM},
			},
			yMMMd => {
				d => q{y MMM d – d},
			},
			yMd => {
				M => q{d/M/y – d/M/y},
				d => q{d/M/y – d/M/y},
				y => q{d/M/y – d/M/y},
			},
		},
	} },
);

has 'time_zone_names' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default	=> sub { {
		regionFormat => q({0} အချိန်),
		regionFormat => q({0} နွေရာသီ စံတော်ချိန်),
		regionFormat => q({0} စံတော်ချိန်),
		'Afghanistan' => {
			long => {
				'standard' => q#အာဖဂန်နစ္စတန် အချိန်#,
			},
		},
		'Africa/Abidjan' => {
			exemplarCity => q#အာဘီဂျန်#,
		},
		'Africa/Accra' => {
			exemplarCity => q#အက်ကရာ#,
		},
		'Africa/Addis_Ababa' => {
			exemplarCity => q#အားဒစ် အဘာဘာ#,
		},
		'Africa/Algiers' => {
			exemplarCity => q#အယ်လ်ဂျီးရီးယား#,
		},
		'Africa/Asmera' => {
			exemplarCity => q#အားစ်မားရာ#,
		},
		'Africa/Bamako' => {
			exemplarCity => q#ဘာမာကို#,
		},
		'Africa/Bangui' => {
			exemplarCity => q#ဘာန်ဂီး#,
		},
		'Africa/Banjul' => {
			exemplarCity => q#ဘန်ဂျုးလ်#,
		},
		'Africa/Bissau' => {
			exemplarCity => q#ဘီစာအို#,
		},
		'Africa/Blantyre' => {
			exemplarCity => q#ဘလန်တိုင်းရဲလ်#,
		},
		'Africa/Brazzaville' => {
			exemplarCity => q#ဘရားဇာဗီးလ်#,
		},
		'Africa/Bujumbura' => {
			exemplarCity => q#ဘူဂျွန်ဘူးရာ#,
		},
		'Africa/Cairo' => {
			exemplarCity => q#ကိုင်ရို#,
		},
		'Africa/Casablanca' => {
			exemplarCity => q#ကာဆာဘလန်ကာ#,
		},
		'Africa/Ceuta' => {
			exemplarCity => q#ဆီရူးတာ#,
		},
		'Africa/Conakry' => {
			exemplarCity => q#ကိုနာကရီး#,
		},
		'Africa/Dakar' => {
			exemplarCity => q#ဒကျကား#,
		},
		'Africa/Dar_es_Salaam' => {
			exemplarCity => q#ဒါရက်စ်ဆာလမ်#,
		},
		'Africa/Djibouti' => {
			exemplarCity => q#ဂျီဘူတီ#,
		},
		'Africa/Douala' => {
			exemplarCity => q#ဒိုအူအာလာ#,
		},
		'Africa/El_Aaiun' => {
			exemplarCity => q#အယ်လ်အာယွန်း#,
		},
		'Africa/Freetown' => {
			exemplarCity => q#ဖရီးတောင်းန်#,
		},
		'Africa/Gaborone' => {
			exemplarCity => q#ဂါဘာရွန်းနီ#,
		},
		'Africa/Harare' => {
			exemplarCity => q#ဟာရားရဲယ်#,
		},
		'Africa/Johannesburg' => {
			exemplarCity => q#ဂျိုဟန်းနက်စဘတ်#,
		},
		'Africa/Juba' => {
			exemplarCity => q#ဂျုဘာ#,
		},
		'Africa/Kampala' => {
			exemplarCity => q#ကမ်ပါလာ#,
		},
		'Africa/Khartoum' => {
			exemplarCity => q#ခါတိုအန်#,
		},
		'Africa/Kigali' => {
			exemplarCity => q#ကီဂါးလီ#,
		},
		'Africa/Kinshasa' => {
			exemplarCity => q#ကင်ရှာစာ#,
		},
		'Africa/Lagos' => {
			exemplarCity => q#လာဂိုစ်#,
		},
		'Africa/Libreville' => {
			exemplarCity => q#လီဗရာဗီးလ်#,
		},
		'Africa/Lome' => {
			exemplarCity => q#လိုမီ#,
		},
		'Africa/Luanda' => {
			exemplarCity => q#လူဝမ်ဒါ#,
		},
		'Africa/Lubumbashi' => {
			exemplarCity => q#လူဘွန်းဘာရှီ#,
		},
		'Africa/Lusaka' => {
			exemplarCity => q#လူစာကာ#,
		},
		'Africa/Malabo' => {
			exemplarCity => q#မာလာဘို#,
		},
		'Africa/Maputo' => {
			exemplarCity => q#မာပူးတို#,
		},
		'Africa/Maseru' => {
			exemplarCity => q#မာဆူရူး#,
		},
		'Africa/Mbabane' => {
			exemplarCity => q#ဘားဘာန်း#,
		},
		'Africa/Mogadishu' => {
			exemplarCity => q#မော်ဂါဒီးသျုး#,
		},
		'Africa/Monrovia' => {
			exemplarCity => q#မွန်ရိုးဗီးယား#,
		},
		'Africa/Nairobi' => {
			exemplarCity => q#နိုင်ရိုဘီ#,
		},
		'Africa/Ndjamena' => {
			exemplarCity => q#အင်ဂျာမီနာ#,
		},
		'Africa/Niamey' => {
			exemplarCity => q#ညာမဲယ်#,
		},
		'Africa/Nouakchott' => {
			exemplarCity => q#နိုအာ့ခ်ရှော့တ်#,
		},
		'Africa/Ouagadougou' => {
			exemplarCity => q#ဝါဂါဒူးဂူ#,
		},
		'Africa/Porto-Novo' => {
			exemplarCity => q#ပိုတို-နိုဗို#,
		},
		'Africa/Sao_Tome' => {
			exemplarCity => q#ဆောင်တူမေး#,
		},
		'Africa/Tripoli' => {
			exemplarCity => q#ထရီပိုလီ#,
		},
		'Africa/Tunis' => {
			exemplarCity => q#တူနီစ်#,
		},
		'Africa/Windhoek' => {
			exemplarCity => q#ဗင်းဟူးခ်#,
		},
		'Africa_Central' => {
			long => {
				'standard' => q#အလယ်အာဖရိက အချိန်#,
			},
		},
		'Africa_Eastern' => {
			long => {
				'standard' => q#အရှေ့အာဖရိက အချိန်#,
			},
		},
		'Africa_Southern' => {
			long => {
				'standard' => q#တောင်အာဖရိက အချိန်#,
			},
		},
		'Africa_Western' => {
			long => {
				'daylight' => q#အနောက်အာဖရိက နွေရာသီ အချိန်#,
				'generic' => q#အနောက်အာဖရိက အချိန်#,
				'standard' => q#အနောက်အာဖရိက စံတော်ချိန်#,
			},
		},
		'Alaska' => {
			long => {
				'daylight' => q#အလာစကာ နွေရာသီ စံတော်ချိန်#,
				'generic' => q#အလာစကာ အချိန်#,
				'standard' => q#အလာစကာ စံတော်ချိန်#,
			},
		},
		'Amazon' => {
			long => {
				'daylight' => q#အမေဇုံ နွေရာသီအချိန်#,
				'generic' => q#အမေဇုံ အချိန်#,
				'standard' => q#အမေဇုံ စံတော်ချိန်#,
			},
		},
		'America/Adak' => {
			exemplarCity => q#အာဒချ#,
		},
		'America/Anchorage' => {
			exemplarCity => q#အန်ကာရေ့ဂျ်#,
		},
		'America/Anguilla' => {
			exemplarCity => q#အန်ဂီလာ#,
		},
		'America/Antigua' => {
			exemplarCity => q#အန်တီဂွါ#,
		},
		'America/Araguaina' => {
			exemplarCity => q#အာရာဂွါအီနာ#,
		},
		'America/Argentina/La_Rioja' => {
			exemplarCity => q#လာ ရီယိုဟာ#,
		},
		'America/Argentina/Rio_Gallegos' => {
			exemplarCity => q#ရီယို ဂါလီဂိုစ်#,
		},
		'America/Argentina/Salta' => {
			exemplarCity => q#ဆာလ်တာ#,
		},
		'America/Argentina/San_Juan' => {
			exemplarCity => q#ဆန် ဂွမ်#,
		},
		'America/Argentina/San_Luis' => {
			exemplarCity => q#ဆန် လူဝီစ်#,
		},
		'America/Argentina/Tucuman' => {
			exemplarCity => q#တူကူမန်#,
		},
		'America/Argentina/Ushuaia' => {
			exemplarCity => q#ဥဆွာအီအာ#,
		},
		'America/Aruba' => {
			exemplarCity => q#အာရူးဗာ#,
		},
		'America/Asuncion' => {
			exemplarCity => q#အာဆူစီအွန်း#,
		},
		'America/Bahia' => {
			exemplarCity => q#ဘာဟီအာ#,
		},
		'America/Bahia_Banderas' => {
			exemplarCity => q#ဘာဟီအာ ဘန်ဒရက်စ်#,
		},
		'America/Barbados' => {
			exemplarCity => q#ဘာဘေးဒိုးစ်#,
		},
		'America/Belem' => {
			exemplarCity => q#ဘီလင်မ်#,
		},
		'America/Belize' => {
			exemplarCity => q#ဘလိဇ်#,
		},
		'America/Blanc-Sablon' => {
			exemplarCity => q#ဘလွန်ခ်-စာဘလွန်#,
		},
		'America/Boa_Vista' => {
			exemplarCity => q#ဘိုအာဗီစ်တာ#,
		},
		'America/Bogota' => {
			exemplarCity => q#ဘိုဂိုတာ#,
		},
		'America/Boise' => {
			exemplarCity => q#ဗွိုက်စီ#,
		},
		'America/Buenos_Aires' => {
			exemplarCity => q#ဗျူနိုအေးရိစ်#,
		},
		'America/Cambridge_Bay' => {
			exemplarCity => q#ကိန်းဘရစ်ချ် ဘေး#,
		},
		'America/Campo_Grande' => {
			exemplarCity => q#ကိမ်ပို ဂရန်ဒီ#,
		},
		'America/Cancun' => {
			exemplarCity => q#ကန်ခန်#,
		},
		'America/Caracas' => {
			exemplarCity => q#ကာရာကာစ်#,
		},
		'America/Catamarca' => {
			exemplarCity => q#ကာတာမာရကာ#,
		},
		'America/Cayenne' => {
			exemplarCity => q#ကေညင်န်#,
		},
		'America/Cayman' => {
			exemplarCity => q#ကေမန်#,
		},
		'America/Chicago' => {
			exemplarCity => q#ချီကာကို#,
		},
		'America/Chihuahua' => {
			exemplarCity => q#ချီဟူအာဟူအာ#,
		},
		'America/Ciudad_Juarez' => {
			exemplarCity => q#စီယူဒတ်စ် ဟွာရက်စ်#,
		},
		'America/Coral_Harbour' => {
			exemplarCity => q#အာတီကိုကန်#,
		},
		'America/Cordoba' => {
			exemplarCity => q#ကိုဒိုဘာ#,
		},
		'America/Costa_Rica' => {
			exemplarCity => q#ကို့စတာရီကာ#,
		},
		'America/Creston' => {
			exemplarCity => q#ကရစ်စတွန်#,
		},
		'America/Cuiaba' => {
			exemplarCity => q#ကွီရာဘာ#,
		},
		'America/Curacao' => {
			exemplarCity => q#ကျူရေးကိုး#,
		},
		'America/Danmarkshavn' => {
			exemplarCity => q#ဒန်မတ်ရှ်ဗာန်#,
		},
		'America/Dawson' => {
			exemplarCity => q#ဒေါ်ဆန်#,
		},
		'America/Dawson_Creek' => {
			exemplarCity => q#ဒေါ်ဆန် ခရိခ်#,
		},
		'America/Denver' => {
			exemplarCity => q#ဒင်န်ဗာ#,
		},
		'America/Detroit' => {
			exemplarCity => q#ဒက်ထရွိုက်#,
		},
		'America/Dominica' => {
			exemplarCity => q#ဒိုမီနီကာ#,
		},
		'America/Edmonton' => {
			exemplarCity => q#အက်ဒ်မွန်တန်#,
		},
		'America/Eirunepe' => {
			exemplarCity => q#အီရူနီပီ#,
		},
		'America/El_Salvador' => {
			exemplarCity => q#အယ်လ်ဆာဗေဒို#,
		},
		'America/Fort_Nelson' => {
			exemplarCity => q#ဖို့တ် နယ်လ်ဆင်#,
		},
		'America/Fortaleza' => {
			exemplarCity => q#ဖို့တ်တာလီဇာ#,
		},
		'America/Glace_Bay' => {
			exemplarCity => q#ဂလဲစ်ဘေး#,
		},
		'America/Godthab' => {
			exemplarCity => q#နုခ်#,
		},
		'America/Goose_Bay' => {
			exemplarCity => q#ဂူးစ်ဘေး#,
		},
		'America/Grand_Turk' => {
			exemplarCity => q#ဂရန်ဒ် တခ်#,
		},
		'America/Grenada' => {
			exemplarCity => q#ဂရီနေဒါ#,
		},
		'America/Guadeloupe' => {
			exemplarCity => q#ဂွါဒီလုပ်#,
		},
		'America/Guatemala' => {
			exemplarCity => q#ဂွါတီမာလာ#,
		},
		'America/Guayaquil' => {
			exemplarCity => q#ဂွါရာကွီးလ်#,
		},
		'America/Guyana' => {
			exemplarCity => q#ဂိုင်ယာနာ#,
		},
		'America/Halifax' => {
			exemplarCity => q#ဟလီဖက်စ်#,
		},
		'America/Havana' => {
			exemplarCity => q#ဟာဗာနာ#,
		},
		'America/Hermosillo' => {
			exemplarCity => q#ဟာမိုစ်စီလို#,
		},
		'America/Indiana/Knox' => {
			exemplarCity => q#နောက်ခ်စ်၊ အင်ဒီယားနား#,
		},
		'America/Indiana/Marengo' => {
			exemplarCity => q#မာရန်ဂို၊ အင်ဒီယားနား#,
		},
		'America/Indiana/Petersburg' => {
			exemplarCity => q#ပီတာစ်ဘတ်ခ်၊ အင်ဒီယားနား#,
		},
		'America/Indiana/Tell_City' => {
			exemplarCity => q#တဲလ်စီးတီး၊ အင်ဒီယားနား#,
		},
		'America/Indiana/Vevay' => {
			exemplarCity => q#ဗီဗဲ၊ အင်ဒီယားနား#,
		},
		'America/Indiana/Vincennes' => {
			exemplarCity => q#ဗင်ဆင့်စ်၊ အင်ဒီယားနား#,
		},
		'America/Indiana/Winamac' => {
			exemplarCity => q#ဝီနာမက်ခ်၊ အင်ဒီယားနား#,
		},
		'America/Indianapolis' => {
			exemplarCity => q#အင်ဒီယားနား ပိုလိစ်#,
		},
		'America/Inuvik' => {
			exemplarCity => q#အီနုဗီခ်#,
		},
		'America/Iqaluit' => {
			exemplarCity => q#အီကာလူအီတ်#,
		},
		'America/Jamaica' => {
			exemplarCity => q#ဂျမေကာ#,
		},
		'America/Jujuy' => {
			exemplarCity => q#ဂျုဂျေ#,
		},
		'America/Juneau' => {
			exemplarCity => q#ဂျုနိုအော#,
		},
		'America/Kentucky/Monticello' => {
			exemplarCity => q#မွန်တီချယ်လို၊ ကင်တပ်ကီ#,
		},
		'America/Kralendijk' => {
			exemplarCity => q#ခရာလဲန်းဒစ်ချ်#,
		},
		'America/La_Paz' => {
			exemplarCity => q#လာပါဇ်#,
		},
		'America/Lima' => {
			exemplarCity => q#လီမာ#,
		},
		'America/Los_Angeles' => {
			exemplarCity => q#လော့စ်အိန်ဂျယ်လိစ်#,
		},
		'America/Louisville' => {
			exemplarCity => q#လူဝီဗီးလ်#,
		},
		'America/Lower_Princes' => {
			exemplarCity => q#လိုအာပရင့်စ် ကွာတာ#,
		},
		'America/Maceio' => {
			exemplarCity => q#မာဆဲသွာ#,
		},
		'America/Managua' => {
			exemplarCity => q#မာနာဂွါ#,
		},
		'America/Manaus' => {
			exemplarCity => q#မာနောက်စ်#,
		},
		'America/Marigot' => {
			exemplarCity => q#မာရီဂေါ့#,
		},
		'America/Martinique' => {
			exemplarCity => q#မာတီနီဂ်#,
		},
		'America/Matamoros' => {
			exemplarCity => q#မာတာမိုရိုစ်#,
		},
		'America/Mazatlan' => {
			exemplarCity => q#မာဇတ်လန်#,
		},
		'America/Mendoza' => {
			exemplarCity => q#မန်ဒိုဇာ#,
		},
		'America/Menominee' => {
			exemplarCity => q#မီနိုမီနီး#,
		},
		'America/Merida' => {
			exemplarCity => q#မီရီဒါ#,
		},
		'America/Metlakatla' => {
			exemplarCity => q#မက်တ်လာကက်လာ#,
		},
		'America/Mexico_City' => {
			exemplarCity => q#မက်ကဆီကို စီးတီး#,
		},
		'America/Miquelon' => {
			exemplarCity => q#မီကွီလွန်#,
		},
		'America/Moncton' => {
			exemplarCity => q#မွန်ခ်တွန်#,
		},
		'America/Monterrey' => {
			exemplarCity => q#မွန်တဲရေး#,
		},
		'America/Montevideo' => {
			exemplarCity => q#မွန်တီဗီဒီအို#,
		},
		'America/Montserrat' => {
			exemplarCity => q#မွန့်(တ်)ဆေးရတ်#,
		},
		'America/Nassau' => {
			exemplarCity => q#နာ့ဆော်#,
		},
		'America/New_York' => {
			exemplarCity => q#နယူးယောက်#,
		},
		'America/Nome' => {
			exemplarCity => q#နိုမီ#,
		},
		'America/Noronha' => {
			exemplarCity => q#နိုရိုညာ#,
		},
		'America/North_Dakota/Beulah' => {
			exemplarCity => q#ဗြူလာ၊ မြောက်ဒါကိုတာ#,
		},
		'America/North_Dakota/Center' => {
			exemplarCity => q#စင်တာ၊ မြောက်ဒါကိုတာ#,
		},
		'America/North_Dakota/New_Salem' => {
			exemplarCity => q#နယူးဆေးလမ်၊ မြောက်ဒါကိုတာ#,
		},
		'America/Ojinaga' => {
			exemplarCity => q#အိုခီနဂါ#,
		},
		'America/Panama' => {
			exemplarCity => q#ပနားမား#,
		},
		'America/Paramaribo' => {
			exemplarCity => q#ပါရာမာရီဘို#,
		},
		'America/Phoenix' => {
			exemplarCity => q#ဖီးနစ်#,
		},
		'America/Port-au-Prince' => {
			exemplarCity => q#ပို့တ်-အို-ပရင့်စ်#,
		},
		'America/Port_of_Spain' => {
			exemplarCity => q#ပို့တ် အော့ဖ် စပိန်#,
		},
		'America/Porto_Velho' => {
			exemplarCity => q#ပို့တ်တို ဗဲလီယို#,
		},
		'America/Puerto_Rico' => {
			exemplarCity => q#ပေါ်တိုရီကို#,
		},
		'America/Punta_Arenas' => {
			exemplarCity => q#ပွန်တာ အရီနာစ်#,
		},
		'America/Rankin_Inlet' => {
			exemplarCity => q#ရန်ကင် အင်းလက်#,
		},
		'America/Recife' => {
			exemplarCity => q#ဟေစီဖီလ်#,
		},
		'America/Regina' => {
			exemplarCity => q#ရယ်ဂျီနာ#,
		},
		'America/Resolute' => {
			exemplarCity => q#ရီဆိုလုပ်(တ်)#,
		},
		'America/Rio_Branco' => {
			exemplarCity => q#ရီယို ဘရန်ကို#,
		},
		'America/Santarem' => {
			exemplarCity => q#ဆန်တာရမ်#,
		},
		'America/Santiago' => {
			exemplarCity => q#ဆန်တီအာဂို#,
		},
		'America/Santo_Domingo' => {
			exemplarCity => q#ဆန်တို ဒိုမင်းဂို#,
		},
		'America/Sao_Paulo' => {
			exemplarCity => q#ဆော်ပိုလို#,
		},
		'America/Scoresbysund' => {
			exemplarCity => q#အစ်တာကာ တိုးမိရက်တ်#,
		},
		'America/Sitka' => {
			exemplarCity => q#စစ်ကာ#,
		},
		'America/St_Barthelemy' => {
			exemplarCity => q#စိန့်ဘာသယ်လမီ#,
		},
		'America/St_Johns' => {
			exemplarCity => q#စိန့်ဂျွန်း#,
		},
		'America/St_Kitts' => {
			exemplarCity => q#စိန့်ကိစ်#,
		},
		'America/St_Lucia' => {
			exemplarCity => q#စိန့်လူစီယာ#,
		},
		'America/St_Thomas' => {
			exemplarCity => q#စိန့်သောမတ်စ်#,
		},
		'America/St_Vincent' => {
			exemplarCity => q#စိန့်ဗင်းဆင့်#,
		},
		'America/Swift_Current' => {
			exemplarCity => q#စွတ်ဖ်တ် ကားရင့်#,
		},
		'America/Tegucigalpa' => {
			exemplarCity => q#တီဂူစီဂလ်ပါ#,
		},
		'America/Thule' => {
			exemplarCity => q#သုလီ#,
		},
		'America/Tijuana' => {
			exemplarCity => q#တီဂွါနာ#,
		},
		'America/Toronto' => {
			exemplarCity => q#တိုရန်တို#,
		},
		'America/Tortola' => {
			exemplarCity => q#တောတိုလာ#,
		},
		'America/Vancouver' => {
			exemplarCity => q#ဗန်ကူးဗား#,
		},
		'America/Whitehorse' => {
			exemplarCity => q#ဝိုက်(တ်)ဟိုစ်#,
		},
		'America/Winnipeg' => {
			exemplarCity => q#ဝီနီဗက်ဂ်#,
		},
		'America/Yakutat' => {
			exemplarCity => q#ရာကုတတ်#,
		},
		'America_Central' => {
			long => {
				'daylight' => q#အလယ်ပိုင်း နွေရာသီစံတော်ချိန်#,
				'generic' => q#အလယ်ပိုင်းအချိန်#,
				'standard' => q#အလယ်ပိုင်းစံတော်ချိန်#,
			},
		},
		'America_Eastern' => {
			long => {
				'daylight' => q#အရှေ့ပိုင်း နွေရာသီစံတော်ချိန်#,
				'generic' => q#အရှေ့ပိုင်းအချိန်#,
				'standard' => q#အရှေ့ပိုင်းစံတော်ချိန်#,
			},
		},
		'America_Mountain' => {
			long => {
				'daylight' => q#တောင်တန်း နွေရာသီစံတော်ချိန်#,
				'generic' => q#တောင်တန်းအချိန်#,
				'standard' => q#တောင်တန်းစံတော်ချိန်#,
			},
		},
		'America_Pacific' => {
			long => {
				'daylight' => q#ပစိဖိတ် နွေရာသီစံတော်ချိန်#,
				'generic' => q#ပစိဖိတ်အချိန်#,
				'standard' => q#ပစိဖိတ်စံတော်ချိန်#,
			},
		},
		'Antarctica/Casey' => {
			exemplarCity => q#ကေစီ#,
		},
		'Antarctica/Davis' => {
			exemplarCity => q#ဒေးဗစ်#,
		},
		'Antarctica/DumontDUrville' => {
			exemplarCity => q#ဒူးမော့တ် ဒါရ်ဗီးလ်#,
		},
		'Antarctica/Macquarie' => {
			exemplarCity => q#မက်ကွယ်ရီ#,
		},
		'Antarctica/Mawson' => {
			exemplarCity => q#မော်စွန်#,
		},
		'Antarctica/McMurdo' => {
			exemplarCity => q#မက်မူဒိုး#,
		},
		'Antarctica/Palmer' => {
			exemplarCity => q#ပါလ်မာ#,
		},
		'Antarctica/Rothera' => {
			exemplarCity => q#ရိုသီရာ#,
		},
		'Antarctica/Syowa' => {
			exemplarCity => q#ရှိုးဝါ#,
		},
		'Antarctica/Troll' => {
			exemplarCity => q#ထရိုလ်#,
		},
		'Antarctica/Vostok' => {
			exemplarCity => q#ဗိုစ်တိုခ်#,
		},
		'Apia' => {
			long => {
				'daylight' => q#အပီယာ နွေရာသီ အချိန်#,
				'generic' => q#အပီယာ အချိန်#,
				'standard' => q#အပီယာ စံတော်ချိန်#,
			},
		},
		'Arabian' => {
			long => {
				'daylight' => q#အာရေဗျ နွေရာသီ အချိန်#,
				'generic' => q#အာရေဗျ အချိန်#,
				'standard' => q#အာရေဗျ စံတော်ချိန်#,
			},
		},
		'Arctic/Longyearbyen' => {
			exemplarCity => q#လောင်ရီယားဘရံ#,
		},
		'Argentina' => {
			long => {
				'daylight' => q#အာဂျင်တီးနား နွေရာသီအချိန်#,
				'generic' => q#အာဂျင်တီးနား အချိန်#,
				'standard' => q#အာဂျင်တီးနား စံတော်ချိန်#,
			},
		},
		'Argentina_Western' => {
			long => {
				'daylight' => q#အနောက် အာဂျင်တီးနား နွေရာသီ အချိန်#,
				'generic' => q#အနောက် အာဂျင်တီးနား အချိန်#,
				'standard' => q#အနောက် အာဂျင်တီးနား စံတော်ချိန်#,
			},
		},
		'Armenia' => {
			long => {
				'daylight' => q#အာမေးနီးယား နွေရာသီ အချိန်#,
				'generic' => q#အာမေးနီးယား အချိန်#,
				'standard' => q#အာမေးနီးယား စံတော်ချိန်#,
			},
		},
		'Asia/Aden' => {
			exemplarCity => q#အာဒင်#,
		},
		'Asia/Almaty' => {
			exemplarCity => q#အော်မာတီ#,
		},
		'Asia/Amman' => {
			exemplarCity => q#အာမာန်း#,
		},
		'Asia/Anadyr' => {
			exemplarCity => q#အန်အာဒီအာ#,
		},
		'Asia/Aqtau' => {
			exemplarCity => q#အက်တာဥု#,
		},
		'Asia/Aqtobe' => {
			exemplarCity => q#အာချတူးဘီ#,
		},
		'Asia/Ashgabat' => {
			exemplarCity => q#အာရှ်ဂါဘာဒ်#,
		},
		'Asia/Atyrau' => {
			exemplarCity => q#အာတီရအူ#,
		},
		'Asia/Baghdad' => {
			exemplarCity => q#ဘဂ္ဂဒက်#,
		},
		'Asia/Bahrain' => {
			exemplarCity => q#ဘာရိန်း#,
		},
		'Asia/Baku' => {
			exemplarCity => q#ဘာကူ#,
		},
		'Asia/Bangkok' => {
			exemplarCity => q#ဘန်ကောက်#,
		},
		'Asia/Barnaul' => {
			exemplarCity => q#ဘရ်နာအူ#,
		},
		'Asia/Beirut' => {
			exemplarCity => q#ဘေရွတ်#,
		},
		'Asia/Bishkek' => {
			exemplarCity => q#ဘီရှ်ခက်#,
		},
		'Asia/Brunei' => {
			exemplarCity => q#ဘရူနိုင်း#,
		},
		'Asia/Calcutta' => {
			exemplarCity => q#ကိုလျကတ်တား#,
		},
		'Asia/Chita' => {
			exemplarCity => q#ချီတာ#,
		},
		'Asia/Colombo' => {
			exemplarCity => q#ကိုလံဘို#,
		},
		'Asia/Damascus' => {
			exemplarCity => q#ဒမားစကပ်#,
		},
		'Asia/Dhaka' => {
			exemplarCity => q#ဒက်ကာ#,
		},
		'Asia/Dili' => {
			exemplarCity => q#ဒစ်လီ#,
		},
		'Asia/Dubai' => {
			exemplarCity => q#ဒူဘိုင်း#,
		},
		'Asia/Dushanbe' => {
			exemplarCity => q#ဒူရှန်းဘဲ#,
		},
		'Asia/Famagusta' => {
			exemplarCity => q#ဖာမာဂူစတာ#,
		},
		'Asia/Gaza' => {
			exemplarCity => q#ဂါဇာ#,
		},
		'Asia/Hebron' => {
			exemplarCity => q#ဟီဘရွန်#,
		},
		'Asia/Hong_Kong' => {
			exemplarCity => q#ဟောင်ကောင်#,
		},
		'Asia/Hovd' => {
			exemplarCity => q#ဟိုးဗျ#,
		},
		'Asia/Irkutsk' => {
			exemplarCity => q#အီရူခူတ်#,
		},
		'Asia/Jakarta' => {
			exemplarCity => q#ဂျကာတာ#,
		},
		'Asia/Jayapura' => {
			exemplarCity => q#ဂျာရာပူရာ#,
		},
		'Asia/Jerusalem' => {
			exemplarCity => q#ဂျေရုဆလင်#,
		},
		'Asia/Kabul' => {
			exemplarCity => q#ကာဘူးလ်#,
		},
		'Asia/Kamchatka' => {
			exemplarCity => q#ခမ်ချာ့ခါ#,
		},
		'Asia/Karachi' => {
			exemplarCity => q#ကရာချိ#,
		},
		'Asia/Katmandu' => {
			exemplarCity => q#ခတ်တမန်ဒူ#,
		},
		'Asia/Khandyga' => {
			exemplarCity => q#ခန်ဒိုင်ဂါ#,
		},
		'Asia/Krasnoyarsk' => {
			exemplarCity => q#ခရာ့စ်နိုရာစ်#,
		},
		'Asia/Kuala_Lumpur' => {
			exemplarCity => q#ကွာလာလမ်ပူ#,
		},
		'Asia/Kuching' => {
			exemplarCity => q#ကူချင်#,
		},
		'Asia/Kuwait' => {
			exemplarCity => q#ကူဝိတ်#,
		},
		'Asia/Macau' => {
			exemplarCity => q#မကာအို#,
		},
		'Asia/Magadan' => {
			exemplarCity => q#မာဂါဒန်း#,
		},
		'Asia/Makassar' => {
			exemplarCity => q#မခက်စ်ဆာ#,
		},
		'Asia/Manila' => {
			exemplarCity => q#မနီလာ#,
		},
		'Asia/Muscat' => {
			exemplarCity => q#မတ်စ်ကက်တ်#,
		},
		'Asia/Nicosia' => {
			exemplarCity => q#နီကိုရှား#,
		},
		'Asia/Novokuznetsk' => {
			exemplarCity => q#နိုဗိုခူဇ်နက်စ်#,
		},
		'Asia/Novosibirsk' => {
			exemplarCity => q#နိုဗိုစဲဘီအဲယ်စ်#,
		},
		'Asia/Omsk' => {
			exemplarCity => q#အွမ်းစ်ခ်#,
		},
		'Asia/Oral' => {
			exemplarCity => q#အော်ရဲလ်#,
		},
		'Asia/Phnom_Penh' => {
			exemplarCity => q#ဖနွမ်ပင်#,
		},
		'Asia/Pontianak' => {
			exemplarCity => q#ပွန်တီအားနာ့ခ်#,
		},
		'Asia/Pyongyang' => {
			exemplarCity => q#ပြုံယန်း#,
		},
		'Asia/Qatar' => {
			exemplarCity => q#ကာတာ#,
		},
		'Asia/Qostanay' => {
			exemplarCity => q#ကော့စ်တနေ#,
		},
		'Asia/Qyzylorda' => {
			exemplarCity => q#ကီဇလော်ဒါ#,
		},
		'Asia/Rangoon' => {
			exemplarCity => q#ရန်ကုန်#,
		},
		'Asia/Riyadh' => {
			exemplarCity => q#ရီယားဒ်#,
		},
		'Asia/Saigon' => {
			exemplarCity => q#ဟိုချီမင်းစီးတီး#,
		},
		'Asia/Sakhalin' => {
			exemplarCity => q#ဆာခါလင်#,
		},
		'Asia/Samarkand' => {
			exemplarCity => q#ဆမ်းမာခန်းဒ်#,
		},
		'Asia/Seoul' => {
			exemplarCity => q#ဆိုးလ်#,
		},
		'Asia/Shanghai' => {
			exemplarCity => q#ရှန်ဟိုင်း#,
		},
		'Asia/Singapore' => {
			exemplarCity => q#စင်္ကာပူ#,
		},
		'Asia/Srednekolymsk' => {
			exemplarCity => q#ဆရစ်နစ်ကာလင်မ်စ်#,
		},
		'Asia/Taipei' => {
			exemplarCity => q#တိုင်ပေ#,
		},
		'Asia/Tashkent' => {
			exemplarCity => q#တာရှ်ကဲန့်#,
		},
		'Asia/Tbilisi' => {
			exemplarCity => q#တဘီးလီစီ#,
		},
		'Asia/Tehran' => {
			exemplarCity => q#တီဟီရန်#,
		},
		'Asia/Thimphu' => {
			exemplarCity => q#တင်ဖူး#,
		},
		'Asia/Tokyo' => {
			exemplarCity => q#တိုကျို#,
		},
		'Asia/Tomsk' => {
			exemplarCity => q#တွန်မ်စ်ခ်#,
		},
		'Asia/Ulaanbaatar' => {
			exemplarCity => q#ဥလန်ဘာတော#,
		},
		'Asia/Urumqi' => {
			exemplarCity => q#အူရုမ်ချီ#,
		},
		'Asia/Ust-Nera' => {
			exemplarCity => q#အူးစ် နီရား#,
		},
		'Asia/Vientiane' => {
			exemplarCity => q#ဗီယင်ကျန်း#,
		},
		'Asia/Vladivostok' => {
			exemplarCity => q#ဗလာဒီဗော့စတော့ခ်#,
		},
		'Asia/Yakutsk' => {
			exemplarCity => q#ယူခူးတ်စ်#,
		},
		'Asia/Yekaterinburg' => {
			exemplarCity => q#ရယ်ခါးတီရင်ဘားခ်#,
		},
		'Asia/Yerevan' => {
			exemplarCity => q#ရဲယ်ရေဗန်း#,
		},
		'Atlantic' => {
			long => {
				'daylight' => q#အတ္တလန်တစ် နွေရာသီ စံတော်ချိန်#,
				'generic' => q#အတ္တလန်တစ် အချိန်#,
				'standard' => q#အတ္တလန်တစ် စံတော်ချိန်#,
			},
		},
		'Atlantic/Azores' => {
			exemplarCity => q#အေဇိုးရီးစ်#,
		},
		'Atlantic/Bermuda' => {
			exemplarCity => q#ဘာမြူဒါ#,
		},
		'Atlantic/Canary' => {
			exemplarCity => q#ကနေရီ#,
		},
		'Atlantic/Cape_Verde' => {
			exemplarCity => q#ကိတ်ပ် ဗာဒီ#,
		},
		'Atlantic/Faeroe' => {
			exemplarCity => q#ဖါရို#,
		},
		'Atlantic/Madeira' => {
			exemplarCity => q#မဒီးရာ#,
		},
		'Atlantic/Reykjavik' => {
			exemplarCity => q#ရေးကီဗစ်ခ်#,
		},
		'Atlantic/South_Georgia' => {
			exemplarCity => q#တောင်ဂျော်ဂျီယာ#,
		},
		'Atlantic/St_Helena' => {
			exemplarCity => q#စိန့်ဟယ်လယ်နာ#,
		},
		'Atlantic/Stanley' => {
			exemplarCity => q#စတန်လေ#,
		},
		'Australia/Adelaide' => {
			exemplarCity => q#အန္ဒီလိတ်ဒ်#,
		},
		'Australia/Brisbane' => {
			exemplarCity => q#ဘရစ္စဘိန်း#,
		},
		'Australia/Broken_Hill' => {
			exemplarCity => q#ဘရိုကင်ဟီးလ်#,
		},
		'Australia/Darwin' => {
			exemplarCity => q#ဒါဝင်#,
		},
		'Australia/Eucla' => {
			exemplarCity => q#ယူးခလာ#,
		},
		'Australia/Hobart' => {
			exemplarCity => q#ဟိုးဘားတ်#,
		},
		'Australia/Lindeman' => {
			exemplarCity => q#လင်းဒီမန်း#,
		},
		'Australia/Lord_Howe' => {
			exemplarCity => q#လော့ဒ် ဟောင်#,
		},
		'Australia/Melbourne' => {
			exemplarCity => q#မဲလ်ဘုန်း#,
		},
		'Australia/Perth' => {
			exemplarCity => q#ပါးသ်#,
		},
		'Australia/Sydney' => {
			exemplarCity => q#ဆစ်ဒနီ#,
		},
		'Australia_Central' => {
			long => {
				'daylight' => q#ဩစတြေးလျ အလယ်ပိုင်း နွေရာသီ အချိန်#,
				'generic' => q#ဩစတြေးလျ အလယ်ပိုင်း အချိန်#,
				'standard' => q#ဩစတြေးလျ အလယ်ပိုင်း စံတော်ချိန်#,
			},
		},
		'Australia_CentralWestern' => {
			long => {
				'daylight' => q#သြစတြေးလျား အနောက်အလယ်ပိုင်း နွေရာသီ အချိန်#,
				'generic' => q#သြစတြေးလျား အနောက်အလယ်ပိုင်း အချိန်#,
				'standard' => q#သြစတြေးလျား အနောက်အလယ်ပိုင်း စံတော်ချိန်#,
			},
		},
		'Australia_Eastern' => {
			long => {
				'daylight' => q#အရှေ့ဩစတြေးလျ နွေရာသီ အချိန်#,
				'generic' => q#အရှေ့ဩစတြေးလျ အချိန်#,
				'standard' => q#အရှေ့ဩစတြေးလျ စံတော်ချိန်#,
			},
		},
		'Australia_Western' => {
			long => {
				'daylight' => q#ဩစတြေးလျ နွေရာသီ အချိန်#,
				'generic' => q#အနောက်ဩစတြေးလျ အချိန်#,
				'standard' => q#အနောက်ဩစတြေးလျ စံတော်ချိန်#,
			},
		},
		'Azerbaijan' => {
			long => {
				'daylight' => q#အဇာဘိုင်ဂျန် နွေရာသီ အချိန်#,
				'generic' => q#အဇာဘိုင်ဂျန် အချိန်#,
				'standard' => q#အဇာဘိုင်ဂျန် စံတော်ချိန်#,
			},
		},
		'Azores' => {
			long => {
				'daylight' => q#အေဇိုးရီးစ် နွေရာသီ အချိန်#,
				'generic' => q#အေဇိုးရီးစ် အချိန်#,
				'standard' => q#အေဇိုးရီးစ် စံတော်ချိန်#,
			},
		},
		'Bangladesh' => {
			long => {
				'daylight' => q#ဘင်္ဂလားဒေ့ရှ် နွေရာသီ အချိန်#,
				'generic' => q#ဘင်္ဂလားဒေ့ရှ် အချိန်#,
				'standard' => q#ဘင်္ဂလားဒေ့ရှ် စံတော်ချိန်#,
			},
		},
		'Bhutan' => {
			long => {
				'standard' => q#ဘူတန် အချိန်#,
			},
		},
		'Bolivia' => {
			long => {
				'standard' => q#ဘိုလီးဘီးယား အချိန်#,
			},
		},
		'Brasilia' => {
			long => {
				'daylight' => q#ဘရာဇီး နွေရာသီ အချိန်#,
				'generic' => q#ဘရာဇီး အချိန်#,
				'standard' => q#ဘရာဇီး စံတော်ချိန်#,
			},
		},
		'Brunei' => {
			long => {
				'standard' => q#ဘရူနိုင်း စံတော်ချိန်#,
			},
		},
		'Cape_Verde' => {
			long => {
				'daylight' => q#ကိတ်ဗာဒီ နွေရာသီ အချိန်#,
				'generic' => q#ကိတ်ဗာဒီ အချိန်#,
				'standard' => q#ကိတ်ဗာဒီ စံတော်ချိန်#,
			},
		},
		'Chamorro' => {
			long => {
				'standard' => q#ချာမိုရို အချိန်#,
			},
		},
		'Chatham' => {
			long => {
				'daylight' => q#ချားသမ် နွေရာသီ အချိန်#,
				'generic' => q#ချားသမ်အချိန်#,
				'standard' => q#ချားသမ်စံတော်ချိန်#,
			},
		},
		'Chile' => {
			long => {
				'daylight' => q#ချီလီ နွေရာသီ အချိန်#,
				'generic' => q#ချီလီ အချိန်#,
				'standard' => q#ချီလီ စံတော်ချိန်#,
			},
		},
		'China' => {
			long => {
				'daylight' => q#တရုတ် နွေရာသီ အချိန်#,
				'generic' => q#တရုတ် အချိန်#,
				'standard' => q#တရုတ် စံတော်ချိန်#,
			},
		},
		'Christmas' => {
			long => {
				'standard' => q#ခရစ်စမတ်ကျွန်း အချိန်#,
			},
		},
		'Cocos' => {
			long => {
				'standard' => q#ကိုကိုးကျွန်း အချိန်#,
			},
		},
		'Colombia' => {
			long => {
				'daylight' => q#ကိုလံဘီယာ နွေရာသီ အချိန်#,
				'generic' => q#ကိုလံဘီယာ အချိန်#,
				'standard' => q#ကိုလံဘီယာ စံတော်ချိန်#,
			},
		},
		'Cook' => {
			long => {
				'daylight' => q#ကွတ်ကျွန်းစု နွေရာသီ အချိန်#,
				'generic' => q#ကွတ်ကျွန်းစု အချိန်#,
				'standard' => q#ကွတ်ကျွန်းစု စံတော်ချိန်#,
			},
		},
		'Cuba' => {
			long => {
				'daylight' => q#ကျူးဘား နွေရာသီ စံတော်ချိန်#,
				'generic' => q#ကျူးဘား အချိန်#,
				'standard' => q#ကျူးဘား စံတော်ချိန်#,
			},
		},
		'Davis' => {
			long => {
				'standard' => q#ဒေးဗစ် အချိန်#,
			},
		},
		'DumontDUrville' => {
			long => {
				'standard' => q#ဒူးမော့တ် ဒါရ်ဗီးလ် အချိန်#,
			},
		},
		'East_Timor' => {
			long => {
				'standard' => q#အရှေ့တီမော အချိန်#,
			},
		},
		'Easter' => {
			long => {
				'daylight' => q#အီစတာကျွန်း နွေရာသီ အချိန်#,
				'generic' => q#အီစတာကျွန်း အချိန်#,
				'standard' => q#အီစတာကျွန်း စံတော်ချိန်#,
			},
		},
		'Ecuador' => {
			long => {
				'standard' => q#အီကွေဒေါ အချိန်#,
			},
		},
		'Etc/UTC' => {
			long => {
				'standard' => q#ညှိထားသည့် ကမ္ဘာ့ စံတော်ချိန်#,
			},
		},
		'Etc/Unknown' => {
			exemplarCity => q#အမည်မသိသောမြို့#,
		},
		'Europe/Amsterdam' => {
			exemplarCity => q#အမ်စတာဒမ်#,
		},
		'Europe/Andorra' => {
			exemplarCity => q#အန်ဒိုရာ#,
		},
		'Europe/Astrakhan' => {
			exemplarCity => q#အားစ်တရခန်း#,
		},
		'Europe/Athens' => {
			exemplarCity => q#အေသင်#,
		},
		'Europe/Belgrade' => {
			exemplarCity => q#ဘဲလ်ဂရိတ်#,
		},
		'Europe/Berlin' => {
			exemplarCity => q#ဘာလင်#,
		},
		'Europe/Bratislava' => {
			exemplarCity => q#ဘရာတီးစ်လားဗာ#,
		},
		'Europe/Brussels' => {
			exemplarCity => q#ဘရပ်ဆဲလ်#,
		},
		'Europe/Bucharest' => {
			exemplarCity => q#ဘူခါရက်စ်#,
		},
		'Europe/Budapest' => {
			exemplarCity => q#ဘူဒါပက်စ်#,
		},
		'Europe/Busingen' => {
			exemplarCity => q#ဘူရှင်ဂျင်#,
		},
		'Europe/Chisinau' => {
			exemplarCity => q#ချီရှီနားအူ#,
		},
		'Europe/Copenhagen' => {
			exemplarCity => q#ကိုပင်ဟေဂင်#,
		},
		'Europe/Dublin' => {
			exemplarCity => q#ဒတ်ဘလင်#,
			long => {
				'daylight' => q#အိုင်းရစ်ရှ် စံတော်ချိန်#,
			},
		},
		'Europe/Gibraltar' => {
			exemplarCity => q#ဂျီဘရော်လ်တာ#,
		},
		'Europe/Guernsey' => {
			exemplarCity => q#ဂွန်းဇီ#,
		},
		'Europe/Helsinki' => {
			exemplarCity => q#ဟဲလ်စင်ကီ#,
		},
		'Europe/Isle_of_Man' => {
			exemplarCity => q#မန်းကျွန်း#,
		},
		'Europe/Istanbul' => {
			exemplarCity => q#အစ္စတန်ဘူလ်#,
		},
		'Europe/Jersey' => {
			exemplarCity => q#ဂျာစီ#,
		},
		'Europe/Kaliningrad' => {
			exemplarCity => q#ခါလီနင်ဂရက်#,
		},
		'Europe/Kiev' => {
			exemplarCity => q#ခီးအက်ဖ်#,
		},
		'Europe/Kirov' => {
			exemplarCity => q#ခီရိုဗ်#,
		},
		'Europe/Lisbon' => {
			exemplarCity => q#လစ္စဘွန်း#,
		},
		'Europe/Ljubljana' => {
			exemplarCity => q#လူဘလီအားနား#,
		},
		'Europe/London' => {
			exemplarCity => q#လန်ဒန်#,
			long => {
				'daylight' => q#ဗြိတိန် နွေရာသီ အချိန်#,
			},
		},
		'Europe/Luxembourg' => {
			exemplarCity => q#လူဇင်ဘတ်#,
		},
		'Europe/Madrid' => {
			exemplarCity => q#မဒရစ်#,
		},
		'Europe/Malta' => {
			exemplarCity => q#မော်လ်တာ#,
		},
		'Europe/Mariehamn' => {
			exemplarCity => q#မရီအာ ဟားမန်#,
		},
		'Europe/Minsk' => {
			exemplarCity => q#မင်းစခ်#,
		},
		'Europe/Monaco' => {
			exemplarCity => q#မိုနာကို#,
		},
		'Europe/Moscow' => {
			exemplarCity => q#မော်စကို#,
		},
		'Europe/Oslo' => {
			exemplarCity => q#အော်စလို#,
		},
		'Europe/Paris' => {
			exemplarCity => q#ပဲရစ်#,
		},
		'Europe/Podgorica' => {
			exemplarCity => q#ပေါ့ဂိုရီကာ#,
		},
		'Europe/Prague' => {
			exemplarCity => q#ပရက်ဂ်#,
		},
		'Europe/Riga' => {
			exemplarCity => q#ရီဂါ#,
		},
		'Europe/Rome' => {
			exemplarCity => q#ရောမ#,
		},
		'Europe/Samara' => {
			exemplarCity => q#ဆာမားရာ#,
		},
		'Europe/San_Marino' => {
			exemplarCity => q#ဆန်မရီးနို#,
		},
		'Europe/Sarajevo' => {
			exemplarCity => q#ဆာရာယေဗို#,
		},
		'Europe/Saratov' => {
			exemplarCity => q#ဆာရာတို့ဖ်#,
		},
		'Europe/Simferopol' => {
			exemplarCity => q#စင်ဖာရိုးဖို#,
		},
		'Europe/Skopje' => {
			exemplarCity => q#စကော့ပ်ရာ#,
		},
		'Europe/Sofia' => {
			exemplarCity => q#ဆိုဖီအာ#,
		},
		'Europe/Stockholm' => {
			exemplarCity => q#စတော့ဟုမ်း#,
		},
		'Europe/Tallinn' => {
			exemplarCity => q#ထားလင်#,
		},
		'Europe/Tirane' => {
			exemplarCity => q#တီရာနီ#,
		},
		'Europe/Ulyanovsk' => {
			exemplarCity => q#အူလီယာနိုစကစ်ဖ်#,
		},
		'Europe/Vaduz' => {
			exemplarCity => q#ဗာဒူးစ်#,
		},
		'Europe/Vatican' => {
			exemplarCity => q#ဗာတီကန်#,
		},
		'Europe/Vienna' => {
			exemplarCity => q#ဗီယင်နာ#,
		},
		'Europe/Vilnius' => {
			exemplarCity => q#ဗီးလ်နီအိုးစ်#,
		},
		'Europe/Volgograd' => {
			exemplarCity => q#ဗိုလ်ဂိုဂရက်#,
		},
		'Europe/Warsaw' => {
			exemplarCity => q#ဝါဆော#,
		},
		'Europe/Zagreb' => {
			exemplarCity => q#ဇာဂ်ဂရက်ဘ်#,
		},
		'Europe/Zurich' => {
			exemplarCity => q#ဇူးရစ်ချ်#,
		},
		'Europe_Central' => {
			long => {
				'daylight' => q#ဥရောပအလယ်ပိုင်း နွေရာသီ အချိန်#,
				'generic' => q#ဥရောပအလယ်ပိုင်း အချိန်#,
				'standard' => q#ဥရောပအလယ်ပိုင်း စံတော်ချိန်#,
			},
		},
		'Europe_Eastern' => {
			long => {
				'daylight' => q#အရှေ့ဥရောပ နွေရာသီ အချိန်#,
				'generic' => q#အရှေ့ဥရောပ အချိန်#,
				'standard' => q#အရှေ့ဥရောပ စံတော်ချိန်#,
			},
		},
		'Europe_Further_Eastern' => {
			long => {
				'standard' => q#အရှေ့ဖျား ဥရောပဒေသ အချိန်#,
			},
		},
		'Europe_Western' => {
			long => {
				'daylight' => q#အနောက်ဥရောပ နွေရာသီ အချိန်#,
				'generic' => q#အနောက်ဥရောပ အချိန်#,
				'standard' => q#အနောက်ဥရောပ စံတော်ချိန်#,
			},
		},
		'Falkland' => {
			long => {
				'daylight' => q#ဖော့ကလန်ကျွန်းစု နွေရာသီ အချိန်#,
				'generic' => q#ဖော့ကလန်ကျွန်းစု အချိန်#,
				'standard' => q#ဖော့ကလန်ကျွန်းစု စံတော်ချိန်#,
			},
		},
		'Fiji' => {
			long => {
				'daylight' => q#ဖီဂျီ နွေရာသီ အချိန်#,
				'generic' => q#ဖီဂျီ အချိန်#,
				'standard' => q#ဖီဂျီ စံတော်ချိန်#,
			},
		},
		'French_Guiana' => {
			long => {
				'standard' => q#ပြင်သစ် ဂီအားနား အချိန်#,
			},
		},
		'French_Southern' => {
			long => {
				'standard' => q#ပြင်သစ်တောင်ပိုင်းနှင့် အန္တာတိတ် အချိန်#,
			},
		},
		'GMT' => {
			long => {
				'standard' => q#ဂရင်းနစ် စံတော်ချိန်#,
			},
		},
		'Galapagos' => {
			long => {
				'standard' => q#ဂါလားပါဂိုးစ် အချိန်#,
			},
		},
		'Gambier' => {
			long => {
				'standard' => q#ဂမ်ဘီယာ အချိန်#,
			},
		},
		'Georgia' => {
			long => {
				'daylight' => q#ဂျော်ဂျီယာ နွေရာသီ အချိန်#,
				'generic' => q#ဂျော်ဂျီယာ အချိန်#,
				'standard' => q#ဂျော်ဂျီယာ စံတော်ချိန်#,
			},
		},
		'Gilbert_Islands' => {
			long => {
				'standard' => q#ဂီလ်ဘတ်ကျွန်းစု အချိန်#,
			},
		},
		'Greenland_Eastern' => {
			long => {
				'daylight' => q#အရှေ့ဂရင်းလန် နွေရာသီ စံတော်ချိန်#,
				'generic' => q#အရှေ့ဂရင်းလန်း အချိန်#,
				'standard' => q#အရှေ့ဂရင်းလန်း စံတော်ချိန်#,
			},
		},
		'Greenland_Western' => {
			long => {
				'daylight' => q#အနောက် ဂရင်းလန် နွေရာသီ စံတော်ချိန်#,
				'generic' => q#အနောက် ဂရင်းလန်း အချိန်#,
				'standard' => q#အနောက် ဂရင်းလန်း စံတော်ချိန်#,
			},
		},
		'Gulf' => {
			long => {
				'standard' => q#ပင်လယ်ကွေ့ အချိန်#,
			},
		},
		'Guyana' => {
			long => {
				'standard' => q#ဂိုင်ယာနာ အချိန်#,
			},
		},
		'Hawaii_Aleutian' => {
			long => {
				'daylight' => q#ဟာဝိုင်ယီ အယ်လူးရှန်း နွေရာသီ စံတော်ချိန်#,
				'generic' => q#ဟာဝိုင်ယီ အယ်လူးရှန်း အချိန်#,
				'standard' => q#ဟာဝိုင်ယီ အယ်လူးရှန်း စံတော်ချိန်#,
			},
		},
		'Hong_Kong' => {
			long => {
				'daylight' => q#ဟောင်ကောင် နွေရာသီ အချိန်#,
				'generic' => q#ဟောင်ကောင် အချိန်#,
				'standard' => q#ဟောင်ကောင် စံတော်ချိန်#,
			},
		},
		'Hovd' => {
			long => {
				'daylight' => q#ဟိုးဗ် နွေရာသီ အချိန်#,
				'generic' => q#ဟိုးဗ် အချိန်#,
				'standard' => q#ဟိုးဗ် စံတော်ချိန်#,
			},
		},
		'India' => {
			long => {
				'standard' => q#အိန္ဒိယ စံတော်ချိန်#,
			},
		},
		'Indian/Antananarivo' => {
			exemplarCity => q#အန်တာနာနာရီးဘို#,
		},
		'Indian/Chagos' => {
			exemplarCity => q#ချာဂိုစ်#,
		},
		'Indian/Christmas' => {
			exemplarCity => q#ခရစ်စမတ်#,
		},
		'Indian/Cocos' => {
			exemplarCity => q#ကိုကိုးစ်#,
		},
		'Indian/Comoro' => {
			exemplarCity => q#ကိုမိုရို#,
		},
		'Indian/Kerguelen' => {
			exemplarCity => q#ခါဂါလန်#,
		},
		'Indian/Mahe' => {
			exemplarCity => q#မာဟီ#,
		},
		'Indian/Maldives' => {
			exemplarCity => q#မော်လဒိုက်#,
		},
		'Indian/Mauritius' => {
			exemplarCity => q#မောရစ်ရှ#,
		},
		'Indian/Mayotte' => {
			exemplarCity => q#မာယိုတဲ#,
		},
		'Indian/Reunion' => {
			exemplarCity => q#ရီယူနီယန်#,
		},
		'Indian_Ocean' => {
			long => {
				'standard' => q#အိန္ဒိယသမုဒ္ဒရာ အချိန်#,
			},
		},
		'Indochina' => {
			long => {
				'standard' => q#အင်ဒိုချိုင်းနား အချိန်#,
			},
		},
		'Indonesia_Central' => {
			long => {
				'standard' => q#အလယ်ပိုင်း အင်ဒိုနီးရှား အချိန်#,
			},
		},
		'Indonesia_Eastern' => {
			long => {
				'standard' => q#အရှေ့ပိုင်း အင်ဒိုနီးရှား အချိန်#,
			},
		},
		'Indonesia_Western' => {
			long => {
				'standard' => q#အနောက်ပိုင်း အင်ဒိုနီးရှား အချိန်#,
			},
		},
		'Iran' => {
			long => {
				'daylight' => q#အီရန် နွေရာသီ အချိန်#,
				'generic' => q#အီရန် အချိန်#,
				'standard' => q#အီရန် စံတော်ချိန်#,
			},
		},
		'Irkutsk' => {
			long => {
				'daylight' => q#အီရူခူတ် နွေရာသီ အချိန်#,
				'generic' => q#အီရူခူတ် အချိန်#,
				'standard' => q#အီရူခူတ် စံတော်ချိန်#,
			},
		},
		'Israel' => {
			long => {
				'daylight' => q#အစ္စရေး နွေရာသီ အချိန်#,
				'generic' => q#အစ္စရေး အချိန်#,
				'standard' => q#အစ္စရေး စံတော်ချိန်#,
			},
		},
		'Japan' => {
			long => {
				'daylight' => q#ဂျပန် နွေရာသီ အချိန်#,
				'generic' => q#ဂျပန် အချိန်#,
				'standard' => q#ဂျပန် စံတော်ချိန်#,
			},
		},
		'Kazakhstan' => {
			long => {
				'standard' => q#ကာဇက်စတန် အချိန်#,
			},
		},
		'Kazakhstan_Eastern' => {
			long => {
				'standard' => q#အရှေ့ကာဇက်စတန် အချိန်#,
			},
		},
		'Kazakhstan_Western' => {
			long => {
				'standard' => q#အနောက်ကာဇက်စတန် အချိန်#,
			},
		},
		'Korea' => {
			long => {
				'daylight' => q#ကိုရီးယား နွေရာသီ အချိန်#,
				'generic' => q#ကိုရီးယား အချိန်#,
				'standard' => q#ကိုရီးယား စံတော်ချိန်#,
			},
		},
		'Kosrae' => {
			long => {
				'standard' => q#ခိုစ်ရိုင် အချိန်#,
			},
		},
		'Krasnoyarsk' => {
			long => {
				'daylight' => q#ခရာ့စ်နိုရာစ် နွေရာသီ အချိန်#,
				'generic' => q#ခရာ့စ်နိုရာစ် အချိန်#,
				'standard' => q#ခရာ့စ်နိုရာစ် စံတော်ချိန်#,
			},
		},
		'Kyrgystan' => {
			long => {
				'standard' => q#ကာဂျစ္စတန် အချိန်#,
			},
		},
		'Lanka' => {
			long => {
				'standard' => q#သီရိလင်္ကာ အချိန်#,
			},
		},
		'Line_Islands' => {
			long => {
				'standard' => q#လိုင်းကျွန်းစု အချိန်#,
			},
		},
		'Lord_Howe' => {
			long => {
				'daylight' => q#လော့ဒ်ဟောင် နွေရာသီ အချိန်#,
				'generic' => q#လော့ဒ်ဟောင် အချိန်#,
				'standard' => q#လော့ဒ်ဟောင် စံတော်ချိန်#,
			},
		},
		'Macau' => {
			long => {
				'daylight' => q#မကာအို နွေရာသီ အချိန်#,
				'generic' => q#မကာအို အချိန်#,
				'standard' => q#မကာအို စံတော်ချိန်#,
			},
		},
		'Magadan' => {
			long => {
				'daylight' => q#မာဂါဒန်း နွေရာသီ အချိန်#,
				'generic' => q#မာဂါဒန်း အချိန်#,
				'standard' => q#မာဂါဒန်း စံတော်ချိန်#,
			},
		},
		'Malaysia' => {
			long => {
				'standard' => q#မလေးရှား အချိန်#,
			},
		},
		'Maldives' => {
			long => {
				'standard' => q#မော်လဒိုက် အချိန်#,
			},
		},
		'Marquesas' => {
			long => {
				'standard' => q#မာခေးအပ်စ် အချိန်#,
			},
		},
		'Marshall_Islands' => {
			long => {
				'standard' => q#မာရှယ်ကျွန်းစု အချိန်#,
			},
		},
		'Mauritius' => {
			long => {
				'daylight' => q#မောရစ်ရှ နွေရာသီ အချိန်#,
				'generic' => q#မောရစ်ရှ အချိန်#,
				'standard' => q#မောရစ်ရှ စံတော်ချိန်#,
			},
		},
		'Mawson' => {
			long => {
				'standard' => q#မော်စွန် အချိန်#,
			},
		},
		'Mexico_Pacific' => {
			long => {
				'daylight' => q#မက္ကစီကန် ပစိဖိတ် နွေရာသီ စံတော်ချိန်#,
				'generic' => q#မက္ကဆီကန် ပစိဖိတ် အချိန်#,
				'standard' => q#မက္ကဆီကန် ပစိဖိတ် စံတော်ချိန်#,
			},
		},
		'Mongolia' => {
			long => {
				'daylight' => q#ဥလန်ဘာတော နွေရာသီ အချိန်#,
				'generic' => q#ဥလန်ဘာတော အချိန်#,
				'standard' => q#ဥလန်ဘာတော စံတော်ချိန်#,
			},
		},
		'Moscow' => {
			long => {
				'daylight' => q#မော်စကို နွေရာသီ အချိန်#,
				'generic' => q#မော်စကို အချိန်#,
				'standard' => q#မော်စကို စံတော်ချိန်#,
			},
		},
		'Myanmar' => {
			long => {
				'standard' => q#မြန်မာ အချိန်#,
			},
		},
		'Nauru' => {
			long => {
				'standard' => q#နာဥူရူ အချိန်#,
			},
		},
		'Nepal' => {
			long => {
				'standard' => q#နီပေါ အချိန်#,
			},
		},
		'New_Caledonia' => {
			long => {
				'daylight' => q#နယူးကာလီဒိုးနီးယား နွေရာသီ အချိန်#,
				'generic' => q#နယူးကယ်လီဒိုးနီးယား အချိန်#,
				'standard' => q#နယူးကာလီဒိုးနီးယား စံတော်ချိန်#,
			},
		},
		'New_Zealand' => {
			long => {
				'daylight' => q#နယူးဇီလန် နွေရာသီ အချိန်#,
				'generic' => q#နယူးဇီလန် အချိန်#,
				'standard' => q#နယူးဇီလန် စံတော်ချိန်#,
			},
		},
		'Newfoundland' => {
			long => {
				'daylight' => q#နယူးဖောင်လန် နွေရာသီ စံတော်ချိန်#,
				'generic' => q#နယူးဖောင်လန် အချိန်#,
				'standard' => q#နယူးဖောင်လန် စံတော်ချိန်#,
			},
		},
		'Niue' => {
			long => {
				'standard' => q#နီဥူအေ အချိန်#,
			},
		},
		'Norfolk' => {
			long => {
				'daylight' => q#နောဖော့ခ်ကျွန်း နွေရာသီ စံတော်ချိန်#,
				'generic' => q#နောဖော့ခ်ကျွန်း အချိန်#,
				'standard' => q#နောဖော့ခ်ကျွန်း စံတော်ချိန်#,
			},
		},
		'Noronha' => {
			long => {
				'daylight' => q#ဖာနန်ဒိုးဒီနိုးရိုးညာ နွေရာသီ အချိန်#,
				'generic' => q#ဖာနန်ဒိုးဒီနိုးရိုးညာ အချိန်#,
				'standard' => q#ဖာနန်ဒိုးဒီနိုးရိုးညာ စံတော်ချိန်#,
			},
		},
		'Novosibirsk' => {
			long => {
				'daylight' => q#နိုဗိုစဲဘီအဲယ်စ် နွေရာသီ အချိန်#,
				'generic' => q#နိုဗိုစဲဘီအဲယ်စ် အချိန်#,
				'standard' => q#နိုဗိုစဲဘီအဲယ်စ် စံတော်ချိန်#,
			},
		},
		'Omsk' => {
			long => {
				'daylight' => q#အွမ်းစ်ခ် နွေရာသီ အချိန်#,
				'generic' => q#အွမ်းစ်ခ် အချိန်#,
				'standard' => q#အွမ်းစ်ခ် စံတော်ချိန်#,
			},
		},
		'Pacific/Apia' => {
			exemplarCity => q#အားပီအား#,
		},
		'Pacific/Auckland' => {
			exemplarCity => q#အော့ကလန်#,
		},
		'Pacific/Bougainville' => {
			exemplarCity => q#ဘူဂန်ဗီးလီးယား#,
		},
		'Pacific/Chatham' => {
			exemplarCity => q#ချားသမ်#,
		},
		'Pacific/Easter' => {
			exemplarCity => q#အီစတာ#,
		},
		'Pacific/Efate' => {
			exemplarCity => q#အီဖာတီ#,
		},
		'Pacific/Enderbury' => {
			exemplarCity => q#အန်ဒါဘူရီ#,
		},
		'Pacific/Fakaofo' => {
			exemplarCity => q#ဖာခါအိုဖို#,
		},
		'Pacific/Fiji' => {
			exemplarCity => q#ဖီဂျီ#,
		},
		'Pacific/Funafuti' => {
			exemplarCity => q#ဖူနာဖူတီ#,
		},
		'Pacific/Galapagos' => {
			exemplarCity => q#ဂါလာပါကပ်စ်#,
		},
		'Pacific/Gambier' => {
			exemplarCity => q#ဂမ်ဘီယာ#,
		},
		'Pacific/Guadalcanal' => {
			exemplarCity => q#ဂွါဒါကနဲလ်#,
		},
		'Pacific/Guam' => {
			exemplarCity => q#ဂူအမ်#,
		},
		'Pacific/Honolulu' => {
			exemplarCity => q#ဟိုနိုလူလူ#,
		},
		'Pacific/Kanton' => {
			exemplarCity => q#ကန်တွန်#,
		},
		'Pacific/Kiritimati' => {
			exemplarCity => q#ခရိဒီမတီ#,
		},
		'Pacific/Kosrae' => {
			exemplarCity => q#ခိုစ်ရိုင်#,
		},
		'Pacific/Kwajalein' => {
			exemplarCity => q#ခွာဂျာလိန်#,
		},
		'Pacific/Majuro' => {
			exemplarCity => q#မာဂျူးရို#,
		},
		'Pacific/Marquesas' => {
			exemplarCity => q#မာခေးအပ်စ်#,
		},
		'Pacific/Midway' => {
			exemplarCity => q#မစ်ဒ်ဝေး#,
		},
		'Pacific/Nauru' => {
			exemplarCity => q#နာဥူရူ#,
		},
		'Pacific/Niue' => {
			exemplarCity => q#နီဦးအေ#,
		},
		'Pacific/Norfolk' => {
			exemplarCity => q#နော်ဖော့ခ်#,
		},
		'Pacific/Noumea' => {
			exemplarCity => q#နူမယ်အာ#,
		},
		'Pacific/Pago_Pago' => {
			exemplarCity => q#ပါဂိုပါဂို#,
		},
		'Pacific/Palau' => {
			exemplarCity => q#ပလာအို#,
		},
		'Pacific/Pitcairn' => {
			exemplarCity => q#ပါတ်ကယ်ရင်#,
		},
		'Pacific/Ponape' => {
			exemplarCity => q#ဖိုနာဖဲအ်#,
		},
		'Pacific/Port_Moresby' => {
			exemplarCity => q#ဖို့တ် မိုရက်စ်ဘီ#,
		},
		'Pacific/Rarotonga' => {
			exemplarCity => q#ရာရိုတွန်းဂါ#,
		},
		'Pacific/Saipan' => {
			exemplarCity => q#ဆိုင်ပန်#,
		},
		'Pacific/Tahiti' => {
			exemplarCity => q#တဟီတီ#,
		},
		'Pacific/Tarawa' => {
			exemplarCity => q#တာရာဝါ#,
		},
		'Pacific/Tongatapu' => {
			exemplarCity => q#တွန်ဂါတာပု#,
		},
		'Pacific/Truk' => {
			exemplarCity => q#ချုခ်#,
		},
		'Pacific/Wake' => {
			exemplarCity => q#ဝိတ်ခ်#,
		},
		'Pacific/Wallis' => {
			exemplarCity => q#ဝေါလီစ်#,
		},
		'Pakistan' => {
			long => {
				'daylight' => q#ပါကစ္စတန် နွေရာသီ အချိန်#,
				'generic' => q#ပါကစ္စတန် အချိန်#,
				'standard' => q#ပါကစ္စတန် စံတော်ချိန်#,
			},
		},
		'Palau' => {
			long => {
				'standard' => q#ပလာအို အချိန်#,
			},
		},
		'Papua_New_Guinea' => {
			long => {
				'standard' => q#ပါပူအာနယူးဂီနီ အချိန်#,
			},
		},
		'Paraguay' => {
			long => {
				'daylight' => q#ပါရာဂွေး နွေရာသီ အချိန်#,
				'generic' => q#ပါရာဂွေး အချိန်#,
				'standard' => q#ပါရာဂွေး စံတော်ချိန်#,
			},
		},
		'Peru' => {
			long => {
				'daylight' => q#ပီရူး နွေရာသီ အချိန်#,
				'generic' => q#ပီရူး အချိန်#,
				'standard' => q#ပီရူး စံတော်ချိန်#,
			},
		},
		'Philippines' => {
			long => {
				'daylight' => q#ဖိလစ်ပိုင် နွေရာသီ အချိန်#,
				'generic' => q#ဖိလစ်ပိုင် အချိန်#,
				'standard' => q#ဖိလစ်ပိုင် စံတော်ချိန်#,
			},
		},
		'Phoenix_Islands' => {
			long => {
				'standard' => q#ဖီးနစ်ကျွန်းစု အချိန်#,
			},
		},
		'Pierre_Miquelon' => {
			long => {
				'daylight' => q#စိန့်ပီအဲနှင့် မီခွီလွန် နွေရာသီ စံတော်ချိန်#,
				'generic' => q#စိန့်ပီအဲနှင့်မီခွီလွန်အချိန်#,
				'standard' => q#စိန့်ပီအဲနှင့်မီခွီလွန်စံတော်ချိန်#,
			},
		},
		'Pitcairn' => {
			long => {
				'standard' => q#ပါတ်ကယ်ရင် အချိန်#,
			},
		},
		'Ponape' => {
			long => {
				'standard' => q#ဖိုနာဖဲအ် အချိန်#,
			},
		},
		'Pyongyang' => {
			long => {
				'standard' => q#ပြုံယန်း အချိန်#,
			},
		},
		'Reunion' => {
			long => {
				'standard' => q#ရီယူနီယံ အချိန်#,
			},
		},
		'Rothera' => {
			long => {
				'standard' => q#ရိုသီရာ အချိန်#,
			},
		},
		'Sakhalin' => {
			long => {
				'daylight' => q#ဆာခါလင် နွေရာသီ အချိန်#,
				'generic' => q#ဆာခါလင် အချိန်#,
				'standard' => q#ဆာခါလင် စံတော်ချိန်#,
			},
		},
		'Samoa' => {
			long => {
				'daylight' => q#ဆမိုးအား နွေရာသီ အချိန်#,
				'generic' => q#ဆမိုအာ အချိန်#,
				'standard' => q#ဆမိုအာ စံတော်ချိန်#,
			},
		},
		'Seychelles' => {
			long => {
				'standard' => q#ဆေးရှဲ အချိန်#,
			},
		},
		'Singapore' => {
			long => {
				'standard' => q#စင်္ကာပူ အချိန်#,
			},
		},
		'Solomon' => {
			long => {
				'standard' => q#ဆော်လမွန်ကျွန်းစု အချိန်#,
			},
		},
		'South_Georgia' => {
			long => {
				'standard' => q#တောင်ဂျော်ဂျီယာ အချိန်#,
			},
		},
		'Suriname' => {
			long => {
				'standard' => q#စူးရီနာမ်အချိန်#,
			},
		},
		'Syowa' => {
			long => {
				'standard' => q#ရှိုဝါ အချိန်#,
			},
		},
		'Tahiti' => {
			long => {
				'standard' => q#တဟီတီ အချိန်#,
			},
		},
		'Taipei' => {
			long => {
				'daylight' => q#ထိုင်ပေ နွေရာသီ အချိန်#,
				'generic' => q#ထိုင်ပေ အချိန်#,
				'standard' => q#ထိုင်ပေ စံတော်ချိန်#,
			},
		},
		'Tajikistan' => {
			long => {
				'standard' => q#တာဂျစ်ကစ္စတန် အချိန်#,
			},
		},
		'Tokelau' => {
			long => {
				'standard' => q#တိုကီလာဥ အချိန်#,
			},
		},
		'Tonga' => {
			long => {
				'daylight' => q#တွန်ဂါ နွေရာသီ အချိန်#,
				'generic' => q#တွန်ဂါ အချိန်#,
				'standard' => q#တွန်ဂါ စံတော်ချိန်#,
			},
		},
		'Truk' => {
			long => {
				'standard' => q#ချုခ် အချိန်#,
			},
		},
		'Turkmenistan' => {
			long => {
				'daylight' => q#တာ့ခ်မင်နစ္စတန် နွေရာသီ အချိန်#,
				'generic' => q#တာ့ခ်မင်နစ္စတန် အချိန်#,
				'standard' => q#တာ့ခ်မင်နစ္စတန် စံတော်ချိန်#,
			},
		},
		'Tuvalu' => {
			long => {
				'standard' => q#တူဗားလူ အချိန်#,
			},
		},
		'Uruguay' => {
			long => {
				'daylight' => q#ဥရုဂွေး နွေရာသီ အချိန်#,
				'generic' => q#ဥရုဂွေး အချိန်#,
				'standard' => q#ဥရုဂွေး စံတော်ချိန်#,
			},
		},
		'Uzbekistan' => {
			long => {
				'daylight' => q#ဥဇဘက်ကစ္စတန် နွေရာသီ အချိန်#,
				'generic' => q#ဥဇဘက်ကစ္စတန် အချိန်#,
				'standard' => q#ဥဇဘက်ကစ္စတန် စံတော်ချိန်#,
			},
		},
		'Vanuatu' => {
			long => {
				'daylight' => q#ဗနွားတူ နွေရာသီ အချိန်#,
				'generic' => q#ဗနွားတူ အချိန်#,
				'standard' => q#ဗနွားတူ စံတော်ချိန်#,
			},
		},
		'Venezuela' => {
			long => {
				'standard' => q#ဗင်နီဇွဲလား အချိန်#,
			},
		},
		'Vladivostok' => {
			long => {
				'daylight' => q#ဗလာဒီဗော့စတော့ခ် နွေရာသီ အချိန်#,
				'generic' => q#ဗလာဒီဗော့စတော့ခ် အချိန်#,
				'standard' => q#ဗလာဒီဗော့စတော့ခ် စံတော်ချိန်#,
			},
		},
		'Volgograd' => {
			long => {
				'daylight' => q#ဗိုဂိုဂရက် နွေရာသီ အချိန်#,
				'generic' => q#ဗိုလ်ဂိုဂရက် အချိန်#,
				'standard' => q#ဗိုလ်ဂိုဂရက် စံတော်ချိန်#,
			},
		},
		'Vostok' => {
			long => {
				'standard' => q#ဗိုစ်တိုခ် အချိန်#,
			},
		},
		'Wake' => {
			long => {
				'standard' => q#ဝိတ်ခ်ကျွန်း အချိန်#,
			},
		},
		'Wallis' => {
			long => {
				'standard' => q#ဝေါလီစ်နှင့် ဖူကျူနာ အချိန်#,
			},
		},
		'Yakutsk' => {
			long => {
				'daylight' => q#ယူခူးတ်စ် နွေရာသီ အချိန်#,
				'generic' => q#ယူခူးတ်စ် အချိန်#,
				'standard' => q#ယူခူးတ်စ် စံတော်ချိန်#,
			},
		},
		'Yekaterinburg' => {
			long => {
				'daylight' => q#ရယ်ခါးတီရင်ဘာခ် နွေရာသီ အချိန်#,
				'generic' => q#ရယ်ခါးတီရင်ဘားခ် အချိန်#,
				'standard' => q#ရယ်ခါးတီရင်ဘားခ် စံတော်ချိန်#,
			},
		},
		'Yukon' => {
			long => {
				'standard' => q#ယူကွန်း အချိန်#,
			},
		},
	 } }
);
no Moo;

1;

# vim: tabstop=4
